(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1094560,      19463]
NotebookOptionsPosition[   1085825,      19194]
NotebookOutlinePosition[   1086352,      19213]
CellTagsIndexPosition[   1086309,      19210]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["\nDieses ",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["Mathematica",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["- Notebook behandelt nicht die schon mehrfach erw\[ADoubleDot]hnte \
Erw\[ADoubleDot]rmung einer Zugbremsscheibe, sondern ein verwandtes Problem, \
n\[ADoubleDot]mlich die W\[ADoubleDot]rmeleitung in einem \
(d\[UDoubleDot]nnen) Stab. Obwohl dieses (Lehrbuch-) Beispiel weniger komplex \
ist, zeigt es bereits fast alle Eigenschaften des vollen Problems. Der unten \
dargestellte Fall (feste Vorgabe der Temperatur an den Stab-Enden) kann auf \
kompliziertere Randbedingungen erweitert werden.  Die Darstellung erfolgt in \
der Standard -",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["Mathematica",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["- Notation (nur diese ist programmiertechnisch eindeutig). Alle \
Erl\[ADoubleDot]uterungen sind als Kommentare eingef\[UDoubleDot]gt.\
\[LineSeparator]\[LineSeparator]",
  FontSize->18,
  FontWeight->"Bold"],
 "\n"
}], "Text",
 CellChangeTimes->{{3.415780136375*^9, 3.415780356921875*^9}, {
   3.4193152466875*^9, 3.419315275921875*^9}, {3.419315323421875*^9, 
   3.41931535546875*^9}, {3.4193169314375*^9, 3.41931696628125*^9}, {
   3.4193211699375*^9, 3.419321265359375*^9}, {3.4474191144375*^9, 
   3.447419141953125*^9}, 3.48194236934375*^9, {3.4819455220625*^9, 
   3.481945523265625*^9}}],

Cell["\<\

Viele Vorg\[ADoubleDot]nge werden durch partielle Differentialgleichungen \
(PDE) beschrieben. Die gesuchte Funktion h\[ADoubleDot]ngt dabei von mehreren \
unabh\[ADoubleDot]ngigen Variablen ab. Die wichtigsten linearen Vertreter \
dieser PDE sind:

- die W\[ADoubleDot]rmeleitgleichung (allgemeiner: die Diffusionsgleichung)
- die Wellengleichung
- die Potentialgleichung (auch Laplace-Gl. genannt) .

Neben Anfangsbedingungen (Vorgabe der Funktion zur Zeit  t = 0 ) m\
\[UDoubleDot]ssen auch Randbedingungen gestellt werden (Vorgabe der Funktion \
oder ihrer r\[ADoubleDot]umlichen Ableitung am Rande des untersuchten \
Gebietes). Die exakte Behandlung (im Sinne einer einfachen \
L\[ODoubleDot]sungsformel) ist meistens nicht m\[ODoubleDot]glich. Oft ben\
\[ODoubleDot]tigt man (unendliche) Reihen, um die L\[ODoubleDot]sung \
darzustellen, s. Punkt (F). Aber auch dies geht nur in relativ einfachen F\
\[ADoubleDot]llen. 

Im Folgenden wird die W\[ADoubleDot]rmeleitung in einem Stab untersucht. Der \
Einfachheit halber gehen wir davon aus, dass die Temperatur nur in der Stab- \
L\[ADoubleDot]ngsrichtung (die hier die z-Richtung sein soll) variiert. Die \
Temperatur   T   ist dann eine Funktion von   t  und  z . Man spricht dann \
auch von der [r\[ADoubleDot]umlich] eindimensionalen \
W\[ADoubleDot]rmeleitgleichung. Die Herleitung der \
W\[ADoubleDot]rmeleitgleichung findet man in einem Physikbuch, z.B. \
Alonso/Finn, Fundamental University Physics, Vol. 2 . Au\[SZ]erdem soll der \
Stab  - au\[SZ]er an seinen Enden -  thermisch isoliert sein.

\
\>", "Text",
 CellChangeTimes->{
  3.415946139734375*^9, {3.419137030140625*^9, 3.419137061578125*^9}, {
   3.419137291375*^9, 3.419137338734375*^9}, {3.419314967234375*^9, 
   3.419314975796875*^9}, {3.419315094859375*^9, 3.419315118515625*^9}, {
   3.41932108378125*^9, 3.419321099140625*^9}, 3.419321130765625*^9, {
   3.4819455931875*^9, 3.481945602984375*^9}, 3.641097977133645*^9, {
   3.6410988349326677`*^9, 3.641098840713932*^9}}],

Cell[TextData[{
 "\n",
 StyleBox["A) Die Vorbereitung\n", "Section"]
}], "Text",
 CellChangeTimes->{{3.419316484953125*^9, 3.419316505078125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Die", " ", 
       StyleBox["Materialdaten",
        FontColor->RGBColor[0, 1, 0]], " ", "sind", " ", "die", " ", 
       "f\[UDoubleDot]r", " ", "Cr"}], "-", "Ni", "-", 
      RowBox[{"Stahl", "  ", "[", 
       RowBox[{
        RowBox[{"Quelle", ":", " ", "DB"}], ";", " ", 
        StyleBox[
         RowBox[{"OHNE", " ", "GEW\[CapitalADoubleDot]HR"}],
         FontColor->RGBColor[1, 0, 0]]}], " ", "]"}]}], " ", ";", 
     "\[IndentingNewLine]", "   ", 
     RowBox[{
     "eigentlich", " ", "h\[ADoubleDot]ngen", " ", "diese", " ", "Daten", " ",
       "auch", " ", "von", " ", "der", " ", "Temperatur", " ", "ab"}]}], ",", 
    " ", "\[IndentingNewLine]", "   ", 
    RowBox[{
     RowBox[{
     "aber", " ", "dass", " ", "soll", " ", "im", " ", "Folgenden", " ", 
      "vernachl\[ADoubleDot]ssigt", " ", "werden"}], ";", " ", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", "   ", 
     RowBox[{
     "\[Lambda]", " ", "ist", " ", "die", " ", 
      "W\[ADoubleDot]rmeleitf\[ADoubleDot]higkeit", " ", "in", " ", 
      RowBox[{"W", "/", 
       RowBox[{"(", " ", 
        RowBox[{"K", " ", "m"}], ")"}]}]}]}], " ", ",", "  ", 
    "\[IndentingNewLine]", "   ", 
    RowBox[{
    "cp", " ", "die", " ", "spezifische", " ", "W\[ADoubleDot]rme", " ", "in",
      " ", 
     RowBox[{"J", " ", "/", 
      RowBox[{"(", 
       RowBox[{"kg", " ", "K"}], ")"}]}]}], " ", ",", "   ", 
    "\[IndentingNewLine]", "   ", 
    RowBox[{"\[Rho]", " ", "die", " ", "Dichte", " ", "in", " ", 
     RowBox[{"kg", "/", 
      SuperscriptBox["m", "3"]}], " ", "und", " ", "\[Alpha]", " ", "der", 
     " ", "W\[ADoubleDot]rme\[UDoubleDot]bergangskoeffizient", " ", "in", " ",
      "\[IndentingNewLine]", "  ", 
     RowBox[{"W", "/", 
      RowBox[{"(", 
       RowBox[{"K", " ", 
        SuperscriptBox["m", "2"]}], ")"}]}]}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.415780405875*^9, 3.415780407953125*^9}, {
   3.41931500484375*^9, 3.419315011640625*^9}, {3.419315072625*^9, 
   3.419315085375*^9}, {3.419315130453125*^9, 3.41931516184375*^9}, 
   3.419315196296875*^9, {3.419315544671875*^9, 3.41931556390625*^9}, {
   3.44738698628125*^9, 3.447387008578125*^9}, 3.447387074984375*^9, {
   3.6410980191181107`*^9, 3.6410980204149885`*^9}, {3.6416458117542076`*^9, 
   3.641645818019847*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.415780405875*^9, 3.415780407953125*^9}, {
   3.415780824328125*^9, 3.4157808290625*^9}, 3.44738709846875*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{"Materialdaten", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Lambda]", "->", "15"}], " ", ",", 
     RowBox[{"cp", "->", "500"}], " ", ",", 
     RowBox[{"\[Rho]", "->", "7800"}], " ", ",", 
     RowBox[{"\[Alpha]", "->", "20"}]}], "}"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Lambda]", "\[Rule]", "15"}], ",", 
   RowBox[{"cp", "\[Rule]", "500"}], ",", 
   RowBox[{"\[Rho]", "\[Rule]", "7800"}], ",", 
   RowBox[{"\[Alpha]", "\[Rule]", "20"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4157801139375*^9, 3.415780833375*^9, 
  3.415944954640625*^9, 3.447387212578125*^9, 3.447388048484375*^9, 
  3.447388421515625*^9, 3.447388977609375*^9, 3.447556608640625*^9, 
  3.48194300396875*^9, 3.481943706296875*^9, 3.481943842375*^9, 
  3.4819524436875*^9, 3.481953740625*^9, 3.6410988513858366`*^9, 
  3.6410999369044704`*^9, 3.641100262655396*^9, 3.6411011940800486`*^9, 
  3.6411016253938856`*^9, 3.6416467071628633`*^9, 3.641647611087398*^9, 
  3.641694261820299*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"die", " ", "relevanten", " ", 
     StyleBox["geometrischen",
      FontColor->RGBColor[0, 1, 0]], 
     StyleBox[" ",
      FontColor->RGBColor[0, 1, 0]], 
     StyleBox["Daten",
      FontColor->RGBColor[0, 1, 0]]}], ",", "  ", "\[IndentingNewLine]", 
    "   ", 
    RowBox[{
     RowBox[{"d", ".", "h", ".", " ", "hier"}], " ", "linker", " ", "und", 
     " ", "rechter", " ", "Rand", " ", "des", " ", "Stabes"}], ",", " ", 
    RowBox[{"Einheit", " ", "Meter"}]}], " ", "\[IndentingNewLine]", " ", 
   "*)"}], " "}]], "Input",
 CellChangeTimes->{{3.415780469671875*^9, 3.415780473625*^9}, 
   3.415944531359375*^9, {3.4193155786875*^9, 3.41931575675*^9}, {
   3.6416467243989973`*^9, 3.6416467366473293`*^9}, {3.641693254837916*^9, 
   3.641693286119052*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"z0", "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"zn", "=", "1"}], ";"}]], "Input"],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.419315229671875*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"die", " ", 
    StyleBox["Bestandteile",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox["der",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 1]], 
    RowBox[{
     StyleBox["W\[ADoubleDot]rmeleitgleichung",
      FontColor->RGBColor[1, 0, 1]], " ", ":"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.419315891546875*^9, 3.4193159066875*^9}, {
  3.41931597478125*^9, 3.4193159796875*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"die", " ", 
    StyleBox["partielle",
     FontColor->RGBColor[1, 0, 0]], " ", 
    StyleBox["Ableitung",
     FontColor->RGBColor[1, 0, 1]], " ", "der", " ", "Temperatur", " ", "T", 
    "\[IndentingNewLine]", "  ", 
    StyleBox["nach",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox["der",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox["Zeit",
     FontColor->RGBColor[1, 0, 1]], 
    StyleBox[
     RowBox[{
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 1]], " "}]], 
    RowBox[{"t", " ", ":"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{3.6416459104732018`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Tpunkt", "[", 
   RowBox[{"z_", ",", "t_"}], "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], ",", "t"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["T", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"0", ",", "1"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"z", ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.415780114*^9, 3.41594450865625*^9, 3.415944677484375*^9, 
  3.41931536834375*^9, 3.419318052671875*^9, 3.41931922534375*^9, 
  3.419319772921875*^9, 3.419320441078125*^9, 3.41932182846875*^9, 
  3.41932188603125*^9, 3.419331862640625*^9, 3.419332893375*^9, 
  3.419334335640625*^9, 3.41935611525*^9, 3.447385488828125*^9, 
  3.44738721265625*^9, 3.447388048546875*^9, 3.447388421625*^9, 
  3.44738897765625*^9, 3.447556608703125*^9, 3.48194300409375*^9, 
  3.481943706375*^9, 3.4819438424375*^9, 3.481952443890625*^9, 
  3.481953740859375*^9, 3.6410988515420885`*^9, 3.6410999369982204`*^9, 
  3.6411011941581755`*^9, 3.6411016255657597`*^9, 3.6416467073503647`*^9, 
  3.641647611212397*^9, 3.641694261992179*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"die", " ", 
   StyleBox["2.",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["partielle",
    FontColor->RGBColor[1, 0, 0]], " ", 
   StyleBox["Ableitung",
    FontColor->RGBColor[1, 0, 1]], " ", "der", " ", "Temperatur", " ", "T", 
   "  ", "\[IndentingNewLine]", "  ", 
   StyleBox["nach",
    FontColor->RGBColor[1, 0, 1]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 1]], 
   StyleBox["der",
    FontColor->RGBColor[1, 0, 1]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 1]], 
   StyleBox["Raumkoordinate",
    FontColor->RGBColor[1, 0, 1]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 1]], 
   StyleBox[
    RowBox[{"z", " ", ":"}],
    FontColor->RGBColor[1, 0, 0]]}], 
  StyleBox[
   RowBox[{
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], " "}]], "*)"}]], "Input",
 CellChangeTimes->{{3.419315947796875*^9, 3.419315951609375*^9}, {
  3.6416459059731894`*^9, 3.6416459068013144`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Tablzz", "[", 
   RowBox[{"z_", ",", "t_"}], "]"}], "=", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.41594434165625*^9, 3.41594440321875*^9}}],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["T", 
   TagBox[
    RowBox[{"(", 
     RowBox[{"2", ",", "0"}], ")"}],
    Derivative],
   MultilineFunction->None], "[", 
  RowBox[{"z", ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{
  3.415780114046875*^9, {3.415944373828125*^9, 3.415944403828125*^9}, 
   3.415944512890625*^9, 3.41594467753125*^9, 3.4193153749375*^9, 
   3.4193180526875*^9, 3.419319225375*^9, 3.419319772953125*^9, 
   3.419320441109375*^9, 3.41932182853125*^9, 3.4193218860625*^9, 
   3.419331862671875*^9, 3.419332893390625*^9, 3.4193343356875*^9, 
   3.419356115296875*^9, 3.447385488859375*^9, 3.447387212671875*^9, 
   3.44738804859375*^9, 3.447388421671875*^9, 3.4473889776875*^9, 
   3.447556608734375*^9, 3.481943004140625*^9, 3.48194370640625*^9, 
   3.481943842484375*^9, 3.481952443984375*^9, 3.4819537409375*^9, 
   3.6410988515733395`*^9, 3.6410999370294724`*^9, 3.641101194189426*^9, 
   3.6411016256282616`*^9, 3.6416467073816175`*^9, 3.6416476112592735`*^9, 
   3.641694262039049*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  StyleBox[
   RowBox[{
    RowBox[{"die", " ", "W\[ADoubleDot]rmeleitgleichung"}], "..."}],
   FontColor->RGBColor[1, 0, 1]], 
  StyleBox[" ",
   FontColor->RGBColor[0, 1, 0]], "*)"}]], "Input",
 CellChangeTimes->{{3.419315427359375*^9, 3.419315427765625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dgl", "=", " ", 
  RowBox[{
   RowBox[{"Tpunkt", "[", 
    RowBox[{"z", ",", "t"}], "]"}], "\[Equal]", " ", 
   FractionBox[
    RowBox[{"\[Lambda]", " ", 
     RowBox[{"Tablzz", "[", 
      RowBox[{"z", ",", "t"}], "]"}]}], 
    RowBox[{"cp", " ", "\[Rho]"}]]}]}]], "Input",
 CellChangeTimes->{{3.415944420921875*^9, 3.415944447984375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["T", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"z", ",", "t"}], "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{"\[Lambda]", " ", 
    RowBox[{
     SuperscriptBox["T", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"z", ",", "t"}], "]"}]}], 
   RowBox[{"cp", " ", "\[Rho]"}]]}]], "Output",
 CellChangeTimes->{3.415780114078125*^9, 3.4159444521875*^9, 
  3.41594452103125*^9, 3.4159446775625*^9, 3.419315379296875*^9, 
  3.41931805271875*^9, 3.419319225390625*^9, 3.419319772984375*^9, 
  3.419320441140625*^9, 3.419321828625*^9, 3.41932188609375*^9, 
  3.419331862703125*^9, 3.419332893421875*^9, 3.41933433571875*^9, 
  3.419356115328125*^9, 3.447385488890625*^9, 3.447387212703125*^9, 
  3.447388048609375*^9, 3.447388421703125*^9, 3.44738897771875*^9, 
  3.447556608765625*^9, 3.481943004171875*^9, 3.4819437064375*^9, 
  3.481943842515625*^9, 3.481952444078125*^9, 3.481953741046875*^9, 
  3.641098851620214*^9, 3.6410999370607214`*^9, 3.6411011942206755`*^9, 
  3.6411016256751347`*^9, 3.6416467074284897`*^9, 3.6416476112905226`*^9, 
  3.6416942620703*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"...", 
   StyleBox["mit",
    FontColor->RGBColor[0, 1, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]], 
   StyleBox["den",
    FontColor->RGBColor[0, 1, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[0, 1, 0]], 
   RowBox[{
    StyleBox["Materialdaten",
     FontColor->RGBColor[0, 1, 0]], ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.41594446*^9, 3.4159444710625*^9}, {3.419315430765625*^9,
   3.419315431125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dgl", "=", 
  RowBox[{"dgl", "/.", "Materialdaten"}]}]], "Input",
 CellChangeTimes->{{3.415944473578125*^9, 3.41594448253125*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["T", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"0", ",", "1"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"z", ",", "t"}], "]"}], "\[Equal]", 
  FractionBox[
   RowBox[{
    SuperscriptBox["T", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"z", ",", "t"}], "]"}], "260000"]}]], "Output",
 CellChangeTimes->{{3.415944484125*^9, 3.4159445226875*^9}, 
   3.41594467759375*^9, 3.419315451265625*^9, 3.41931805275*^9, 
   3.419319225421875*^9, 3.419319773015625*^9, 3.419320441171875*^9, 
   3.4193218286875*^9, 3.419321886125*^9, 3.419331862734375*^9, 
   3.419332893453125*^9, 3.4193343358125*^9, 3.419356115359375*^9, 
   3.447385488921875*^9, 3.447387212734375*^9, 3.447388048640625*^9, 
   3.447388421734375*^9, 3.44738897775*^9, 3.44755660878125*^9, 
   3.481943004203125*^9, 3.48194370646875*^9, 3.4819438425625*^9, 
   3.481952444171875*^9, 3.48195374115625*^9, 3.6410988516514645`*^9, 
   3.6410999370919724`*^9, 3.641101194251926*^9, 3.641101625706386*^9, 
   3.6416467074753647`*^9, 3.6416476113217726`*^9, 3.6416942621171737`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"die", " ", 
    StyleBox["zus\[ADoubleDot]tzlichen",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    RowBox[{
     StyleBox["Bedingungen",
      FontColor->RGBColor[0, 0, 1]], ":"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    StyleBox["Anfangstemperatur",
     FontColor->GrayLevel[0]], " ", "in", " ", "\[Degree]C"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.419315769546875*^9, 3.41931577015625*^9}, {
   3.419315993015625*^9, 3.419316011359375*^9}, 3.4193160749375*^9, {
   3.419316330234375*^9, 3.419316332890625*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.4819436515625*^9, 3.481943678578125*^9}, {
  3.6410981653997016`*^9, 3.6410981884466343`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"1.", " ", "\[IndentingNewLine]", " ", 
     StyleBox["als",
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"Ausgangslage", "/", "Anfangsbedingung"}],
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontColor->GrayLevel[0]], 
     StyleBox["zur",
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontColor->GrayLevel[0]], 
     StyleBox["Zeit",
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontColor->GrayLevel[0]], 
     StyleBox["t",
      FontColor->GrayLevel[0]]}], 
    StyleBox["=",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{
     "0", "\[IndentingNewLine]", " ", "nehmen", " ", "wir", " ", "eine", " ", 
      "inhomogene", " ", "Temperaturverteilung", " ", "im", " ", "Stab", " ", 
      "an"}],
     FontColor->GrayLevel[0]]}], 
   StyleBox[",",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox["   ",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
    "wobei", " ", "an", " ", "beiden", " ", "R\[ADoubleDot]ndern", " ", "die",
      " ", "gleiche", " ", "Temperatur", " ", "TRand", " ", "vorgegeben", " ",
      "\[IndentingNewLine]", "  ", "sein", " ", 
     RowBox[{"soll", ":", " ", 
      RowBox[{"dann", " ", "liegen", " ", 
       RowBox[{"sog", ".", " ", "\"\<homogene Randbedingungen\>\""}], " ", 
       RowBox[{"vor", "."}]}]}]}],
    FontColor->GrayLevel[0]]}], "\[IndentingNewLine]", "*)"}]], "Input",
 CellChangeTimes->{{3.415780484890625*^9, 3.415780488859375*^9}, {
  3.41594619690625*^9, 3.415946202125*^9}, {3.419316336359375*^9, 
  3.419316337375*^9}, {3.419316378515625*^9, 3.419316378953125*^9}, {
  3.481942449328125*^9, 3.481942449859375*^9}, {3.641645934207632*^9, 
  3.641645935504511*^9}, {3.641646031473502*^9, 3.641646034286009*^9}, {
  3.6416461438175516`*^9, 3.6416462220052595`*^9}, {3.641693340993865*^9, 
  3.641693346728224*^9}, {3.6416933942437*^9, 3.641693443790434*^9}}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{3.481943183640625*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TRand", " ", "=", " ", "0"}], ";"}], "  "}]], "Input",
 CellChangeTimes->{
  3.48194318871875*^9, {3.641098221602959*^9, 3.6410982472905216`*^9}, {
   3.6410983362282357`*^9, 3.641098348697016*^9}, 3.641099926857566*^9, 
   3.6416462451615767`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"deltaT", "=", "100"}], ";"}]], "Input",
 CellChangeTimes->{{3.6411009027822886`*^9, 3.6411009169229574`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", "z_", "]"}], "=", 
  RowBox[{"TRand", " ", "+", " ", 
   RowBox[{"deltaT", " ", 
    StyleBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{"UnitStep", "[", 
        RowBox[{"z", "-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zn", "/", "2"}], "-", "0.1"}], ")"}]}], "]"}], "-", 
       RowBox[{"UnitStep", "[", 
        RowBox[{"z", "-", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"zn", "/", "2"}], "+", "0.1"}], ")"}]}], "]"}]}], ")"}],
     FontColor->RGBColor[1, 0, 0]]}]}]}]], "Input",
 CellChangeTimes->{{3.4819430930625*^9, 3.48194313178125*^9}, {
   3.48194316434375*^9, 3.48194319059375*^9}, {3.48194368596875*^9, 
   3.481943687234375*^9}, {3.64110092161047*^9, 3.641100923329225*^9}, 
   3.6416462483959565`*^9}],

Cell[BoxData[
 RowBox[{"100", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"UnitStep", "[", 
      RowBox[{
       RowBox[{"-", "0.6`"}], "+", "z"}], "]"}]}], "+", 
    RowBox[{"UnitStep", "[", 
     RowBox[{
      RowBox[{"-", "0.4`"}], "+", "z"}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.4819431101875*^9, 3.481943135296875*^9}, {
   3.481943178640625*^9, 3.481943191921875*^9}, {3.481943688296875*^9, 
   3.481943706515625*^9}, 3.481943842625*^9, 3.4819524443125*^9, 
   3.4819537413125*^9, 3.6410988517295885`*^9, 3.641099937170096*^9, 
   3.641101194345676*^9, 3.641101625831385*^9, 3.6416467076003656`*^9, 
   3.6416476114155245`*^9, 3.6416935650401373`*^9, 3.641694262242175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"anfangsbedingung", "=", 
  RowBox[{
   RowBox[{"T", "[", 
    RowBox[{"z", ",", "0"}], "]"}], 
   StyleBox["\[Equal]",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[
    RowBox[{"f", "[", "z", "]"}],
    FontColor->RGBColor[1, 0, 0]]}]}]], "Input",
 CellChangeTimes->{{3.41594455434375*^9, 3.4159445595*^9}, {3.48194245525*^9, 
   3.4819424815625*^9}, {3.48194290765625*^9, 3.481942963875*^9}, 
   3.48194300903125*^9, 3.481943105546875*^9, {3.481943208328125*^9, 
   3.481943212421875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"T", "[", 
   RowBox[{"z", ",", "0"}], "]"}], "\[Equal]", 
  RowBox[{"100", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"UnitStep", "[", 
       RowBox[{
        RowBox[{"-", "0.6`"}], "+", "z"}], "]"}]}], "+", 
     RowBox[{"UnitStep", "[", 
      RowBox[{
       RowBox[{"-", "0.4`"}], "+", "z"}], "]"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.48194321328125*^9, {3.481943696328125*^9, 3.481943706546875*^9}, 
   3.481943842671875*^9, 3.481952444421875*^9, 3.481953741390625*^9, 
   3.6410988517452126`*^9, 3.6410999371857233`*^9, 3.6411011943613005`*^9, 
   3.6411016258470125`*^9, 3.6416467076316147`*^9, 3.6416476114311485`*^9, 
   3.641694262257801*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Thick", ",", "Red"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.481943012703125*^9, 3.48194302925*^9}, {
  3.4819431956875*^9, 3.4819431993125*^9}, {3.6416935385714483`*^9, 
  3.641693558727651*^9}, {3.6416936050087957`*^9, 3.6416936120400305`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQ7ZX64uKBl6F2DFDwfF1Y0n1JE3sYX4z7at9mSRc4
X89SZOlcyRA43+qC8YZJkilw/oHZh017JUvg/ObG7oouyRY4P6XkvWSn5BQ4
n2OK58IPH5fA+dsvGLm7y62H8yOa79w63L0Fzs/fWKw748tOOP/ThGsnGBn3
w/knDh7bf97mEJyfWenJG/nmCJx/kNPo/5rc43D+ssVH/kmpnoLzHcT2Lgpe
dwbO1z1+Z8cxrfNw/hWH4Hcr312A83O4si9dNbgE55++Eb6Xr+8ynB/sFvHw
yZMrcL7Zgu7wBSrX4PwH/yZfyai/DufzvLnQXd6C4Fvc5HVu60TwJ2xu37h4
MoLvkFHdd285gr/wYpJHyAUEP2mJ4R57xRtwft/EvGI/NQR/V91qrVhtBF8o
UnVmlSmCf5hXsmyrJ4KvUs5goF2E4D/1PL9Y7DCSfLd6/8QTCH7KmfoqnnMI
/iM/g0Cmmwj+veCJ/96+Q/BvxAZHHpW6CeeLz1/t4qCA4Ic9YDbYrYrgX0na
wrbRAMG/mC66ZY4bgi+wMne+uA+CH/DqaNekQAT/XE5ZYkcMgn+q8DpfSRGC
z7lZ/9e7cgTf40v708xaBL/D9MGFJ00I/vEyiz3xHQg+244Jy2/1IvhuP19M
Cp2M4N88m6+YMAXBBwA8LeZX
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQHZ16WPDyvJv2DGAQ6XCg4ZeY+RYEf29r9BGlUwj+
tn5Z+V9fEfwNM+9XXlS8BedrTSxs/HsWwV/awdypWXUbzv+aHPUqbfcdOJ/b
pS1oo/g9OL9G4CnPw5j7cD7PPm2G674P4HzbMv+/h38h+HOW9CxWnvMQzo8L
NTnL6f0Izu8S9TV4sgDB33o1dfK+bwh+m4l/42Gux3B+2GSL/BNyCP4+J91n
pzQQ/CBfufJpBgg+ANSqXnc=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBmIQLSLp8f686WN7Bii45TlnxjlzBH9LaaSZvxWC37dQ
7Mp5GwQ/4+zlwgB7BN/p5wT+i44I/vcAbu9Lbgj+pZoTL4I8Efw1K1rbLnsj
+AkMDIeuBCD4J9Z/sbgeheDP4LundicPwbc8s4Hp2TQEX2ZR9a45MxF8hgq3
ouA5SOYp33l4YCGCH1bNfnD2GgS/SCuuPvAQkvs6uP/seYvgK7imfZ3s8gTO
NzUxnbjlGYJ//1PvycWtT+H8N8aBrZJGz+B8tde6rxgvI/hHVEovFTQ+h/P7
r1xNDlJ5Aee/Dz4wkekIgr8pVNTZsvAlnL/4bPPcR0KvEOF9PKZa6BCC/2Di
/q8Cea/h/G8XrSWb+N7A+QVTlA5U7kHwxc8qCTyJewvnB19d80fmH4L/KX5h
zp1V7+D8/QnrW/l83sP5u87neN/zQ/C32WkJrgtE8NfILJ3jG47gz7oxa3NP
EoJfGtD2kKsSwdd2iLVlX4bgq62XYr6+AsFXkrtxYtlqBF/iT1CI20YEn22H
R3brHgT/ob7JTObLCP6deR/jLl9F8G/wrldZfAPBP/dac4PTPQR/z3L5440v
EfwdYnd7At8g+JtbZwUpvkfwVyWL3jvwBcFfeunS4gnfEfwFjhMyE34h+HM2
+Oob/EXwp8tzf/3/H8EHALIZ/Wo=
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {0., 100.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.48194303109375*^9, 3.481943200203125*^9, {3.481943697421875*^9, 
   3.48194370659375*^9}, 3.481943842828125*^9, 3.481952444765625*^9, 
   3.48195374153125*^9, 3.6410988524483395`*^9, 3.6410999372638497`*^9, 
   3.6411011944394283`*^9, 3.641101626143886*^9, 3.6416467082878666`*^9, 
   3.6416476117123985`*^9, {3.641693569243251*^9, 3.6416936130869045`*^9}, 
   3.641694262585924*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", 
   RowBox[{"a", ".", "\[IndentingNewLine]", 
    StyleBox["am",
     FontColor->GrayLevel[0]]}], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["linken",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["Rand",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["wird",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["die",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["Temperatur",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["auf",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["dem",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["Wert",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["TRand",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["festgehalten",
    FontColor->GrayLevel[0]]}], 
  StyleBox[" ",
   FontColor->GrayLevel[0]], 
  StyleBox["*)",
   FontColor->GrayLevel[0]]}]], "Input",
 CellChangeTimes->{{3.419316354171875*^9, 3.419316394046875*^9}, {
   3.4819432625*^9, 3.48194327034375*^9}, 3.64164625902099*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"randbedingungLinks", "=", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"0", ",", "t"}], "]"}], 
    StyleBox["\[Equal]",
     FontColor->RGBColor[1, 0, 0]], " ", "TRand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.48194243425*^9, 3.48194243809375*^9}, 
   3.641646263067871*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"2", 
   RowBox[{"b", ".", "\[IndentingNewLine]", " ", 
    StyleBox["am",
     FontColor->GrayLevel[0]]}], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["rechten",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["Rand",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["wird",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["die",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["Temperatur",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["auf",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["dem",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["Wert",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["TRand",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"festgehalten", ":"}],
    FontColor->GrayLevel[0]]}], "*)"}]], "Input",
 CellChangeTimes->{{3.4193164343125*^9, 3.4193164413125*^9}, 
   3.6416462664897547`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"randbedingungRechts", "=", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"zn", ",", "t"}], "]"}], 
    StyleBox["\[Equal]",
     FontColor->RGBColor[1, 0, 0]], " ", "TRand"}]}], ";"}]], "Input",
 CellChangeTimes->{3.641646273880402*^9}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"alle", " ", "Gleichungen", " ", 
    RowBox[{"zusammen", ":"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.419316554359375*^9, 3.419316554890625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gl", "=", " ", 
  RowBox[{"{", 
   RowBox[{
   "dgl", ",", "anfangsbedingung", ",", " ", "randbedingungLinks", " ", ",", 
    "  ", "randbedingungRechts"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["T", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"0", ",", "1"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"z", ",", "t"}], "]"}], "\[Equal]", 
    FractionBox[
     RowBox[{
      SuperscriptBox["T", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"z", ",", "t"}], "]"}], "260000"]}], ",", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "0"}], "]"}], "\[Equal]", 
    RowBox[{"100", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"UnitStep", "[", 
         RowBox[{
          RowBox[{"-", "0.6`"}], "+", "z"}], "]"}]}], "+", 
       RowBox[{"UnitStep", "[", 
        RowBox[{
         RowBox[{"-", "0.4`"}], "+", "z"}], "]"}]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"1", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{3.41578011415625*^9, 3.41594467765625*^9, 
  3.419318052796875*^9, 3.419319225484375*^9, 3.4193197730625*^9, 
  3.419320441234375*^9, 3.419321828765625*^9, 3.419321886171875*^9, 
  3.419331862796875*^9, 3.4193328935*^9, 3.419334335890625*^9, 
  3.419356115421875*^9, 3.447385488984375*^9, 3.447387212796875*^9, 
  3.44738804871875*^9, 3.4473884218125*^9, 3.447388977828125*^9, 
  3.44755660884375*^9, 3.481943004609375*^9, 3.48194327675*^9, 
  3.481943706640625*^9, 3.4819438429375*^9, 3.48195374175*^9, 
  3.6410988529170923`*^9, 3.6410999373732214`*^9, 3.6411011945488024`*^9, 
  3.641101626581388*^9, 3.641646708787868*^9, 3.6416476118061495`*^9, 
  3.641694263132799*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n\n",
 StyleBox["B) Die Berechnung der L\[ODoubleDot]sung\n", "Section"]
}], "Text",
 CellChangeTimes->{{3.419316484953125*^9, 3.419316505078125*^9}, {
  3.419316549109375*^9, 3.419316583703125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"alle", " ", 
      RowBox[{"Gl", ".", " ", "werden"}], " ", "dem", " ", 
      StyleBox["Mathematica",
       FontColor->RGBColor[1, 0, 0]]}], 
     StyleBox["-",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], 
     RowBox[{
      StyleBox["L\[ODoubleDot]sungsbefehl",
       FontColor->RGBColor[1, 0, 0]], " ", "\[UDoubleDot]bergeben"}]}], ";", 
    " ", "\[IndentingNewLine]", "   ", 
    RowBox[{
     StyleBox["DSolve",
      FontColor->RGBColor[1, 0, 0]], " ", "l\[ODoubleDot]st", " ", 
     "Differentialgleichungen", " ", 
     RowBox[{
      StyleBox["exakt",
       FontColor->RGBColor[1, 0, 0]], "!"}]}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.41931658921875*^9, 3.4193166030625*^9}, {
  3.419316637921875*^9, 3.419316662609375*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ls", " ", "=", " ", 
  RowBox[{
   StyleBox["DSolve",
    FontColor->RGBColor[1, 0, 0]], "[", " ", 
   RowBox[{"gl", ",", 
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "t"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["T", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"z", ",", "t"}], "]"}], "\[Equal]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["T", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"z", ",", "t"}], "]"}], "260000"]}], ",", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"z", ",", "0"}], "]"}], "\[Equal]", 
      RowBox[{"100", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"UnitStep", "[", 
           RowBox[{
            RowBox[{"-", "0.6`"}], "+", "z"}], "]"}]}], "+", 
         RowBox[{"UnitStep", "[", 
          RowBox[{
           RowBox[{"-", "0.4`"}], "+", "z"}], "]"}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"0", ",", "t"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"T", "[", 
       RowBox[{"1", ",", "t"}], "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
   RowBox[{"T", "[", 
    RowBox[{"z", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "t"}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.415780114796875*^9, 3.415944677875*^9, 
  3.419318053140625*^9, 3.419319225515625*^9, 3.41931977309375*^9, 
  3.419320441265625*^9, 3.419321829234375*^9, 3.41932188628125*^9, 
  3.41933186296875*^9, 3.41933289353125*^9, 3.419334335953125*^9, 
  3.419356115625*^9, 3.447385489265625*^9, 3.447387212828125*^9, 
  3.447388048765625*^9, 3.447388421859375*^9, 3.447388977859375*^9, 
  3.447556609078125*^9, 3.481943287921875*^9, 3.48194370678125*^9, 
  3.48194384309375*^9, 3.48195374196875*^9, 3.641098853182717*^9, 
  3.6410999374044733`*^9, 3.641101194595676*^9, 3.6411016266595163`*^9, 
  3.6416467089753685`*^9, 3.6416476118842745`*^9, 3.641694263242173*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"aus", " ", "den", " ", 
     RowBox[{"o", ".", "g", ".", " ", "Gr\[UDoubleDot]nden"}], " ", "kann", 
     " ", "Mathematica", " ", "dieses", " ", "Problen", " ", "nicht", " ", 
     "exakt", " ", "l\[ODoubleDot]sen"}], ";", " ", "\[IndentingNewLine]", 
    "   ", 
    RowBox[{"also", " ", "ist", " ", "eine", " ", 
     StyleBox["numerische",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox[" ",
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["Behandlung",
      FontColor->RGBColor[1, 0, 0]], " ", "erforderlich"}], ";", " ", 
    "\[IndentingNewLine]", "   ", 
    RowBox[{
     StyleBox["N",
      FontSize->24,
      FontColor->RGBColor[1, 0, 0]], 
     StyleBox["DSolve",
      FontColor->RGBColor[1, 0, 0]], " ", "ermittelt", " ", "numerisch", " ", 
     "eine", " ", "approxiamtive", " ", "L\[ODoubleDot]sung", " ", "der", 
     "  ", "\[IndentingNewLine]", "  ", "Differentialgleichung"}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.419316685015625*^9, 3.419316686171875*^9}, {
  3.419321415765625*^9, 3.419321515640625*^9}, {3.6410985204943323`*^9, 
  3.641098521603711*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Anfangs", "-", " ", 
     RowBox[{
     "und", " ", "Endezeit", " ", "des", " ", "Simulationsintervalls"}]}], 
    ",", " ", 
    RowBox[{"in", " ", 
     RowBox[{"Sekunden", ":"}]}]}], " ", "*)"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t0", "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tn", "=", "1000"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ls", " ", "=", " ", 
  RowBox[{
   StyleBox["NDSolve",
    FontColor->RGBColor[1, 0, 0]], "[", " ", 
   RowBox[{"gl", ",", 
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "mxsst"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using maximum number of grid points \
\[NoBreak]\\!\\(10000\\)\[NoBreak] allowed by the MaxPoints or MinStepSize \
options for independent variable \[NoBreak]\\!\\(z\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/NDSolve/mxsst\\\", \
ButtonNote -> \\\"NDSolve::mxsst\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.41578011584375*^9, 3.41594467815625*^9, 
  3.41931805384375*^9, 3.419319225546875*^9, 3.419319773140625*^9, 
  3.4193204413125*^9, 3.4193218295625*^9, 3.419321886546875*^9, 
  3.419331863265625*^9, 3.4193328935625*^9, 3.41933433703125*^9, 
  3.4193561161875*^9, 3.447385489921875*^9, 3.447387212859375*^9, 
  3.4473880488125*^9, 3.44738842190625*^9, 3.44738897790625*^9, 
  3.44755660975*^9, 3.481943326390625*^9, 3.4819437069375*^9, 
  3.48194384378125*^9, 3.481953742484375*^9, 3.6410988537139683`*^9, 
  3.6410999375919733`*^9, 3.641101194783177*^9, 3.641101627003266*^9, 
  3.6416467098972473`*^9, 3.641647612165525*^9, 3.6416942635859222`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], "\[Rule]", 
    RowBox[{
     TagBox[
      TemplateBox[{RowBox[{
          StyleBox[
           TagBox["InterpolatingFunction", "SummaryHead"], 
           "NonInterpretableSummary"], 
          StyleBox["[", "NonInterpretableSummary"], 
          DynamicModuleBox[{Typeset`open$$ = False}, 
           PanelBox[
            PaneSelectorBox[{False -> GridBox[{{
                  PaneBox[
                   ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                   Alignment -> {Center, Center}, ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                   GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                   ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                  GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                   AutoDelete -> False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                   BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
                GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                BaselinePosition -> {1, 1}], True -> GridBox[{{
                  PaneBox[
                   ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                   Alignment -> {Center, Center}, ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                   GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                   ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                  GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                   AutoDelete -> False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                   BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
                GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                BaselinePosition -> {1, 1}]}, 
             Dynamic[Typeset`open$$], ImageSize -> Automatic], 
            BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
          StyleBox["]", "NonInterpretableSummary"]}]},
       "CopyTag",
       DisplayFunction->(#& ),
       InterpretationFunction->(
        "InterpolatingFunction[{{0., 1.}, {0., 1000.}}, <>]"& )],
      False,
      Editable->False,
      SelectWithContents->True,
      Selectable->False], "[", 
     RowBox[{"z", ",", "t"}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.415780117328125*^9, 3.415944678359375*^9, 
  3.419318054265625*^9, 3.4193192255625*^9, 3.419319773171875*^9, 
  3.41932044134375*^9, 3.419321830078125*^9, 3.419321886703125*^9, 
  3.419331863609375*^9, 3.419332893578125*^9, 3.419334337046875*^9, 
  3.41935611659375*^9, 3.447385490484375*^9, 3.447387212875*^9, 
  3.447388048828125*^9, 3.447388421921875*^9, 3.4473889779375*^9, 
  3.447556610203125*^9, 3.48194333134375*^9, 3.48194371546875*^9, 
  3.4819438523125*^9, 3.48195375696875*^9, 3.6410988595733595`*^9, 
  3.641099945013869*^9, 3.6411012030332017`*^9, 3.641101634768914*^9, 
  3.6416467194129004`*^9, 3.6416476220530057`*^9, 3.641694271460916*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"die", " ", "Aufbereitung", " ", "des", " ", 
    RowBox[{"Ergebnisses", " ", ":"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.419316793984375*^9, 3.41931680421875*^9}}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"lsf", "=", 
    RowBox[{"ls", "//", "Flatten"}]}], ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"TL", "[", 
    RowBox[{"z_", ",", "t_"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], "/.", "lsf"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}]], 
               GraphicsBox[{{
                  GrayLevel[0.6], 
                  AbsolutePointSize[5], 
                  PointBox[{1, 1}], 
                  PointBox[{2, 4}], 
                  PointBox[{3, 2}], 
                  PointBox[{4, 3}]}, {{}, {}, {
                   AbsoluteThickness[1], 
                   Opacity[1.], 
                   LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                  GrayLevel[0.7], 
                  Thickness[Tiny]], FrameTicks -> None, 
                ImageSize -> {Automatic, 
                  Dynamic[
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}]], 
               GraphicsBox[{{
                  GrayLevel[0.6], 
                  AbsolutePointSize[5], 
                  PointBox[{1, 1}], 
                  PointBox[{2, 4}], 
                  PointBox[{3, 2}], 
                  PointBox[{4, 3}]}, {{}, {}, {
                   AbsoluteThickness[1], 
                   Opacity[1.], 
                   LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                  GrayLevel[0.7], 
                  Thickness[Tiny]], FrameTicks -> None, 
                ImageSize -> {Automatic, 
                  Dynamic[
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->(
     "InterpolatingFunction[{{0., 1.}, {0., 1000.}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", 
  RowBox[{"z", ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.415780117390625*^9, 3.415944678390625*^9, 
  3.419318054328125*^9, 3.41931922559375*^9, 3.419319773203125*^9, 
  3.419320441375*^9, 3.419321830171875*^9, 3.419321886734375*^9, 
  3.419331863671875*^9, 3.419332893625*^9, 3.419334337125*^9, 
  3.419356116671875*^9, 3.447385490546875*^9, 3.44738721290625*^9, 
  3.447388048859375*^9, 3.44738842196875*^9, 3.44738897796875*^9, 
  3.44755661028125*^9, 3.481943338265625*^9, 3.481943715546875*^9, 
  3.48194385278125*^9, 3.481953757203125*^9, 3.64109886001086*^9, 
  3.6410999451857443`*^9, 3.6411012032675776`*^9, 3.641101635315792*^9, 
  3.641646719834777*^9, 3.641647622728057*^9, 3.6416942719452887`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"die", " ", 
    RowBox[{"Gesamtsicht", ":"}]}], " ", "*)"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"TL", "[", 
    RowBox[{"z", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Axiale z- Richtung [m]\\t\>\"", ",", "\"\<\\tZeit [s]\>\"", ",", 
      "\"\<Temperatur [\[Degree]C]\\t\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.419318396421875*^9, {3.419320792703125*^9, 3.419320793328125*^9}, 
   3.419321799875*^9, 3.641098912495386*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0nXlcT9v3/5MIKTIkRIPmSMqQpvdRpIjmWUkiShMaKClDhQYqUoaSJGMD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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNnQf8V9P/x+/n7vtBSSRZDZGMFBIhLZSSWSKjNFA0pFRGhGTL3rJX9t4j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          "]], Polygon3DBox[CompressedData["
1:eJw1nHf8VvP7x89932d+aElFoUVlVFbLakmFoikqSoWsJEoipGUXMiJaIomo
jHaZZW8yi2jK+JqF3+vpdX5/nMd9Xe91zn3O+7zf1/W6Xtepfe6QrpcWgyCo
GgVBqN8X4iCYVgqCQZIfV8HL0h+RfqH0A6X/LwmCfQtBcJnaH1IWBHupfowG
uFv1FSWHWRD8Iv1I6U3SIDhJeg/J1dS3oPZTpb8q/ULpNaQ/qj6TNH5jle3S
7+Ma/zDJf0j+RG3bSO8vfaXaDVH71SrrJ31/9Q+ll1f5aJ3vZl1TOclN1X6A
6h9T/aGqn6dr6Kv68/g/kh9Um/Eae53K2kiuo/FOl36i+u+r+nnq31Bt/1TZ
p6qbpDZXS95DZVv0u1T6Q/rtKf1X3YN91OYE6Zeo/wj1X6b+16nuKJ3/e9Ud
reNa1ZepvqHk31T+k+rVNdgs+VUJb6tuu/RXJE9TmzclX6a6Wrr+k3S+9brW
g1X2m8a5UuPPk7xB5cNVf41+W6m8uspGSX5M19Bb7Q/SmLMkH6XxrlH9udKr
Sa6ro4v0k6UfqPrZ6nOL9IPUf5bk13XMlX6Z9HWSJ/MMNV5H/q/O/aeusY/0
0er/h+RKanOD9BOkj5Z+oMbvqv6nSq+vvmtUP0v6Fer/tP7TPtJvU/tZ0p9T
+9Ok/yS9nvQJ1OscTSVPkly/zNfzuPo31HhrJS/QmMPV/ia1CfPrv1X1iepn
MlcZX3p9rle/Z0kv6reb9Ic1Zkv12ST5OJWfqfFr6nztpN+rugbSn1L5PWrf
VWWVVXaw6tty7Sq/SPXTpFeV/o3avKn/eqXG+0vnHqDjFMljMl8/L9Nfkv/V
799S99LxFfNb49xV8pip6k5Rm4GSa0tONP4bqp+n+pEqa6SyRdLvL/kdYM4/
xjOR3lL6FOnzpd8t/WjpT0jumvneLFHdUI13g/RG0v9Smz8lH0u95HdUdqTk
R/R/6kj+SWXvSR8s/UHpn2isK9W/h35/1/1upbJYY36kZ7ZC//Vf6QXJ96r+
RvWtIf0eyQ9ojNckX6S2+6n/O/l87SH9V9UtV5uH8/nVQGXXqKym5J0q+13y
3bqHHXW+01kD1PcMtd8l/UTGV/tp0ieobXvp90tvkvhZPavyS3S+VfqdUfL8
X8G5WK9U/73K3uJd1FFL+o/S/8h8/6ZIrqD28yT/o/90vs43Rvrfkh/Kz9dc
ffaJ/L61lP699G3MJ43RTPJkyRfo/LWln6b6NupfRf/lOZ3/6vxZfqu6bur/
m8ZvorI7VHYQ74f0+3gfJf+pPh9IP4I5Rl+VHa/xpqp+pOTa3GPV3yO9luTK
mde+43Tsob5nqc949b1PdeeV+XnVVPu9WRMln6P62yS/r/phvF/SH5DeQdfy
M/NZ5c11vtdV9pnKhkk/SvrL0j+V/kY+PzpK/kXtKzKfdO5jdGQ6/z86Jkpu
oSOVfDVtGEtj/Cb5OpUdoOuprLKPNdYIjX+s6u5X+7d1fS+qbILqWmj87Wo/
VPVHqP5u1b+p+gGqv0v1J0o+Qtf/tX4barzLVP+V5MvUvrHaL1ObD0Ov96+r
for0ByQfoP5HSZ4rebD6L5Y+WHpdtd2o892o62uk9g1U9rXq5uo4VPLvGvNj
9i7pd0pvq/Y7pb+c388TpP8g/RKN20Bt56vsLZVNVFlvydUlF3W+D3WNNTT+
b8xfya/9//9R/Y+Z36cx6r+aNVXyTrVpL7mD2vwg+WUdsfSzpe+X7x+J9Euk
15M+SH2qq/8d0pdJ/1z/51HVvyi9oeTP1b6+9Lo8E/Zw9gzpPXX/bpN+ua7h
HNUVdV0lHZ+pzyOq7676TyUPUPsqGv9G6efGrp+t+tXqs17yWB1HSD9c+kb1
vynzflxL1xLr/98o/XiWR+m7JF+gMfbTeBM03vmSP1H/merfVfr7ki9kzqv+
IfV5WX0aSX9C9Q+wn0p+Uuc4lutV3Wcab6n00axt0r+Tvln/6Ri1b8EaILm8
yvbWeIer/1Mav5z061W3WO376fq+U5vman+F6jdJ3lP1e6l9I+lPqn3FxHvL
RN5dtV+rsrtUV0PX0kb6Tapfo/qDpfeQfoB+79N4z2BbabznVT9KcmP176L6
s1VfXuMPVdmTKvuUPVTtL9WYn7DXqj5j/1b9o6pfqf43Sm4meYuubYX0MdKb
St8s/VnpV/GspX8j/VL1P4T5oPFe13jv6Kiq8T9gP1Kbd6VXk76e9YY9UP3b
cC3qd2GZ//+Qou/RHsxv7Lmi58jFkjO1u0J6M40/SmO9pf4zVXcatqLqi4yj
+uHsiTxrlbXT9VRV+x/VtrruXzvJY9S3qc5X4L0s+vlcpbJFanOWuu6r8Tao
79PST5FeXvqX0p+R3oX9VfpX0p/QeBcVveYWWWtU1l7nq8l6rrb7Sz9J+v7S
/5K+UMeZrO3q/zX/T312qO5s6Z2xD1TWqeQ1brTqytgXNf449m/Ja7CbpZ8m
vZL6jFf7UyVXkPyP5Ak6ukuvinGt8e7QGFdh76nfCdJ/l/62+r+r6ivYL9T+
ltyWOq3M7/s66VtV/xLva+LxpmObqL67+mxjP5PeUXqsa7pc441Xn0jy2Mz2
zR6q3y15HP9f+p7YJdi36j9SbffR8YvGfkLnWCh5i9rsCG0/n63x6qtsruSj
8/u9UGNfrPM1UFkn1U1QvxbSj1T5IrWfprIjJK9S+7Fq31xjbdX5vlf7Z1X/
nsoOl/ydjoWsZ2q/QfILan8NddhGrBcao5/u/1rmS+T9MZK8mT1Mbd/DBlf/
h1W2SvIYte+r9t+q/jzuF+tPyXv092r/s/q/pvbPq/017FXMN9UfKn285KfU
5ji1LbF2qu9D0veR/p3adND1PKg+o7hXGrtlmfe7b9m/1eYYyfVY79X2G/YE
6SdrzI2qv1L6DPUZqrL/qX8PHSdLXqDxT1ZdOZ3vC549dqb6H6n6myTfzPsj
/Ra1OU5tlmmMX/L+t0reojGqqe461Z3M/GJfV/vjdM4tqt+KTyJ5gdr3kdxE
9c9JHyT9TtXfLn1obt8UsEEz76Wpju8S+z8jVb9cfZrHfj9+Ut3pOi6QPFjH
TskL1X+U2j+beS+Yo7Hb6XpClVWSfo3GriP9Pe5xyT7Su5LvVfsXJPdT/d6q
P0dllfBPdIzQGMN13MC5Sn4+HXVsKPqetlDdQOn74G/ouFr6SB3jCr5n3L++
2JySv5O8l8YfqetZiX2r81WSfqD0TtIfzPejWonfj/ty+71ZYvt8bv7+HprY
n52Rv08v5v7NbB1H6NxjpZ9b8px7WPLfuW2OzY/NUZk9peA9ciNrr46K0ptI
/xe7WGN+qN9A5/lX8p2p9/86ub/dV2PsyVzEp1LZxdLrlWxz3sBeJ32F2q8s
2sf5QGXVJffh/JKnaNwveRd0/bU1XqqyUsE+JPbsHZltybYqP1z1t2e27VpL
byz9NunNeXekN5J+iK6vs/SJnJv3QePXln659MOk36r2TaQfj50mvbeuKSl5
DR7KfoRPzn/n3qh+P/xNtb9Rdc2kn8n8YD5IbyJ9iNo1LNmHHa+yu3S+z/V/
Nunaa6r+cOl9pD+Sr7/7ST9B+t2h/Z+mkd91fO5nJa/R+W7X+bupvpz6X6L2
C5ib0vcss7+9RPoH0itIv0r6CmxX6RXZr9T/YI11tMZKpc+WfqbGq6n6SHqH
zP7Osth4RTv1H6b+C3J76NjI7/rGgte85pFtjYEa4xDpF6v9U2r/juQ9yowr
8O48iT8T24fCl3pM+qux7Wbs57El+wDcd+4/e3gT1R2WGLuYma//PFee76aC
15eWOm5X/dMl+wix6ouqe1rHesmRjgJrbcFr4tbQ/vRfrEFqv1Vl5STfgM0u
fY/E/taNoe3/CuqfFWxjb4hsV2Nf76GySthnkdeeQ1T/P9X9nGMTN+t3eux5
yfwcpfrW+Fwa/3HVvyG5TPenv/Tp0l+Vnkk/TvpF0p/I7e8qibGmW0P7m9US
26q3hfYH+0fGSgbi00f2724v+ZrZPypGxnJeLXh/HCb92oJtcPCbjbrGJeBE
GrO/6oezp0r+VuUjdP4vWX9V/7TKerPmpfYV1+Nnqf772OvVKvYv8JDU2NRX
sef/17HfB2ysapL/wr+RPkR6feZPZv8BX/wdbFv2JF1bJ+nvS4+x69V2NL6c
9I9V/kzJz/yj2Os1eOC1qn9d9ftm9nfBlt7G3kv8fMdgO0r/VPofPO/Q/nVl
bCzpt4TGzxh/ofofq//woeSXM79f/HfW41czr8f//VfpP2BTlWz/b2ctzf2t
tbk92TfxXvhi7q9ekPuvb+b4wo/q86L6v62yoSobk/hZ7GAf0/jbsElUvw77
FRta+sr8eewveW3musaSz1D7/+n3FdV/qrLh/Cfsm5KfaU/pr6n92nys/dX+
D8ZQ/YGB5+srmdcP5kIV7D2VvVayvfMrz1xzpoHkd7ApsDkS40XjQuMxrVPb
Y/PU7iPpd6j+E9VvzPGV26V/LH1DaDy1Kpijxh8svTrrlfQfVP9rvv9u4J2i
f2D88VKN/zP7q+R9VT8o8//9Jfb/OTfz/dwZ+/mMS4xPfqH2VaXfLf0L7KPQ
eOVGjfc0/ov0A6T3BNOQ3lZjXKz/cGYc/DcB8QGGgEdkfh5bY9+fGxLfz/W5
PTBe+lvSv5ReDbxZ+n6sB6Hx4esyrxesG+CFl+j3yoJ9vuqR/ZX3eR4qm65r
u5I5W7LNcZHkf3hPSsakuWcVc3vvJskfqr689CrSx0v/QPowHXOld5deXucb
Kv2jkjHpC/GVdHwgvWfk/WxdZiwL/4T9PIuMt2HDlkkerbIwl+up/bfq+2vg
Pfv9yPghWMk/+E/SR2Vef1mH8T95rjzfwaxZYFeRsWgwH/C5Lqqfo/qWKlsX
Gl/FfwUjPQF/KfHaCgZ8PNeue9RNbWeo/0ep8Q+wCO459x57cyl1atM3tT2P
LYlNuRn/gDkd28ZHr6PjjqL3WPbal3RMKrrsRckH4T9LvpP1U/JyHTdLnqhj
meQPU2M50/PrGa1reKhoG/Ri6b3Y82PjVZMTt+fawdRulL4XmASyjsWSq6Ye
e4KOpfhbOsYV3eZZye/qmFb0OTjXvTqeLxrjxT+bkdgW3hP/j71U5z9M55+n
sq9Vf21q7AufEd+xUua1r7P0WpKrxLbTsNfACtkflpa8Z/TOvOaw9iwgZiH9
cB0v6VyPgwlK/ib1f+Ud+zY13jC3aJ/istSYNnYf9t926dMTy9iE21L3f6Zo
H437xft6TsFljDdRZXOKxnzAc8CPwIbAiL6U3F3j1439TLi/l+b+PnsSthp4
yJSin+mrzCV8aOYDe0pivHx5wT4vvu85qu8a2+domtp/P0RyBY2Xarwd6Kz3
ar8zv/9gzexJ7E0P6nhD+pDc/vtVbd5Q2yUao73ke8Ag2Xt4hvhe4FWB2/yW
Go/hXBXZ4zXWWRqjdew2tB0gfTh2Vcnxk9WJfX98SHzJZqmxpZeYk/jyiWNL
96hsoOQfU9ct0jW0SW3vdil4jr0nubGOVwKv2azdw/GJA8eUiC0dC4Yhec+i
8YcfUt8L9gT2BvZk9mbiPy9knr/PBbapGb+pyhZLvx+MJp+PNbGd8YFz/Kty
yRgX+M781LEWfLAy7CFsqtiYGdhZlDnW0lp6dcnnqn5wnGPQ6nu8jrqqq6Oj
iupvkj5CdSdKrwH2lrnuFuZk6nvOvU/BbKQ/pKNWwZgN2A3xK+49MQtiF8y3
50u2oXpJr8v6IHmy+r+c/9/rpI/W0SRzPHIIawV2ZuZ4y8ySbXBs8Q90nFMy
xnCw6l5PjTUTwyKW9ab060sek/s3M7Ftiw2ELbQ5se+MD90wf19HSD4LG1d9
T83sG+IjnqS2l5XZT6Ssk+o6g6+UjFnUl/4V+FDJY/C+10sc67lceiPp2xPL
+PiNMx/I+P37a9zWiW1BbEL2oyOldw78HxtkxlfwpfGpm6eOr04v2UfBVyHG
RazrPultpO9MLLfS/b0ldTzs3pJjZK1Vf77al4vs47J/EHMk9kIM5mR8xdzf
IGbaHtsq8bsxTvoxmePDD5bsY+Nrz8z3d2zY5nl7fBl8mt744jrfztB4GM+L
GAd+Dm1aSP8Te5B7CyaTOj40teQY2omZY0TEimjTLrP9/Wz+PrwguZXav1Gy
zQC+eQHXgM2k+pLkboljc8ToumSOoeAn4S91zxx/e4JnV3B88s3EddjYPVR3
OetzZHu7G7ZB5ngrsc1mKj8lcaydmHtn1Z2mY07JayJ4JvFlfD360BefAt+C
d6CP9KsT27LYtGdjyyX2FcFcuuX1K0r2McBGrlD/NjrvtMDXB+aO7Y0N3l/6
hWq/uGSb9wzp1yeO771Vsv2Efb26ZBsOWw77irr1zGHJA3S8LPklnqHaXo1P
H7lsYGbMD1sYm5j97vzM8Rnu+WDeZfV5u2Sb6lLpk6S/WrKNiq06SuPNiN2H
vpyDc2GzYruCV2Kbgalclttvn0h+XmXDVHdFYluQsiuwRVNj5XAC4AYQD/m4
5DnB3Bie+b9xTVwbMeDfNR9/CRwbpp6xP83/P/jn10VjVn/zX6Xfyn4ROn7W
RfoI1u7Q8a6Z7Gc6/5OR8dyR0j+U3iw2vvdQ5PVmPZib5L/U72PJq3U8nuv4
Y5+yp0v/Gb+sYB8VX/UncPOC19hDpP8P3LxgHwRfZHpkrgRtFklumxobroUM
/hkZSwx0lCTvwg4v+Bqejnx97HWVCo6XgrdsKHi9AcsDAwUL5ZyLI8esiF1t
yPGY+3TMKdgG/iM0hguWO0Nld/N+hH5X2cOIB7E+Dlfdpao7Xtf3gK73dOyh
HJ99jfUc+zWPzwxV+8lqP5a1kvh25HjNlBzDGqYx+0rureNryQ+obL7kM3S+
SZKn6nhcek/pt3M/Y8835jPzegfrhup3acy/1f8u8A58jfz6l+v4ivVQ+grJ
V6lN/4JtsG9D2xNDwS/BOfDvpLfV9e+IHC+ownUzd9XmIsmdImOvk3LMjPNx
r2bpuFfyzMhYd1MdJ4DJZd6rwH0HabzrM/sCc2LHr1nD8QXgUrC2w6doEBgD
oQ18HfASOAhwEbgH3AvsX+Jx3CPuFZg++D/4UK+S7U+wyVtU373kGB/x7gMi
x+/ZUxZIvzayrXxt0XyeVpn3GngZxKPAeMF6hxYd37hJejfpU4uOh+8OzdXh
nOBRYMhgyecVHc/fKPkR3YuZOqZE5j21DcyhIP4Pfjux5Jg/XINZqn8B/LLg
mPOQ1Pj70sj4difpK5nfatte+rTIXJ0Xc5+dPZ29/frQ8YPZkW3TrQXzXx7R
sVTyDwXHB+GQwCU5V/JJan+Fxm1a8j3j3u0bmfvA9cFNmKxjFGu1jj9DY/is
D/wH8GfWDdYP2tyJHcc9K/od4l2qHFtmD/xM8tTYezMcKeLlxB/ABolJEJs4
DB9T419TMMbbJHJs7zrpV0qeHPn6d+Xzm/mOvI3zqf985geuLP5f5BgE/uM/
Bcdv6kauIyYFx6wcNqr0tZHjYbx/xH6JYRLL5P0k1kQMk1jmSh1fB44JERta
p6NC0feYe02ckXgjZa/n7Tn3dumngs1EPh/PiGdFjIVYy95F8xPeiizjwzwa
Oe5F/KtS0fyENyLLywqOgbCe6S/8F/Mn9g/+f6TkNsxxne/jyPEbYr7EftHr
FB2z2aQ2m0u27Q8qGn/9gvlVNOcJvtYvJes7i+ZPgdfSFkw/kfwl73zRbWiL
Xi8wZwLuBHhs46I5anfF5pgxfxvn+OzukrkoXDPxin+kH836WjR/5ZvIOhwa
+EffRua2EEMnlo7erOg29L0g8t7BfyS+Df5NvI+YDbEbOEat8H+Kjl+Fsd91
SIpHh8bEwcbrqf1TkrdF5gadmK+RZSprXXRMBU7X1si2KzYsdm0WWgeTgk9U
RUdnydUKjqn+HJkr1iXfQw5SWT/JdVQ/X/LBOgYUHYMhXj+I/Vx113Eezc9W
kflXcGCIkXB9rN+ck3MfwHpYdAyEeH7bxHw6eHWnl/n87F/Yr3uHjiMQTzig
YE4jHATiA89K7qr2P0Vuiz2LXUsMmlj0KUXHS4mnw9UgBk8s/l+VXVB0jJ14
fKJjWNExfOLZpdj3ekHJ8Tnu//WBY8rElndH5irAkYIrBf+PeDUcULigFWhf
NCcQPij8ALgdxMyJne+KfP/g9K3Lx2Ntpox7y3/m/4ARwtfbM/ZecDX3MPSB
TMxvWV4P1wUOKFzQPWLXgzmDZ3eIjK/jH+4r/dbYviAcmD0i+xD4fsSZ8S1u
zuz79ovNByFeRbwXDgZcDOJvcB/hbMDdIF4JV6xy3gfOAtwF/GX4Mbtj24pg
jH9LvlzHkSXvWexdxyTmH8wLzT/CPiOe/2xufxUS265gjHByTgVzUf2i0PwW
fHKeH88RX71xZP+L+8m9hleIb4WPBZ/34MhcCDixf7EWROZCMCd/i+xz4Hss
DM1XA6+FrwCHEi4lHA+4HjVK5uvAGQIfOq5kfhrrI9xCOF1wu8BMiKf0i4yl
XBW7LfggOCGYMNgwawR8G+rhQsB5g/t2XuxzMaeYW8R74TbAcYLrBL4MVweO
IFzB02Nzj+Egd8l1fLfyPJPIHKoOqt+tsl6qOzo1/xQeal9dX43IdWDIYMlg
UvD14O2BVYEhMH+YR2eXeQ1nLYcj2T32fkg8kHeMd+3IyNyJ89RmXGx7k3gp
nKwG0rtF5srCoaonvV1qew27bRv+Xx4vfD403wd7Ce4M7wjv/umRubwPs0ap
/ymR40X3FB3P6BvZv+qHjcneG9m/A18EZ+yu8a/V+EtD89dOSm3vYPf8JL1+
YnvzodD8ml6J+UerQvPVwLQW5b7IevCzyFwxMBtwszMS85NWhubLHRb6/4DB
wAeuGDr+Xll9pklumJhrPCs0Hwf7DG4m6ydreaPEfInZoflANULHe6uz30ru
CL4h/ZnQ/Cf8mx3Sn8v9DXgvJwWO0cMfxZ7CV1nMPcS+ShyPvDM0n6x6Yj76
XaH5INgn8N9fL9h+qR3ZP+paNB+8ttofo/ZTQ/M56iTmpz0Qmq/UGfyG6wnN
14pCx6fhwMPnZf7tVTDnmvlJzJ7YPZwSbMzBkbE39nT4jrwfcO/h0MGlm5MZ
a4GnfmmZ3/dBgTn9S2LPR7jY4FFwF1gviB+DAcGX7ZgZu4FHC9++Z2bfn7gX
fGDyAYingkm8EhszANsgtgeWAMYA1vBObKwD+xSuIzED7M8R+o+Li/ap4Jux
PhNLA2MgBgo/BS4PmHvT2HxouFxgKm+y12TGXpDhN4+OjS3CwVodGdMG24aH
RGwAjgRcCTjx8NV5H4jlgSH8mr9/qwJjIptjr4f9A2NGi6W3zYwdwcOG78Q7
zLuMT98+ts2N7Y3PCp9zfmbshbjiVWV+34gngpEQzzwrM9ZPnBj+Pu8reA2Y
JjHeXbGxBjCHP2PHd1nvKaMOjIP4InFGsA/iTB/keAR7Tb/M2A1xVOKdrA/E
P4kxfBP7/SQ2is+K74p/AfcYzi/cX+J2xBaIAX2Obx56rcAHgQ88IHQs5hTV
fxQ6BkCsBR4zsYEvUscKDo3Nf4SvBLeXmEL92DEA+MvwmIkNnBMaq+6oNu9L
Pjf0WgbHA/4uHNW6ut4dRcew4X/At4TjC9cX/svtBXNu4d5iv88KjEFfxPoX
Gvturzbvhcao4ZPCKwW7Zj+GSw3HGa4z9vvqwJxjuMf4D3A34VDCpbxcY8wv
GgOAP3l+6NgMezr8aPwruKrEsKpKPja270sOCfypP4gBSG8rubfOvyt1fgd5
Hn2knxg7VgHHF74fmBjY2G+xY0NbQvcnh4RcklYqX1M0Bx++MDEL+M7kthDL
ICbF9XGdxKrguRCLa80aFtomwjYCPwRHPCO0DqcI/nKv0LG5tmr/tuTqsfEU
2tAW/jDc9Ln5M6ce7jMxoP3yPXLPyPsxeyf/GR46fHTuBXtu59h8V/biXZof
pxVtk98v/XfW+6JzAsgNuEtHh6I5UXCj7gVjL7rNlNQxXmK9PaXPJF6UWj5D
R8vE/D1se84xNTUHFy4unFHiTe2JBxTNeSRfCJv898j8W2z1R1R2VtE2Ozp8
H3wRyuakrqftmbnOOTk3GFyv1DY7PBz4ONjyF+r4seB3gneD64Xb3SO/fjio
cFGJ6RDvBJ+8tegcmtWpMQL8UPxRsAMwfbC2w3SUiE0l9tWxKT9MHA/DN+Ce
ce/AwDqr/6OBsbGHifEVjUH2SI35sS+yP4IFDkmMNeFD10jNAYQLyH+4KDWf
tF3Rz4hnRTzl3qI50G9IPl/H9oJjwMSC70mMhZGjRD7KiWXGILF/F2bmy+Lb
teE/Y6sllvHxbk2dY4a9V5A+MjVHDtwA/ID50SU1FvOZ6jeob6XE+SBwmuD3
w/+pHTgGD18dvD8ueI0Ff/4tsW2BjQG3bH5irhI2ArYC8ZUa0g/SOQ+MfH34
ktjMXC8cXfxKyn5ObE/BB6gC5pM4nrN3wRgm8Z2tiW0hbCK4iTsStyWGNjG1
fdQrsA1CPhaY536RY0RgofAr8d2OLngPnpOYiwIHCC7Q5alzOeB8DEvN/+jF
WLlOfDMrmuNfIXM8EkLQM9hgxKZS3+tXsHlSc1jBR8DEhuTjMxYc/VsS27ON
Cx4Tvi3xcWKZ36vsXMkPJF4LyAkhNwSMB+4z+WRgPx0SY0vv8o6lvv/YVy3U
fkLqmCL7P3YA8S/u1/Gq+xybV/U38w4WXcb9Oyoxd32/gvOLWqTGHo7SEaX2
4U+KzOfFt38NfCA0pwxuGRwjcpngnME9gpME131GYK4SMWewIzAkrh8fitwf
Ykb4VktScw9qlZyvA2eHXEhiKnB54DSRizM1MNdpUWruwv4l59fAoYZLjQ2+
LLNPQC4ANja+AjYluQA3BLY1ucfcazjK5ONgE5MbQMwBW5kYBLk8cKiITeBz
HBP5mfHsiPeC9YDfjEvNSSJXjHcGrhIcMvLayG+DWwZn7IuSOb9wyeCgTYkd
MyWed3Zq7ggxT2KfxK9bxOZUEM8nnkJuHZybWZnnHHNvDft3Yk4ZuZnY5HDN
xobO5aoVmGsIRwfOIHMe7s6Y1FzCH7GXE3N6yAusH5jrQ04PHEQ4Bksyc6y2
h87vIr4Ox217yTFJ4r3Ex8FHwEmI1+GDk2uCD4VvPip1LBtOef/UHPBvAmOw
8K9ZY1lrt+ETpubPg/2CT3bM9wO4Ejvy9bQTNic2rPTa0mul7rtFx6DUmPP1
sXMSwaJPRQeLUn0l6RVTz2XmwIDU+WLMPWwgbCHyt5hbcAzgGoBpg1suy9/n
BxM/C3L+Tk2drwF2zRzvkJqjD28V/uoKjdWTPT1wzsIZvM+pY1ObVPZuYgwc
3ij8UbBxfEJyqSYH9hXxOVtGjlfgi+JjkhsFBxDfk5xaOLDk+LwoeZOOI0Jj
iOx3xNDgwI4PHFtbIbmNjknSe7Keqv740BxC3nd8XnK3iMnhC3dLnYv7Zn79
Z6bm5mETYBsMlL65YM4Q3KGnIudhsWezv8OZgwuIzU98Eo4euZBrA3P3uD+M
XVfHCYnXZ3Ipq+Tzlfu9UfKFqj8iNd+DuYiNB/+F/FW4uPvm95N8Ap7VmsD8
H/I34KaC4RKLWJr52WFzYXvBBydeoa7/8cs65OvV7MD7Oe8nzwZMGn5X79R7
MZg/6y9rKmtr68D7FzFGYo1/Bo7/EbfEdgDjB+vn/p0XeE9nbz8ndeySGMXm
/H1h7pATBf+DfBZ86165vcL5Wfvx4U/E1ki9FtSR/kXinBTwFTgVcCvI94Cr
e1vs+Bb5q+RCwLkHnyF+BhbURv2T0Hw89n7WM9Y18v+wDdrl9jj5G2AHrIfk
GxBnZK+GUwFesTzxWtskx2NfyuO7zDHm2tzM965OaH74tNT4W4PI/nmjyHPh
4sD4MsECbA1wjVKZ4y3w6S/Ix1iS4zXMeeb+Mfn7vTo0Hx8cGjyaNQa+H/Ya
z/bUyHz6YmZbGw4h62GZjvKBY5V1ia8k5huyprO23594bWdNZ20n34NYKTGP
gyU/ljg+yJrK2sqexd61JnS+QIXEaxOx4gOxVRPzuVmjWavvz8ynHxSa33mf
9OXSB4bml45NzO/CFz2W+HdmPijcXvIXmA9wI78LvD/MSsw/Zs1m7e6HTSv9
ldD5DJMyrwWsCfDDWRPQl4fOT7hI+pOBfZ2jy5zTQny1e+T8hnsixw6J9w+K
bF8zVw+NnO9AXJn4Mms4/uadmc/fKTR//67MtgQ2BfkFrCe3Fbxms3afn5hf
im92pPS7M9sa2BzkH2A/31nwnsDeQI4w8ZnbQ/NH78mcL3BW6PyWEYnvJ756
c/CYzM8HGwO+/JTM//fM0PkM5IdiK2IDg48/kjneiA+AL4Cdi73LGg/exn7E
3jQ538/IASMmBodqcWb+J7491/z/fE+wA3x4+IFcE9dGWb3UHHdwEPAQ+IT4
g8Q+wODx18gRJIYHR2MReGhq3x6O2+WJY+Z7RebkEUsnn+nXojFcsFzmEHMJ
fOMw6dckzo0Fkz00NT8UXxdMAf7pZdhggXNS9k/tj2I7winE34TfRqwKGxNb
85PEvjk+Ov4tnGi+5cCchSsNRxGuIhxqclfgSJ8dOf4PF5M5zdwGoyFXB3t7
c2AOG/4N7xDvEjG0LxPzC7cE5gzAP+Qd5l2Gf7Be9eXy9/fv3F7D3v4x8DVy
rZGOnYE5xB8lXh+wlcDE8ceTxN8FoQ/52vDltgaeA/DJZic+124dnyXmwPBu
sMdgj5ATQO49nGpyBf5NjeX8oOOo1PxHuBYP6rg1MZ+Be8097xOanw03Es4k
8ZN1qfHyrpHxNfiExOaJQcE3JCecOD1le6bOWQaPhpsB9wh+KL4FGAn8T95n
9to4MB8A3gX3EnuQfBTyh/E1wGThk5PvSS4iPht4I/E+8qEmqv0xYGeZnx3Y
N/GOZzLHQ/DR8dXhbMDdwGclHsE7zrsOHlM5t9ew3VjD8T/Kp+Zuz1H78xLz
mWnLmgFfmTWKtYo5Wy31N0+IE/LO7MY/Tc09+SO///fpOL/gmDv5l+wnYAWX
5vbrmsTxqxG5/cR+hm90bW4f4TNQR4yD3Kc+if879yCRvjZxfAj7i28R3Jw4
15MYEfnn5LiA84L3vpQ5/sXexh73b2L+Z7eiMQiwCPZDYq9gzuTywPnn2zD4
3/DRyWkpRrah8G/xt2tGznk9JLfvW8bmsMNlJ0bxX6xCY07P7O8Qaxmr9o9n
Hg+ckTk6O/cH4HGAITyc2f/qEBv/XZXbo6/F5uTBzeP9+yf0HsTeCn6AL0+c
48B8Dwwj74HsjXwT5/nY8Tm4kOz5DSP/Z/47HH+4/rw/+Cvw+eAOkqf1duw9
ixwvbBD2Mvibz8Tm08DVhDMDd4acXXK7wTzBPuFP7ZUZ0wbb7heYK8c3EfhG
CfYR30qAEwTvB/4PuVDwLe+P/T0Fni82B3Fu4t3YItjvxI74psG8zBwiuERw
hjcljrESawWDmpHZRoOLRL4kthvrIRg0e/6CzDkr5Dio+X/+JHscuRLkT7D3
YVNhFzGHCrk9DucNGx5bnvuJLcV+9WjmHAxyMbgf8AH55goxUmIkazLn7B0e
GdMD2yNnj++u9A/MjyVH7Mfc/wU7IqeMbzv0yecnOYZ8a4UcM3IPyfHj2wcD
A/ONyUkkN5w5AZ4ER5VYHjF/8tHJMSVXnBzTZvn84NtJcGhXZX6/60fOAedb
R+T4kLfyqvSnMufA/JcLEzjXg2/akGPKN2n41g02CrwdMEFsF2xQYkXEr7BN
uR+rY8fn4EqXyzFjbJInMrehLe8o+fTcLzgKA1T/WOb1g3efmDTfVyCniNyi
V1T2ZOb1gblDPHdh6hxbNhjys8m9xeYGCyc/EFucfIbjY/s8LXN7oUtkmwXb
Bnvg+cg+Kb4pNi48ODBKbF/Wm89j85vg+mIDkkOIzYdtyH7RLnIOA98WYT1u
H9lGwhbDXugV2YbCFiV/A1wffH95bu8siezDN8jX446RbT5sSWIg4OLg4+Rq
wEmEVwIGDRbdOrcZsWFqpsab4YIQr3qU9S8ztwf+zg2p90z2Tl4IvjcFpgm2
SQxhd2q8hdw/ciRWZuaQ4pPhU+FbwSGFE0Y8jlwe8APiisQXD8ocwyGWAz/v
49ScSXB88HxyO4jZELuBb/dWap9uQWQfGV8PPGBCbI45XPNWuU/CHlYhNYcR
ng6YLtguNjW8S3wKbG32dGJnxK/Z64lhEcsifgbXmD3859jxcvZ2fAxyWPHn
8T3gdz8XO34H95v4A7F67NlvE8fwieWDacWZ85WIMxJvJNeHmNx/OZyBc3/h
VMCtGIePkJkTAs8Dvge5E8Qv4A7wjAqZY3LE5sipOi4zP3tT7PgbuT7EVImt
Em+Fe0+MklglfMlNqWOoxFLJGSpLHbMhdgNm+3xmvBcfFIx4W27vYrOASW9J
HPMh9kMOyi+pY7bEbvkGE992+iJ2Dio5mOQ690iMpZBLzH4Cn/2D2N/44VtB
+NQvxeaL4GsT0wVXBl+OU8dgicUSn4X7Tk7tzhyPI9eW/LjX81gm35MBr/si
xwuxTfHx8PXwAcktxAfEFyQnlNw/cg7JDV0VmM9NDvFnOb4I3gc+2zbHh8Bf
wbjAusBowL/I0eue47Xwu/H52uR4E3guOYfkZhIjhb/OetU7MiYONo5PhG+E
T0XuNz4VvhX3b2S+/vaJbMOSv8OcZe4S8+D7Z+Qw8m0D5hO5jcTj4MqS40Gu
BzkrxNKIqfE9NvCqpjmeCx6Gz4fvNy+fj2B+YH/EUMAD4Rjw7YiOgbkHcIjq
5vshttX41N8WwAfiew5wJviWCpwjuBRwEviWysmBuQpf5fsjMQpiFXAw+DYK
Pi6xBzB/sH++UcX3N+BE8K0MOA5wJeBM8C0eMHriI+wfp0X2Acn/W5k694cY
Ft/bwwfunOPnzEdyMOCjwlHl+1n4zJ1y/J1ceHKGyR0mZk7+AvbcD6F9ILgo
zG/weNZz8oPAVMFWd+Z4BT5vhxzvBr8npkVsi5gV3z/hGxB8mwhOBvEXcuTh
jLQPnDvPNx/4lspJgb8F8XbqtZAcIXKFyJGBqwLnj+/bkANKjB7/hdyv/wMk
4AvK
          "]], Polygon3DBox[CompressedData["
1:eJwt1gu0T2UexvGNv3MOiSbjktxikuHQaExTRJ04xHDEwijG7WQ1MmVmqjUo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          "]]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.224146685, 0.090484535]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0rtOVVEQANABBBR5FcaEKBhDKIFYUAk/AFRQySMKEl4hYhAVhNBC/ACg
oSLQgY0U2uoXgMpTBELDKyQEFRGD64Tkzlkzs/fcc/c5935rb92zlIiYEgWp
EUm+6HLM9MyIfGbzHm+zjIWsYglr+YCNrGI3azjIeo6xiRNs5yz7uMCKGxEj
aRGf5WXXIxrcd95vWFL/kj8Sc+q+axFf9PbkTXrv+FXdLH9h7Zu8n8t8yRW+
4iofp0c8sW/BzGu9Nb19eYvegHpdPcgNvuF3DnGTT8222fcjOVNGxIG5dvUH
bunV6h3KO/U+clvvn7xDTDrjovotP3GY7/mcM2zjOBs5yjoOsJpdfMgGlrOG
xazkHZbyFou4zovknbh/Hi/du0ccea656gPmJGdmdnJW7omb8gvnPGeWWDHz
V/1Hftd3eTUx4fzT+r/lXk+cWf/JXfOZyYx9p5yxZ0fP44gTsS03Gls0Epv0
iQ2X1OTsFrtSrv5v/wF/P1Oa
       "]]}, 
     {GrayLevel[0.2], 
      Line3DBox[{1797, 2006, 2424, 2594, 1796, 2507, 1945, 1798, 2508, 1946, 
       1799, 2007, 2175, 1947, 2008, 2296, 2651, 2491, 2124, 1948, 2097, 2467,
        2509, 1949, 2125, 2631, 2341, 2342, 2110, 2140, 2282, 2425, 2634, 
       2281, 2141, 2142, 2126, 2343, 2632, 1950, 2098, 2009, 2510, 1951, 2127,
        2001, 2111, 2649, 2284, 1952, 2283, 2489, 2511, 2329, 1953, 1800, 
       2495, 2512, 2360, 1954, 1801, 2513, 1955, 1802, 2595, 2010, 1956, 
       2011}], Line3DBox[{1804, 2426, 2550, 1803, 1156, 1805, 2012, 2514, 
       1957, 2013, 2128, 2002, 2112, 2166, 2328, 2167, 2099, 2303, 2468, 2515,
        2176, 1958, 1806, 2516, 1959, 1807, 2596, 2014, 2177, 2304, 2305, 
       2653, 2100, 2306, 2015, 2178, 2427, 2597, 1808, 2517, 1960, 1809, 2016,
        2179, 2652, 2299, 2300, 2017, 2129, 2463, 2518, 2113, 2286, 2287, 
       2285, 2490, 2519, 1961, 1810, 2520, 1962, 1811, 2521, 1963, 1812}], 
      Line3DBox[{1814, 2428, 2551, 1813, 2429, 2552, 1815, 2018, 2180, 2430, 
       2598, 2019, 2297, 2003, 2130, 2168, 2169, 2101, 2308, 2347, 2654, 2020,
        2307, 2408, 2409, 2407, 2683, 2364, 1964, 2365, 2663, 2021, 2181, 
       2309, 2330, 2310, 2655, 2102, 2311, 2022, 2182, 2431, 2599, 1816, 2366,
        2432, 2664, 2367, 2023, 2346, 2661, 2348, 2356, 2349, 2024, 2143, 
       2464, 2522, 2114, 2288, 2289, 2103, 2620, 2025, 2183, 1965, 1817, 2523,
        1966, 1818, 2524, 1967, 1819}], 
      Line3DBox[{1821, 2433, 2553, 1820, 912, 1704, 913, 268, 1661, 834, 370, 
       732, 269, 371, 1387, 270, 1822, 2665, 915, 916, 1707, 271, 835, 1388, 
       372, 272, 2600, 1823, 2434, 2554, 1824, 866, 1693, 903, 1694, 273, 373,
        1389, 274, 1825, 2525, 1968, 1826, 2526, 1969, 1827}], 
      Line3DBox[{1829, 2435, 2555, 1828, 2026, 2027, 2621, 1830, 2350, 2028, 
       2351, 1309, 2331, 2185, 2186, 2184, 2029, 2144, 2030, 1831, 2527, 1970,
        1832, 2666, 2368, 2369, 1833, 2667, 2370, 2031, 2187, 2032, 2332, 
       2190, 2622, 2191, 2189, 2033, 2188, 2034, 2601, 1834, 2436, 2556, 1835,
        2437, 2557, 1836, 2469, 2627, 2115, 2035, 2192, 2195, 2194, 2602, 
       2036, 2193, 2037, 1837, 2528, 1971, 1838, 2529, 1972, 1839}], 
      Line3DBox[{1841, 2438, 2558, 1840, 2038, 1316, 1842, 2344, 2004, 2345, 
       2660, 2465, 2298, 2198, 2199, 2197, 2039, 2196, 2040, 1843, 2506, 2559,
        2416, 1844, 2668, 2371, 2372, 1845, 2669, 2373, 2041, 2200, 2042, 
       2333, 2203, 2623, 2204, 2202, 2043, 2201, 2044, 2603, 1846, 2439, 2560,
        1847, 2374, 2561, 2496, 1848, 2375, 2470, 2670, 2205, 2045, 2334, 
       2206, 2207, 2133, 2466, 2633, 2132, 2005, 1849, 2604, 2046, 2047, 1850,
        2530, 1973, 1851}], 
      Line3DBox[{106, 1060, 107, 608, 1061, 108, 463, 1062, 109, 778, 110, 
       1063, 111, 1064, 112, 1531, 611, 1065, 113, 612, 1066, 114, 1067, 115, 
       1068, 116, 1669, 870, 117, 1441, 439, 118, 1535, 616, 119, 1069, 120}],
       Line3DBox[{1853, 2440, 2562, 1852, 2048, 2563, 2471, 1854, 2134, 2135, 
       2131, 1455, 2136, 1855, 2209, 2210, 2208, 2413, 2412, 1856, 2418, 1795,
        2417, 2410, 1857, 2497, 2564, 2376, 1858, 2671, 2377, 2378, 2211, 
       2216, 2215, 2640, 1859, 2213, 2214, 2212, 2565, 2472, 1860, 2441, 2566,
        1861, 2379, 2567, 2498, 1862, 2380, 2381, 2672, 2217, 2219, 2218, 
       1863, 2137, 2628, 2483, 2116, 2139, 2138, 1864, 2473, 2568, 2049, 1865,
        2531, 1974, 1866}], 
      Line3DBox[{1867, 2382, 2532, 1975, 2383, 2050, 2220, 2312, 2641, 1976, 
       2313, 2170, 2171, 2145, 2494, 2635, 1977, 2104, 2051, 2533, 1978, 1868,
        2534, 1979, 1869, 2499, 2535, 1980, 2384, 1335, 2221, 2314, 2442, 
       2656, 2317, 2315, 2316, 2222, 2642, 1981, 1870, 2536, 1982, 1871, 2537,
        1983, 1872, 2492, 2538, 1984, 2301, 2474, 2539, 2117, 2172, 2290, 
       1985, 2319, 2493, 2657, 2318, 2223, 1986, 1873, 2540, 1987, 1874}], 
      Line3DBox[{1875, 2385, 2443, 2673, 2386, 2052, 2224, 790, 791, 522, 875,
        1675, 874, 2105, 2053, 2541, 1988, 1876, 2542, 1989, 1877, 1743, 1990,
        2387, 2674, 2054, 2225, 792, 1637, 794, 793, 2226, 2444, 2605, 1878, 
       1214, 1879, 2543, 1991, 1880, 2544, 1992, 1881, 2475, 2545, 2118, 523, 
       796, 1640, 795, 2227, 1993, 1882, 2662, 2361, 2362, 1994, 1883}], 
      Line3DBox[{1884, 2055, 2445, 2606, 2106, 2302, 2056, 2146, 2173, 2335, 
       2174, 2107, 2320, 2057, 2228, 2446, 2607, 1885, 2546, 1995, 1886, 2547,
        1996, 1887, 2675, 2388, 1997, 2389, 2676, 2058, 2232, 2321, 2336, 
       2322, 2658, 2108, 2323, 2059, 2234, 2447, 2608, 1888, 2448, 2569, 1889,
        1224, 1890, 2548, 1998, 1891, 2609, 2060, 2238, 2324, 2325, 2109, 
       2487, 2639, 2061, 2119, 2293, 2294, 2292, 2650, 2291, 1999, 1892}], 
      Line3DBox[{1894, 2062, 2063, 2624, 1893, 2064, 2147, 2065, 2636, 2148, 
       2231, 2230, 2066, 2229, 2067, 2610, 1895, 2449, 2570, 1896, 2549, 2000,
        1897, 2677, 2390, 2391, 1898, 2500, 2611, 2068, 2233, 2069, 2337, 
       1557, 2237, 2236, 2070, 2235, 2071, 2612, 1899, 2450, 2571, 1900, 2451,
        2572, 1901, 1757, 2392, 1902, 2393, 2613, 2072, 2239, 2073, 2338, 
       2240, 2241, 2484, 2614, 2074, 2120, 2075, 1903, 2615, 2076, 2077, 
       1904}], Line3DBox[{1906, 2078, 2079, 2625, 1905, 2150, 2080, 2149, 
       2081, 2637, 2151, 2244, 2243, 2082, 2242, 2573, 2476, 1907, 2419, 2574,
        2420, 1908, 2452, 2575, 1909, 2678, 2394, 2395, 1910, 2679, 2396, 
       2083, 2245, 2084, 2339, 2248, 2626, 2249, 2247, 2085, 2246, 2086, 2616,
        1911, 2453, 2576, 1912, 2454, 2577, 1913, 2501, 2578, 2397, 1914, 
       2398, 2477, 2680, 2250, 2087, 2340, 2251, 2252, 2485, 2617, 2088, 2121,
        2089, 2153, 1915, 2618, 2090, 2091, 1916}], Line3DBox[CompressedData["
1:eJwNzLsyQ1EUBuClCtq4tXpKFGqNIoVQi0hhHM5JCkwyQ9wTeQHxIh6Byp0g
wrP4im/Wv/+1954uZyvpUEQU6OQiZocjBvzxy9poxJW+KtdYJmNJfzsS0bbr
O//wTUNf0W/SsiubU7p789J5Ur6RL+QJuSufy4vyjPfv9PjgTL+q/5S/eGPD
/RJ1/an9ujwu35knzmPytXwsJ+YeB+zT1KVmRt69Z/+98sKR3Y5Z0O+aWyRs
c2hX1D/KTzyw4I955vgH6P4rsA==
       "]], 
      Line3DBox[{1944, 2096, 2279, 2280, 1588, 1943, 2164, 2295, 2165, 2123, 
       2630, 2482, 1942, 2354, 2363, 2355, 2327, 2659, 2481, 1941, 2593, 2462,
        1940, 2592, 2461, 1939, 2591, 2460, 1938, 2480, 2590, 2274, 2276, 
       2275, 1937, 2648, 2277, 2278, 2273, 2406, 2647, 2505, 1936, 2405, 2589,
        2504, 1935, 2588, 2459, 1934, 2587, 2458, 1933, 2479, 2586, 2326, 
       2095, 1932, 2478, 2585, 2158, 2163, 2162, 1931, 2488, 2646, 2272, 2271,
        2353, 2352, 2094}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{988, 1149, 2507, 989, 1156, 1008, 2552, 1165, 1019, 1703, 
       1704, 1173, 1029, 1308, 2621, 1390, 1181, 1040, 1316, 1317, 1190, 1051,
        2563, 1325, 1326, 1197, 1061, 609, 841, 783, 2641, 1071, 620, 843, 
       790, 1083, 632, 845, 2335, 524, 1094, 488, 2636, 1408, 526, 1106, 492, 
       2637, 1413, 528, 1118, 2638, 497, 1418, 531, 1128, 2585, 1371, 1423, 
       428, 687}], Line3DBox[CompressedData["
1:eJwVzrFLglEUhvETlaDgEG5RQ0tr4uBSSyA0BAmZTkEQLi01CEFDLlFqQf0p
bu1J1qBT7RVtTZmzZb9veHjf85zv3vutHJ7sHs9ExA7eZiOacxHDdMS7PtVj
PuJSvnA/XNqcwWom4pafcJ/mHM5TEXuoImX3xd3py7IpH2QPC3YjecHV3fNt
LumPXB9L5q4cy4Z8wnPypvleFnGKK2faaGHbPXn7df4MHe4G19jgN7k13/T0
rQRzwTzQK8jqZe5VP8DUuRxX4yb6L/5wZLfI7/Mfyf/hH4oPKyo=
       "]], 
      Line3DBox[{992, 240, 2175, 542, 880, 230, 2112, 434, 232, 2130, 454, 
       269, 869, 476, 2144, 277, 585, 2196, 284, 597, 2208, 292, 778, 300, 
       2533, 1073, 307, 2541, 1085, 1219, 2546, 1096, 2570, 1228, 1108, 2574, 
       984, 985, 2421, 974, 1130, 2587, 1249, 1140}], 
      Line3DBox[{993, 1256, 1270, 1257, 1603, 2651, 1448, 1494, 1281, 1383, 
       1282, 2515, 1613, 1499, 1500, 1291, 1676, 2654, 1292, 1617, 1616, 1300,
        1387, 1301, 1031, 1182, 2527, 1042, 2559, 1792, 1793, 1794, 1795, 
       1785, 1787, 1786, 1063, 1204, 2534, 1074, 1211, 2542, 1086, 1220, 2547,
        1097, 1229, 2549, 1109, 2575, 1236, 1120, 2580, 1242, 1131, 2588, 
       1250, 1141}], 
      Line3DBox[{994, 1429, 1430, 1381, 1271, 2509, 995, 1158, 2516, 1010, 
       1696, 1784, 2683, 1697, 1021, 1705, 2665, 1706, 1032, 1710, 2666, 1711,
        1043, 1715, 2668, 1716, 1053, 2564, 1724, 1725, 1064, 1735, 1736, 
       2535, 1075, 1742, 1743, 1087, 1747, 2675, 1748, 1098, 1752, 2677, 1753,
        1110, 1761, 2678, 1762, 1121, 2581, 1770, 1771, 1132, 2589, 1779, 
       1780, 1142}], Line3DBox[CompressedData["
1:eJwVzjFLgmEYhtEnzIaiKQhcAiNcHRpamlxyFJemCFocxIQIoq3+R1O5RAUV
VFu5ZktaGWRN2hIlNGRDS8fhcD/vhcKXXqsW10ciokgvEfGQjHjkkN2xiKXx
iB27551gznvUvnGg19inpE9qXY69Tzhi2vuDM3fZb87tKTPaN5fuin5lL8ho
A27cVb1ur8lqfzTcd9yyMPwm26TFPRv+s6hPuNs888SmntOn3B1emddebF5P
2R5b2rvtUtBn7Rfbet9+sqxnh6sN7C8/rOir/AMG2zL8
       "]], 
      Line3DBox[{1001, 1680, 1592, 1595, 1593, 2511, 1659, 1660, 1259, 1288, 
       1260, 2518, 1451, 1437, 1452, 1261, 1296, 1262, 2522, 1459, 1438, 1304,
        1694, 1305, 1439, 2627, 1312, 1313, 1525, 1723, 2670, 1320, 1722, 
       1321, 1530, 1732, 2672, 1329, 1731, 1330, 1669, 1607, 1608, 2538, 1080,
        1216, 2544, 1092, 1225, 2548, 1103, 1757, 1758, 1115, 2578, 1766, 
       1767, 1126, 2584, 1775, 1776, 1137, 2593, 1255, 1147}], 
      Line3DBox[CompressedData["
1:eJwVzz0vg1EYxvFblIStFgnpUBKDrRGDRtoONbQGSS2YaDeJl6kRn8PLSs3E
wCfoF7AZ2bw0qRaJ1e8M//yv5zr3ufOcfPOocTgSERv4HI04G484x9NExAVf
ooQKynjW/5nLjkXsY3UyYorf8I4ZHGAWW+b7/IU5LJo95nl0cYs71PSDjHN5
yA98har+nn90S/zLj3yNut0r6S4Xuee/OlxCOe3xfZN2oGDPGk+bfUVdXta9
yOtyjj9womukd8ibvMDfONVvp53yDre5pduV99DCP+CVKyY=
       "]], Line3DBox[CompressedData["
1:eJwVzLtKgmEYwPHHjipE2eQU1NJgYwVdQC0NguAF9AUVBEaCGAQOLkG41Nja
6RI62qx2oi2IoL0uoK1+Dj/+z/O+7/dNJzulSioiynwPRjSHIt4yET/mQ/O7
+dd8bP4wD+gJn+YxPeXLnNfCcMRcNqLaLzPO0vZ5c40F/ogR/yHFnj3Rddb6
vB/VNFky7HuzqVtsMM4Ek+RouC/6rqvb9o6ecUXefq2L7pv6SMVZT8+5Ycp+
q0veHOgzu86e9IJl53c66+xeW7xSt7/oJSveJHrEA21W3f8DMnUqmg==
       "]], 
      Line3DBox[{1005, 1277, 2595, 1278, 1006, 1163, 2521, 1017, 1171, 2524, 
       1027, 1179, 2526, 1038, 1188, 2529, 1049, 1195, 2530, 1059, 1202, 2531,
        1069, 1209, 2540, 1081, 1688, 2662, 1689, 1690, 1691, 1692, 1602, 
       2650, 1601, 1104, 1356, 2615, 1411, 1357, 1116, 1364, 2618, 1416, 1365,
        1576, 1577, 2645, 1579, 1578, 1421, 1657, 1658, 1656, 1587, 1588, 
       1590, 1589, 1426, 1472, 1490, 1471, 1612}], 
      Line3DBox[{1138, 1247, 1488, 1434, 1422, 1581, 1582, 1580, 2646, 1127, 
       1241, 1651, 1650, 1417, 1568, 1569, 2643, 1567, 1117, 1234, 1412, 2625,
        1358, 1105, 1226, 1407, 2624, 1350, 1093, 1217, 2606, 1404, 1344, 
       1082, 1210, 2673, 1741, 1740, 1070, 2532, 1203, 1734, 1733, 1060, 1196,
        2562, 1050, 1189, 2558, 1039, 1180, 2555, 1028, 1172, 2553, 1018, 
       1164, 2551, 1007, 1155, 2550, 987, 1148, 2594, 1269, 1380}], 
      Line3DBox[CompressedData["
1:eJwVz00opVEcB+AjlyJjhQVSwsJuTFN2yJJCl1yfM5Ipd3J9FN1SN9mwsPCx
EFlY2tnZ2dpOWQgplJnZYGPUjGLynMXT77zn9z/v+57a8ZnkdF4IIUc2EcId
pwUh7LFBU2EInxgoDuGjzOivWLCeZ81MvWygz0ydHNefMWs9w4qZKtmur5aV
pPQ/yFhPsWymXFZQRqfuhO/xfc6lZc7MB1lKCW36Y75ZT7CoL5CFJPisO2LM
+THPX8maeeM/rzTqD/miG413svePF3qc+ytr9AeM6IeZs/eHVv2zfKJMv8+Q
fjDe294DLWYe5T1F+m1S+v54b3u/+M3P+E/5Iazre+O/OpeUafs33HIdv2tm
1Ux3/F8zXXLS/gWXnMd3mlky06Fv1m+xyYu9Xf0ZO/Gent8Ba5BCtw==
       "]], 
      Line3DBox[{1144, 1252, 1374, 2590, 1134, 1244, 2619, 1368, 1123, 1238, 
       2616, 1361, 1112, 1231, 2612, 1353, 1100, 1222, 2608, 1347, 1089, 1213,
        2605, 1341, 1077, 2642, 1206, 1336, 1066, 1199, 1328, 2565, 1055, 
       1192, 2603, 1319, 1045, 1184, 2601, 1311, 1034, 1175, 2600, 1303, 1023,
        1168, 2599, 1294, 1012, 1160, 2597, 1285, 998, 2632, 1152, 1666, 1382,
        1428, 1427, 1431}], 
      Line3DBox[{1145, 1253, 2591, 1135, 1245, 2582, 1124, 1239, 2576, 1113, 
       1232, 2571, 1101, 1223, 2569, 1090, 1214, 1078, 2536, 1207, 1067, 1200,
        2566, 1056, 1193, 2560, 1046, 1185, 2556, 1035, 1176, 2554, 1024, 
       1169, 2664, 1702, 1701, 1013, 2517, 1161, 999, 2510, 1153, 1450, 1274, 
       1458, 1457, 1275}], 
      Line3DBox[{1146, 1254, 2592, 1136, 1246, 2583, 1125, 1240, 2577, 1114, 
       1233, 2572, 1102, 1224, 1091, 2543, 1215, 1079, 2537, 1208, 1068, 1201,
        1730, 1729, 2567, 1057, 1194, 1721, 1720, 2561, 1047, 1186, 2557, 
       1036, 1177, 1693, 1668, 1695, 1025, 1678, 2661, 1677, 1683, 1295, 1505,
        1014, 1606, 2652, 1605, 1287, 1286, 1498, 1000, 1597, 2649, 1596, 
       1594, 1258, 1663, 1276}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsu3k0l+/3/0uhUkoJGTJnFjJm2oYSKpUGJGOEZMyYyliGNCBJ5hSSIVMI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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"Axiale z- Richtung [m]\\t\"", TraditionalForm], 
    FormBox["\"\\tZeit [s]\"", TraditionalForm], 
    FormBox["\"Temperatur [\[Degree]C]\\t\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 1}, {0, 1000}, {0., 100.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], 
    Scaled[0.02]},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.415780118359375*^9, 3.41594467865625*^9, 
  3.419318054765625*^9, 3.4193192258125*^9, 3.419319773421875*^9, 
  3.41932044159375*^9, 3.419321830921875*^9, 3.4193218870625*^9, 
  3.419331864078125*^9, 3.419332893890625*^9, 3.41933433734375*^9, 
  3.419356117109375*^9, 3.4473854910625*^9, 3.447387213015625*^9, 
  3.44738804896875*^9, 3.447388422078125*^9, 3.447388978078125*^9, 
  3.447556610734375*^9, 3.481943341546875*^9, 3.481943715828125*^9, 
  3.4819438530625*^9, 3.48195375784375*^9, 3.641098861807742*^9, 
  3.6410999455763702`*^9, 3.6411012037050805`*^9, 3.641101636175169*^9, 
  3.641646721756657*^9, 3.641647623743685*^9, 
  3.6416942730702887`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[TextData[{
 "\n\n\n",
 StyleBox["C) erneute Berechnung der L\[ODoubleDot]sung\n", "Section"]
}], "Text",
 CellChangeTimes->{{3.419316484953125*^9, 3.419316505078125*^9}, {
   3.419316549109375*^9, 3.419316583703125*^9}, {3.419317019671875*^9, 
   3.419317040515625*^9}, 3.4819433806875*^9}],

Cell[BoxData[
 RowBox[{"Clear", "[", "T", "]"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{"tn", "=", "10000"}],
  FontColor->RGBColor[1, 0, 0]]], "Input",
 CellChangeTimes->{{3.481943407765625*^9, 3.48194341115625*^9}}],

Cell[BoxData["10000"], "Output",
 CellChangeTimes->{3.481943411875*^9, 3.481943715859375*^9, 
  3.481943853109375*^9, 3.481953238109375*^9, 3.641098862104616*^9, 
  3.6410999456076202`*^9, 3.641101203751954*^9, 3.641101636393921*^9, 
  3.641646722006658*^9, 3.6416476239780617`*^9, 3.6416942734140387`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ls", " ", "=", " ", 
  RowBox[{"NDSolve", "[", " ", 
   RowBox[{"gl", ",", 
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "mxsst"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using maximum number of grid points \
\[NoBreak]\\!\\(10000\\)\[NoBreak] allowed by the MaxPoints or MinStepSize \
options for independent variable \[NoBreak]\\!\\(z\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/NDSolve/mxsst\\\", \
ButtonNote -> \\\"NDSolve::mxsst\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.481943414765625*^9, 3.481943715921875*^9, 
  3.481943853171875*^9, 3.641098862245242*^9, 3.641099945748246*^9, 
  3.641101203892579*^9, 3.6411016365345464`*^9, 3.6416467221785336`*^9, 
  3.641647624228063*^9, 3.6416942736484165`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], "\[Rule]", 
    RowBox[{
     TagBox[
      TemplateBox[{RowBox[{
          StyleBox[
           TagBox["InterpolatingFunction", "SummaryHead"], 
           "NonInterpretableSummary"], 
          StyleBox["[", "NonInterpretableSummary"], 
          DynamicModuleBox[{Typeset`open$$ = False}, 
           PanelBox[
            PaneSelectorBox[{False -> GridBox[{{
                  PaneBox[
                   ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                   Alignment -> {Center, Center}, ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                   GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                   ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                  GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "10000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                   AutoDelete -> False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                   BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
                GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                BaselinePosition -> {1, 1}], True -> GridBox[{{
                  PaneBox[
                   ButtonBox[
                    DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                    ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                    None, Evaluator -> Automatic, Method -> "Preemptive"], 
                   Alignment -> {Center, Center}, ImageSize -> 
                   Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                  GraphicsBox[{{
                    GrayLevel[0.6], 
                    AbsolutePointSize[5], 
                    PointBox[{1, 1}], 
                    PointBox[{2, 4}], 
                    PointBox[{3, 2}], 
                    PointBox[{4, 3}]}, {{}, {}, {
                    AbsoluteThickness[1], 
                    Opacity[1.], 
                    LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                   GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                    GrayLevel[0.7], 
                    Thickness[Tiny]], FrameTicks -> None, 
                   ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
                  GridBox[{{
                    RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "10000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                   AutoDelete -> False, 
                   GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {
                    "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                   BaseStyle -> {
                    ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
                GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
                GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                BaselinePosition -> {1, 1}]}, 
             Dynamic[Typeset`open$$], ImageSize -> Automatic], 
            BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
          StyleBox["]", "NonInterpretableSummary"]}]},
       "CopyTag",
       DisplayFunction->(#& ),
       InterpretationFunction->(
        "InterpolatingFunction[{{0., 1.}, {0., 10000.}}, <>]"& )],
      False,
      Editable->False,
      SelectWithContents->True,
      Selectable->False], "[", 
     RowBox[{"z", ",", "t"}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.415780118640625*^9, 3.415944678875*^9, 
  3.4193180549375*^9, 3.419319225953125*^9, 3.41931977359375*^9, 
  3.41932044178125*^9, 3.419321831265625*^9, 3.419321887234375*^9, 
  3.419331864203125*^9, 3.41933289403125*^9, 3.419334337484375*^9, 
  3.419356117296875*^9, 3.44738549128125*^9, 3.44738721315625*^9, 
  3.447388049125*^9, 3.44738842225*^9, 3.447388978265625*^9, 
  3.447556610984375*^9, 3.48194341996875*^9, 3.481943725203125*^9, 
  3.481943862296875*^9, 3.6410988676827602`*^9, 3.641099955076397*^9, 
  3.6411012124238553`*^9, 3.6411016452376976`*^9, 3.641646731850437*^9, 
  3.641647634478093*^9, 3.6416942850859003`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"die", " ", "Aufbereitung", " ", "des", " ", 
   RowBox[{"Ergebnisses", " ", ":"}]}], " ", "*)"}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"lsf", "=", 
    RowBox[{"ls", "//", "Flatten"}]}], ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"TL", "[", 
    RowBox[{"z_", ",", "t_"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], "/.", "lsf"}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}]], 
               GraphicsBox[{{
                  GrayLevel[0.6], 
                  AbsolutePointSize[5], 
                  PointBox[{1, 1}], 
                  PointBox[{2, 4}], 
                  PointBox[{3, 2}], 
                  PointBox[{4, 3}]}, {{}, {}, {
                   AbsoluteThickness[1], 
                   Opacity[1.], 
                   LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                  GrayLevel[0.7], 
                  Thickness[Tiny]], FrameTicks -> None, 
                ImageSize -> {Automatic, 
                  Dynamic[
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "10000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}]], 
               GraphicsBox[{{
                  GrayLevel[0.6], 
                  AbsolutePointSize[5], 
                  PointBox[{1, 1}], 
                  PointBox[{2, 4}], 
                  PointBox[{3, 2}], 
                  PointBox[{4, 3}]}, {{}, {}, {
                   AbsoluteThickness[1], 
                   Opacity[1.], 
                   LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                  GrayLevel[0.7], 
                  Thickness[Tiny]], FrameTicks -> None, 
                ImageSize -> {Automatic, 
                  Dynamic[
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "10000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->(
     "InterpolatingFunction[{{0., 1.}, {0., 10000.}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", 
  RowBox[{"z", ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.415780118671875*^9, 3.415944678890625*^9, 
  3.41931805496875*^9, 3.41931922596875*^9, 3.419319773625*^9, 
  3.4193204418125*^9, 3.419321831296875*^9, 3.419321887265625*^9, 
  3.419331864234375*^9, 3.4193328940625*^9, 3.419334337515625*^9, 
  3.419356117328125*^9, 3.4473854913125*^9, 3.447387213171875*^9, 
  3.447388049140625*^9, 3.44738842228125*^9, 3.447388978296875*^9, 
  3.44755661103125*^9, 3.4819434245625*^9, 3.48194372528125*^9, 
  3.481943862390625*^9, 3.641098867823382*^9, 3.641099955263898*^9, 
  3.6411012126426077`*^9, 3.6411016453939486`*^9, 3.641646732053564*^9, 
  3.641647634587468*^9, 3.6416942851952753`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n\n",
 StyleBox["D) Graphische Darstellung der L\[ODoubleDot]sung\n", "Section"]
}], "Text",
 CellChangeTimes->{{3.419316484953125*^9, 3.419316505078125*^9}, {
  3.419316549109375*^9, 3.419316583703125*^9}, {3.419317019671875*^9, 
  3.419317040515625*^9}, {3.419317905171875*^9, 3.419317935453125*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    StyleBox["die",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    RowBox[{
     StyleBox["Gesamtsicht",
      FontColor->RGBColor[0, 0, 1]], ":"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{3.419317993390625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"TL", "[", 
    RowBox[{"z", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"TRand", "+", 
       RowBox[{"1.5", "deltaT"}]}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Axiale z- Richtung [m]\\t\>\"", ",", "\"\<\\tZeit [s]\>\"", ",", 
      "\"\<Temperatur [\[Degree]C]\\t\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.41931803553125*^9, 3.4193180685625*^9, {3.419318245984375*^9, 
   3.41931825771875*^9}, {3.419320803140625*^9, 3.419320803796875*^9}, 
   3.419321808609375*^9, {3.4819442205625*^9, 3.481944231484375*^9}, 
   3.6410989394173303`*^9, {3.6411009752512574`*^9, 3.641100981345028*^9}, 
   3.6416463252555447`*^9, {3.641693760258486*^9, 3.6416937673209753`*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0nXdczt/7xysiCqEto7pLi6Y07/vddmspDVuIiMoKZRQZISubkhkRFbrT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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmwnYVsMbxt9z3jNnRJYKlVCR7GmxlRSyr5ElVChLEgmFkqRsIUsiRVmS
UJbKruzZlyJ7ZQ1RtCGk//373+NyXd98z33mzJl3zpyZZ5/G3fscdU5eqVSO
DpVKVfQL/Vsm+rnoJJUJwivUYKzwKOGFwuOFxwgvEp4ofI/wMuH7hO8WXip8
v/C9wsuFxwjfIvyd8HXCw4Q/Ej6nqFRaZ5XKpqLXq/4K1X+s+tHCNwt/IzxC
+ErhT4SHC18u/KHwXcJjhX8SPl3P76Z+NhHtp/peqp+h+v7CZwnPFL5MuL/w
G8IXCPcUfo5nhTsLTxE+Q/h44YeFrxQeJPyecCeVo1QG6/p40c4qdwo3ipVK
D9E9NXfd9Nu7aAz1RGeWlcopqt9D9UPUz4XCb+qZa4SHCH8gfLvwSOFvhdsI
byE8SHgP4S2FLxU+XH21UJ8biu6t671UttK99mqzjehQXbdT2VNlY12fLnqa
yo601XPbq3yn+tZq31j0EtU3UV87qH4D0S1U/lb9V7p/geq6qqzS9bW6Hio6
l/GoTXPV1xHdVfX1Vd9P9TcJD2edCN8mfJPw18I3C1/LOhI+VuUYvqGuR6r+
OtF5uu6lvnZXnw1EzxJdW2WJ7u2iNvVEL1Cbg3RvJ9XXFm3LOFR2UmmsskD1
76kcrfKL2m+u8qnwEJXfmBf1M0D0bbUdJjxQ+B3hO9TXP2ozVvQqfaORol/o
G45W3a0qLVXGqS7j+4repjb3in6pNk/o3vTM475f5b7M3/sxlUcyr7+RKjdl
/maTVR5U2VXlFvVzt/pZoH7uEi3YQ6LvqP413T9X9FZdrxQeJXqMrncWPq70
eCexBnhfPTeFNaZyou5NED2+9O88oFJX5cjc7TdWOUfvfp7e/RXVXVv62W6i
HVVaCR8lOlq/94fwbaJjVP4Svl10W917Rc9uLXqY6pqqNFG5UH32Vv3z6nOd
zGujka4PF91WZRuV7oXfu77owSGtedGQe57qq3QUPkLlXN27WH2eI/qiri8S
Plv4BeFL0vhfFb5C+BLhd6nX84eo7KgyWPX9VP+66gcJny88S/hS1rTwa8LX
q921mddTs9JrbJLGs53uNaNedUtEB6psrbIu31xtaoquozKbNab+3lD5XLgp
v6NnXlfbvqJrq82nql9LdHLaL81Vv6PKRqqfqN86OPO+q6HrmPl3awuvp/Z5
4rc3C//CGhJ9nrUn3Fl0nu59DS+CQauvJiKPia5R+Ux1n2ldDVa7PelPdecl
XsecvCT8kvAGoi9ShNcXfUvt3xS+Xe13EJ4jfLfwdN2bKpyJnpvmkPmcJvyY
MEJigMa3p8bWULSiZzcQ+Uf4PJU2qt9MtG/6Lsz/mrRXNmKvqH071T8q+gV8
X/hY/e4mul6tZ37Wu/QW7ZPWw1lpbbAe2qjdyaxJtemV1gnrsE/67qyT8xO/
hc9/UHjfrILfJ1mAXDgzrWHkwuXC18A/hB8Xniac8601nmeFr9Nvrl+YLy5Q
/Q+Zeeb3yEJd/wifFJ1fNa+dI/pQYV66k+ivad3VUPle9xYh40TvL83zHxQN
aU2yNnfWM1W1/UFtauh6keg7et+/VH+qxvinaH+VPdRmc/h3ME/eR22PV91K
5KbKX6qvw+dS/XGqX17xGpqi/h4UXaW+1tW9nSpeq/+ofTPhQrR1YZ78i9o+
WZjXDhJtp+vd1GaEnq2pZxbr+huNbT3hpby/cFOVbfld9bNa5VPVf6K6Lurj
d+Qd85ubP8CvPinMq/5Su+fUz1G6v6OeO6EwD6wrerzuHaT68XruBOGDhe8S
3lt4O+ErhPcXbik8XHg/4RbC1yC3C/P1jUSPUv3eqr9N9X1Vd6zKUl3vq+sO
KjsLP4FOIjwdeU6dysdq97TG1kH3G2psndXPgcLjdO/Rwvv5Z9WdIppnXhPN
kTXMuerPTPu9luq+Yw3BD0X303Wp+p+Ej4Syf1W2UL/f6vpDxliYV28sulfV
czss9xphLa1bMS8MKgX8V3N9qeoO0jgPU/s2wjer/aHCrYVvEt5XeC/hUchZ
4f2FxwpvoHdcruvv0WtET1P9U6o/WPgA4TuEjxTuKDxBuKPwEcL3oncInyH8
jPAbGusGrEXVnapyuuqfht8LHy58D7qN8GHwHOFDhHcXvlG4m/BJwlOF31U/
tVk3qjuOovqHVP+axjlZ+FK94zbocJl50LFqcyx7Cr1D+BjhB4RPFO4i/Ihw
F+Gu8B/hVZnntpbKSVXzlmmq/zvz2quj0lX13eC3qu/O+wg/KfyT7s1XGZDk
/8NJriFLx2V+/ykaZzPksejBKjVVd6Xo7uqnufq5SvfWLq2/PKx3+bHq738x
61ltO6is5luK7pP4zpdqs5ZoY83NPmp3Q+Z+F2bW4f7UvYsyy5s1wjeo3ffC
I0T3K71G+C30lBuRdSp7qs9d1fb63PKHPg8sLTOHJ97VT2W/1P/Oar+16BC1
b49eq/q1kOmZ9wJy7WrRnpnX935qc4voeshtjeNs0d1Ee2XWIRqp/SLROchz
1S9mP2XmQeixf1jMVLZC3uj6W/1+u8Lv943wjSq3C/+AjgdvFV6JDic8Sfg3
5kl4NHxbuIE6W6PrJVrnt4repfpfVP+z+txc/VdFfyus7yDTH1CbJ+Bpoq/B
z4S35FvllncNVUZrTt9Q/Xbqcy31v6nwZNU9CA+FryIXVJ5ChIuWarMJaxWZ
pucz5gJeJtoj8ZGoNg1Y82pzaOn5u0b0RNETMvPSrdDpsUl0PVn9Ps1ciY5T
eUD4d92bIPwoMlp4Mz2fIZc0zntV/4jqV6t+lvDH8B7R9olXB/an2r+v6wtF
Z0XrQ9uX1lnRXfuJvhEt+89EJ4rm3cdyP5p/HSn8gvA96jsTfV5llPDfyFjh
A4U/FW6k8rz6HC/6dPS6/FD4qeg984Hwk9Hrb47wTOGrhVcJN0Ff1bN3iQ4t
LaeHibZPcnEv9KMkC9uJ1kUnF75DtLXKz+w79kxhfnKGyqfqfx/1/5Hu71Ha
1viIPV/aXmGNvhktj88pvWfYB+yhNuh/qf3narOj+pmtuk+q5tkXodMixyvW
4S7TvV+FJ4p+nnmdIyf2STwAfYP9dITKYuHLS++7/fk+pXUP9MzPVDcUecqa
U/2Govep/iJkq+p3F90+t+7L/ts2Nw89Db6ge82FHyg9F50yz813osckWfll
5n6WJH0CvQL9lT3dO/tvjmjPnH2V+uHdLindxz2iB6huu8y+hkzXtajXOC/P
vL6x487L3G4Fv1Gar9wbvN7Rc6pJv0HPmRD8Peam73O0bh6t+klq+4rwXOFG
oq/yPeGfVduevMtmacxHp+92RhpzQ9XvVvr+FPXfWN+xFfpQ9PhOTHtwR2xq
0d0Lr7faabwf6P65qa++aU5YE/eW1j3altaL2MvstT3TPDAfJ6R5gOVNQp7q
Pe7HD1Da1r8/eJ10g0/q+sOki6KToguiEz4Q3E+XNE54CzpKzYp1h+6Z1yI6
56mZ34193yWN56Okr6K3npV7bPuqzUmpH34PelLqc+/CfKiZ6ESVdfXMfWns
8IpGKo+orxlquzZ9lq7bUvRl9rrqG1a9p29krcG3dW+q2pzMNy0tk+uJHlFa
bm8o2lulsfBWop1K6wwbl7ZlsaG4PqVqX80T6rNnab7dq/QYX8zM97dBJ89s
854KDxe+FV4k+hTrROXZzNf4reBnD6vPv9FLVZ7M/Ax+gmkqDVS6w+dFR7Ku
SsuKxqLP6dm39Ww99KzSv9+wNF8cr/ol6u+43O/O84cyT5nH91hhWTs1+W/g
EfCHGdgKovVFZ6q8K7wJMkHldeENkT/IMOE6orVy2xHM3TNVy6+NRJcW/i6h
cN/oH+gcT+reLNHa6G6ldZzapX0no1TWz8zL91ObMbn1hQMz6wwvqP590U2R
RYxPeB3R/qV52i6ib+l6nuq3qdoWx8bcCh6r6y9UvzXvp7IAOcv8qcwX3pZ3
rdpm3170MZXnhWuKTlV5QXhdZDj7X7iW6BbRc7grMkfX76m+QdLVGc/ZufnO
AYlHDcusU2G/71XYJ7IdukzpOewjOih9p7aZfW/oLugt27JvM+tsyPl9M8t6
+HqH9O3g27RZKPyW6Bvp/Ven78v8owfRJ7wePx7Pbil6WeKT+qvMrvo+9ij6
Er+FrYGvBDsB/e/KhNev2CfBe2GrvJPZj/OVcLuE8edsU/i9+a3X1ddn6B2i
TQu/Xx/N1eDUnuca5p6fJmkuDk3rdlbCH1TMY5GzyN11Svsnd0q8F767JvkG
R2TWA9FF8ePUrXhtXJrmBxl4XWa5u1Nqh746PGHaH1y4zYGiR6jcLHxY4bEM
SuNB56UeXfr83Pb4EuSycNNKal/Y/4rdy15/Ju33G5H/mfk/NgFyGhmNzcd6
Qh5gJyBvG1W8vs5MbZAJyAbk4i6FZQ02/64JU4cM7ZPmhd9Bxv6rjyBzsR+Q
Mcga5Cw+W3CbwvKNeURe45dE70fnxy+B/s+77Y8/NDNvR/dETsDPD0lrBdty
s9y8Ej51bmH7Cz1yha6Xs3913bZqep3atSj9e1eX1jGuSt96/dK/f4jo7SrL
MttEjGdp+obYFdgXy6pem+y9NUnWMDZ0Y2QjugLy8YDCMvHBwu90U3qvIakN
snof7HTRvug3he+9X/W+Yf+gi2ydW3diD/INsWGQeeflXkesH9b44LRH6HtI
GsOY0v5b9POBudfzr1XLeb4vcn+x6seJnq0H1sotU7iGPp0wfB/+nxeeR+bz
yMI2Jr7myyr24z6a2Q+M3xf/b9+K5Q5+6hsq9gE/lNm30qMwPiX5ZWmP72VN
ep5nW6cxION6F45vYCO1lSLQXfgEvdcY3RvLOtH1b5mvwScX9uPiZztL+HHW
d2FfOWNCDiLHqEeW9SwcE8Df16fwPmJOkPfIfSZ0WnqWd1mQm9LniLSe2Rsv
5x4773Vq4fgMfiR8uPAIZEd/lQsz60htC/vGrizMP2gDL2ONYTPDA9GNB6S9
2aLq/Tog9zpBH9Xf/21hbO1VaY/gj4aXzsusN7POsWUHpP2O/x0/9t/YgJrH
8zPrq8jHfqkfvsnk9C3wkfO98SecUfhbn1bYx/BIWgOzc1Pq5+T2sf+j/jsW
9mPhj2tf+P3xQXVNY2YPXJB+F7nMXhmZ9ku3NF9r/yu/+c56duPcfg3kPfsU
/nqQ3uMl0ZdVnlO7maIvqEypWCZSjz6GjfxSalOjatqvsP6HHlgWXnfPpvXP
nM1P839hYZuO9j1TPf4EYkDYpNjY2DWzM+vnl2LbqO4J4QsK+2+x5f/KPa6+
SW6/nTmewV5G5hG3uKSwrX2p6LuZbRv87rzHq2n8TZK+it56fmFblT7XUf8z
0rujC6ITFoXrZqZ6dE5w42TnwkfR+8ZorG/BY0r7QFhD+AMHlR4PPgD0AvQD
bDrWF3YF/B4f1Jw0J/gMsX12SDIFewaew1ojNvZbWvesf/je0GR7YoOyvlmn
yIuBpf2drwbbQ/SDnMEX+olwW+Gr1O6LzH7sywvPOX7ei0v7LGfq2Stz+5Yf
L7yusFWwZ69K78geuabwN9yhsJ1NXGBkblmHzPs1yTUwsm9omgf482Xpdy9P
PqHP07r9hm+X2ZeNT5W1gV+1ZWk/8PDSch9dBH36osJxEHTdOWlOWYPoHNiT
/9r5i9Pczk314D8z+xA7CY9PGJvkTv1GzK3zX1X9j4fx3osSj7ixdP3NpeNi
Ze59f0vV+wBZsUnuWCF8Hl5FjOqzxFsWpe9eq7TefTg2ddX8+HY983tmHs31
0rRv2eOtqqboNXWSvw/dCX/Jj5ntiU5Vv9P9uffcT+m38GHUTfIQHwv4itL8
ZGHiLdgUxMVY0zVyyzneZ9PScqBHaZmD7CEeVD93vBU5dXbV/A++zn0cC8SN
rkv2NXb2kNLrljWG/oeeDJ+vW/VvXsx6rv7HI+slO6tG4Zgd7dlrF5Ru+6EG
vXlpuXe66HWlnx0hWi93/JUYUqvS8myU6DiVtXPbhjVz73/2+N1VU/gNMY5q
bnlLnBafcp1EV2f2L59ctWx9PPe78s68P+uItdUqteUZ2tXNbdNizxLDRRZj
/x5dODaB7/444TtUf4zo5rltb3gW34Rvg633bJor5gzeDI9umOj6yaeJvsz6
YG1sFR2XfiY6Ho+ORoyydu4+6QvdecPc+jN1tZNteRvfObfvkjwGdELi7sQz
eD/izvgYG+X2l9ZPOgrxd3Ip+P5jk/5SP62TiZm/Dd/l/zp4bj2cmAj94LMg
Nsn6wEYjTsZY8J8QT2LuiXETp+Rd8VGQg4IORLz/zcw2DPYLsneTtAe3JY6V
O+5AfAaey7rEH4UfFt66XdL9BiY9YvvkZ1uZ2tEGHwkY/xW+oC1z+8Tmpj7h
oU1z66PwOmQdMo843ITSeu670fyYZ9um3+W3kJsLUnt4K76ClrnjUy1yY/xl
xCV2TJi8Ea7xFU4p7Jd+RHS3qnk4vJy49g65/ZObR8c8m0fHL7egfbBNvafa
vR3dd4vUP/kb+BWRZ5PV/pCK5QtjaZXabJfGToysQdId7066ZIPceiP+yd1y
+8M7oN+o/S25Y3ZtcssabAPa4JvqKXqGyu4qz+jZA3P7K5ARtEdOMC7GR24J
7VsnuTW1dF7NVP3WtNJ2H/ix0jHHx4NzUtqm93o22SDYIq8hz4RHo/uwzoWv
zW33ocdgU2DnIgPxr76Q7Ersy8dL62/PqP8nSsclXxR+svQeB++PPpo7Vjqj
cD7AYF1PL50jxLOvJj0QffDNxB/gE+RIIWfIP3mqcH7CuXrmIJWDc+ctvVha
P5+vfmbwvXL7094r/Jud4ZuF23YR/ahwvP4ltfu8cPzxfeFPk12AfUAcdZe0
VsmL4ln6YA1Tj87xQmkdfk6wH3LX3H7Lt9XuSNGJuj5U5bDc/RJfow3+7S8L
5xLM1/XLpe2XH1T/TbI1sDleKp2PRP38ZC9gN3wHz0TO696rpW3bX9Xmh2QH
YQ+Rq0AOGHOyCH6E/Nf1ibl5ArrmK6Vzw3gWPQe7F786/nUw3/vf6w3S+mCd
vFz43XjH14UbBeveX5ZeN6yfmYXj7PBXYonE1tFN8HVvGR2f3y3lgbCuiVk0
CN4j80vnXbAPPhatEWxfz0V3CI5FflI6Tky8eIj6ahwcF/4KP2hwvHiBcK/c
OWbwCujpCf+e9Cj0qXdL57A9GpwP8DA8PTpmT+x+GOswOF/lC7WtH6z7zYOX
BMeavy4dj0ZuEPvaMDj34HPhOsHxys+ET1Gf3XPn35APgx+FOMPOpfn56NKx
R+QQfSEz70x6Uee0nolTdyrcBlsbPRGfJnoVMVF+a0XVfg78nNjkdZL/Ez8o
eYB/6v6IaN2LvpG/o1I/tIeOTvjh6n/2ELIf2d61cE4XeWXY2uiTd2XWw8gH
A+P3PrFw3Or4wrENYhx/VK0zjE/tiW2hI3RKz92T/afPQXn276SX8NvI2PuS
PtYl7Wti7l1Kj2uO3qubnj0p9zdelmwrbKw31ebk3D78bYPj+99hhwXnCXwv
3Cx4nD8Ibx0c9/8WPhqcP7BQeKfgeP2P+I2CY/0/Ce8SHLtfLDw9d4z+Hf1u
8+BY/yLWdXCM/hfkQ3B8fwm8QfhE9jVrITiv4NfSPgL0CHLh0HfQe/gep6e9
yT4ldwebuYPo4sI8Ab/XL+hBwmupj72Dcx5WwneD8xxWlM7B+FjtjojmifDG
OYXzRIlBLFWb9sH5FcuF2wXnFSwTPkr4YuZfuLfwbcL/CJ8VHL9eU1qm9Uxy
ipygM3Pz8dapnn2OPEAuPI2dFJ031Co67wjZ3DI6vwh/MHkBzdJe5t5m0XlM
O0TnKMAfphWOAaOLNInO/0E3JObZMDo3akfRVYXHRL7SSRrz1fDJ0nFndDTi
KvBN+OdCtTkvOP5e1bOnBvt/VqvN2cExfYwK9ho67VjRviH5x6Lj+OgFxFi6
Bedx/cX8Ey8X/qY0T4e3f1U4xww9jlgScgJ5AV8nx444UVdsAj07UfVF9Hfv
qnZLCusPb4n+SM5AdM4BvzUqOreAd9wrOpflpSR/yXuYVViOw+MX6v7YFHdn
/KOj8xX+SToA+Rwvig4PjuOvDz+JzmPgu9+W8hWYH+QX+aALkI3RuY9zme/g
fIN1o787fBh+vHt0HvCTzFNwHsJ6qltRmIeuFH2vdD4GcfZ9ovOHXgne48t1
f3m0fEcOMm8donOqZqnNmOicA77XwdF52O+ofkBwDkapuunRMZtNRGcXluXs
i6nRMZ56otOi40D1RR+Pjvc0iNYVDlf7ucxndLxnU9FHo3My6kb7zIlDk2Ny
fHQO9zz9/iHRueDvCh8Unf/9drB+Qr7sZ4X1nPdFf9L9IcH5EmuTmxCdF/6W
6u6LjoHVZB9Fx9WYw72j86teVpuR0TmIKxOfQcdAr0FHIt8VvtA+Ol/tBXhG
cM78j8H6Cet0MXZWsG5AmzuiczjYI1cX1u+Hi94YHNuqo/qJ0bE9vvvR0fnu
nwTnbZOP+n/9vepYFjn+6NnEJ9C7yUnAR0LOITl/+D7Iz+FgADGnRqyR0j7Z
m0THRee1BNF9g3Ot+dbNq/bxkOPWrOq4Fnnm5JfjVyAHqQO5CBXP/63BsciN
1U+9YN2A9XZLcJxuQ9XXCs7Ze1702sJ21/WidYNzApnzG4LjfbWjdTZisT+K
HhudC/4ZukZ0vuCMYNusV3r346JzxD9PuiIx128L63Lwp190v110TiFjuErl
cf3WOqyv4Lwg1sNJpf2z14t2jM5d/hA/ZHDe7FLRttE5fM8JHxWdo/yR8MbB
+YTwjU7ROc0f81zan+QU7RGd9/+s6ttEnxN4Wrh3bjuS3OBjos8bfKr61tHn
Cp4KzpXCr4s/eGBwXlDU/Uei836Y/0nRMWB4TguVllXbdONCio2qrpnKTlXn
FTSpOg8KvtEy2Xvoe/tF52u+LvxxtK8QeTE+pPivcOfofO4vWNshxazZE9H5
nW+obufo8wDThMeGFCtX3fXBfuMNhDeuOmb9a+F4GH5P4mOHRuepvxec4wpP
g7etiNZT3xbeNzqP8zX0kei88/eF7wwpbs67Rq9pcrQOiD4r8qbwydHnH75D
p4g+o/Kt8JnR51J+Cc6/xXYh969H9BkJ9njP6PMzS4JzcYjPdUCmR5+xWQxP
iD4z8zN6QfR5mEXoC9HnRn4KjpdjT5LLRAybWDY5Tt2jz1p8rzYnRJ85WSB8
SvTZjIXBvnviZPgEkdfo9KtFu0Wfw/lGba6Mzt1Ev+oSfSbkq+B8I2Ku94ke
UDrOSp5V1+izPV+jc0Wf1flSeERwrL8WcxCchwCvviI6xxR9b1h0biX64YDo
vFJslr8L6zaM7aLonFHshX7ROazYLLtEn0uZzr6Ozk/FTiEwDa/bV7R/dJ4r
9sIl0bmh2FYXRue2YlNcEJ3fjE10cXSuKvbIZcE5cjXgedF5FbzLA9H5FqzD
h6JzCOA/k6NzHeDJD0fnG20UrS+iN/6kd7k5OkcfXfGW6Bx09L0p0blK8L2z
os9WLdPvXxqd/4pNdHj0eYnZqu8TnZf/G3pTdL4+OuQN0Tnx6JnXROe7oz8P
j86bRze+OjonHt34sui8WHTyy6NzcNHJh0Tnv6LPD43OkUWfHxwc41iLbx6d
r49efW10vj56+PXRMp5c/XOjzxX8rufOic5BXyl8dvQZsxXC50efVfgTHhud
T4z+3zc6L/8P1Q+KzvHFJiVfnfgAeXM3RZ83QJceHJ3vi+53XvSZh1Vqu1Fp
3zx5QxOic0Hg4eiu6M6c1cB/i193gsZ9TPB5JXgU5xPQFdElsN2Ig5PfhK8e
P/89hXOV8Z+gQ3A+Ah/iwMK+Vnyw5HAxBuJpz0X7nPEbY5+SR0EscOvCZ2fw
dRKz7RGsu7KXOV+G3/Okwufd8EsSG8Svjo8dv/Qpwefy4EtfFz5/hSzD1814
yNUcWHXsl1jkV9F+NHwC9UvbkTOizwJyhguZSJyC+MRNqQ0+bPKwbg4+F8Pc
jgw+P8K3e6VwPj16L3k2yPEo/H3hs3PIZWL/5ACQ29kUPlUxz8fuwJdA3mLv
6DOEyxO/IuZIzifnBTomnY3zWXwv/PGc9Tgs6YcdWUMVy8FDQzrLFpzrie1M
bip5MuS5otuMTfYFeaqdgs+1oTMQWyGGQsyIs1TYx9j5P0T7+J5Sfa/oc4/I
d/ww+AbxEeI/xPb6WnVbBZ8rRCb2DD4XCQ8nrvFd0md6oV9WzP/7586pa1E4
poY/Zi4yLXfOXkt0yZDORSJ3gs9pIi/IWyLfhPwS/Pb4Moh9oe8tTvXEd4jn
cvaLfB5iouQ0kXtNbIrYEjHIMmFiRsSJOJ90RvB5T+QR+R7kb9yi+mXRtvHr
pXO6iKG+FR3TIYbC2TviU+RIcNaN2AexDM6czYuO2fxWOo/x5PTuh4d0JjTY
741PHLmDjxp/LX6leYXPZ2IH9Qk+24Js5WwpsQHyC8gJJo5Mji5n8dizxOjI
MyaGS94yZxLxNZO/gN8bXzc6M+dH8AvhH9qZua7YFlgU7Zd8tnTMFJ/WR6o7
LKTzrcExZXz2nKHhLCcxEvKPyKvskb4jMdAvkz6/NNq3OKv0GQp8vNicrYLP
q6J7nBtsO6NjNC0dzyH/ET8ysVL8ypyjwZ/L2DhHht2E/cR5E/yS5PsQ2yYm
wXfqH3zuib3GGQR8AtsXznclhkA+O/oguf2cd+HcKDFp8trQB8mb4LwL/qKJ
yY6+Qn29XDHfJoeTOOYfpWNsxNrIA+eMEOdZkN1Ngs/hoo8RgyN+hi69brBP
Er19WPBZNuQI9gj5EeR+c46yR269bmjwGTdkInEKYhnk2ncJPr+MbnNISOeI
g/OR8OuRp3RXdA49uvGo4FxHZPf46Nx9bFjOAeF/Z+/fE51riG7AGTpy5ciN
vzP6zAA+hHujcxCxJTlHtn3i85w/Ze+QA8V5K/RW8sjujs6PRLZuHuwTxr7m
/CZxUvYIebbkHZHH9EE0T+d85TOFzwM/Vzge0T7hi4LPRGCvPV/4LDF+BuIF
+JW/RfcOPieLjXxC8Nlk9L08+KwxenhXlVsr1nXJP+dcCTntnDXC549OMj86
5s235pwO/nHW86Bg/Qe5f2LweXB0RfKyhiY/21rBvm7sGs5f4Nf9o/BZPPyP
8BZ4CmuWPPAtSudZvBQdm8NP82L0viCv5GV4ptpNr1jHIL8XWfRKdG4PvA6e
1y/4zCO61nal48mc6yRfiPwJYlrkxOL/xA9CG+LJr6K3Bp9DR6+uGXzGCvsu
Bp9Hw/46MPgsOfYF8W/i4Jx96Bx8bhr9/P1o+5wc+HWCz0Nh65XBZ9nw28yO
tqsnpXcnZktOMXmTjSu2Zw8IPieL7XN88Dl69HDOUxPTJReSXAF825y5+B8X
Ne1U
          "]], Polygon3DBox[CompressedData["
1:eJwtmwf8V9Mbx+/3jnOLKBXZMjNCorKK0rBTyEho2JStbDIiJKlE0kKLCv9Q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          "]], Polygon3DBox[CompressedData["
1:eJwt13m8TeUeB+DNPucgFSEy5BqSMQ3kpi4qURm7Lt2M3RCRKCEylDlkyJyx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          "]]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.224146685, 0.090484535]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0r1PU1EYB+BDpX4gBWcHESutxdiJOBB0MRgSHEhjDCkxJB1IaJo2MkCb
YHRQcCfBxM1BJ0f8CzRMuCiCH3yUSBiZGIwE63Pi8N7n957bc+85t6e3VCtU
20IIr9RTIeYZlyP+bQ/hAqf0LblHrsntyRDychdv8SLv8RoneJNlDrPBAl9w
ki9Z4Vs2+J6L/Mjc6RDSnr+qvugfc0j1nAphXX+ZX9nLDV7hJtP8xqv8zg5r
zZi3pvqM/TB2KGdVRv9Tn+VWXDO347u5w37u8jqbTHlWzrxPak//hLfVa2v+
rF/iBz7nCuf4hmUu8yEXOcY673CaAywyw1G+s/eBhP3KQ/ID77ghD8r35Utx
X3JSXlDd+vn4G9Uwr0tfZ4olY3NyZ/zm8qx8Xt63p/gHd8R18pe+JT+Tz8Vv
Ya935RP5rGq6f8xH5p/hgXt/OMKaMcsJv1VVto1QjGeDeZdxOb6u4l4inhVj
/W3/z9g/gyhCaA==
       "]]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwVzzlSQmEUROGLjLIHtbAMBUkcEnDWnCW4AM2UhARxISACgroRJ4wMXAqW
5fcH553uvjyqXuXiqnWZiYgW/nIehYgTzIsRg3xERm6giW1c49Xt3m1J3scB
drBuf8NMHrpnecETfsaDnOMVv9nEXB7ZqrymVzHWD/UPeZjewRm6+MKP/Y5v
0cN52m0T79XkPGr6o34k//KWPuWCvirX011+wcxe5A6+7Ru4kft4citxxfaJ
Y3kP7fQ9brv8bl/m0/R/tjL/Ay2nJ4E=
       "]], 
      Line3DBox[{1279, 359, 1593, 377, 1151, 466, 378, 555, 554, 1583, 1547, 
       1841, 1455, 1706, 1703, 1842, 1456, 1742, 1835, 1843, 1457, 1280, 2018,
        1714, 1458, 1715, 2019, 1548, 1608, 495, 1170, 497, 496, 1609, 1746, 
       1975, 1281, 1844, 1459, 1282, 1845, 1460, 1283, 1830, 1846, 1461, 1713,
        1827, 1847, 1462, 1662, 2008, 1533, 1658, 492, 493, 1168, 366, 1595, 
       470, 1594}], 
      Line3DBox[{1284, 1534, 1664, 1702, 1196, 1584, 1549, 1743, 1747, 1976, 
       1285, 1848, 1463, 1286, 1849, 1464, 1287, 1850, 1465, 1288, 2020, 1716,
        1466, 1717, 2021, 1550, 1610, 1670, 1689, 1671, 2012, 1585, 1672, 
       1551, 1611, 1748, 1977, 1289, 1749, 1908, 1290, 1851, 1467, 1291, 1852,
        1468, 1292, 1853, 1469, 1293, 2005, 1657, 1470, 1665, 2010, 1535, 
       1660, 1698, 1699, 1596}], 
      Line3DBox[{1294, 1663, 1750, 2009, 1712, 1711, 1751, 2017, 1295, 1752, 
       1909, 1296, 1854, 1471, 1297, 1855, 1472, 1298, 2022, 1718, 1473, 1719,
        2023, 1552, 1612, 1673, 1690, 1978, 1829, 1586, 1674, 1553, 1614, 
       1753, 1979, 1299, 1754, 1910, 1300, 1755, 1911, 1301, 1856, 1474, 1302,
        1857, 1475, 1303, 1858, 1476, 1304, 2006, 1659, 1477, 1708}], 
      Line3DBox[{1306, 1756, 1912, 1305, 1757, 1913, 1307, 1758, 1914, 1308, 
       1759, 1915, 1309, 1859, 1478, 1310, 2024, 1720, 1721, 1311, 2025, 1722,
        1554, 1613, 1555, 1691, 1617, 1991, 1618, 1616, 1556, 1615, 1557, 
       1980, 1312, 1760, 1916, 1313, 1761, 1917, 1314, 1762, 1918, 1315, 1860,
        1479, 1316, 1861, 1480, 1317, 1862, 1481, 1318}], 
      Line3DBox[{1320, 1763, 1919, 1319, 1764, 1920, 1321, 1765, 1921, 1322, 
       1766, 1922, 1323, 1767, 1923, 1324, 2026, 1723, 1724, 1325, 2027, 1725,
        1558, 1619, 1559, 1692, 1622, 1992, 1623, 1621, 1560, 1620, 1561, 
       1981, 1326, 1768, 1924, 1327, 1769, 1925, 1328, 1770, 1926, 1329, 1771,
        1927, 1330, 1863, 1482, 1331, 1864, 1483, 1332}], 
      Line3DBox[{106, 701, 107, 702, 108, 703, 109, 704, 110, 705, 111, 706, 
       112, 1120, 424, 707, 113, 425, 708, 114, 709, 115, 710, 116, 711, 117, 
       712, 118, 713, 119, 714, 120}], 
      Line3DBox[{1334, 1772, 1928, 1333, 1773, 1929, 1335, 1774, 1930, 1336, 
       1775, 1931, 1337, 1776, 1932, 1338, 1831, 1933, 1726, 1339, 1236, 1727,
        1624, 1629, 1628, 2002, 1340, 1626, 1627, 1625, 1934, 1824, 1341, 
       1777, 1935, 1342, 1778, 1936, 1343, 1779, 1937, 1344, 1780, 1938, 1345,
        1781, 1939, 1346, 1865, 1484, 1347}], 
      Line3DBox[{1349, 1866, 1485, 1348, 1867, 1486, 1350, 1868, 1487, 1351, 
       1869, 1488, 1352, 1870, 1489, 1353, 1832, 1871, 1490, 1728, 1019, 1630,
        1675, 1782, 2013, 1678, 1676, 1677, 1631, 2003, 1491, 1354, 1872, 
       1492, 1355, 1873, 1493, 1356, 1874, 1494, 1357, 1875, 1495, 1358, 1876,
        1496, 1359, 1877, 1497, 1360}], 
      Line3DBox[{1362, 1783, 1940, 1361, 1878, 1498, 1363, 1879, 1499, 1364, 
       1880, 1500, 1365, 1881, 1501, 1366, 1244, 1502, 1729, 2028, 1562, 1632,
        1679, 1784, 2014, 1682, 1680, 1681, 1633, 1785, 1982, 1367, 1882, 
       1503, 1368, 1883, 1504, 1369, 1884, 1505, 1370, 1885, 1506, 1371, 1886,
        1507, 1372, 1887, 1508, 1373}], 
      Line3DBox[{1375, 1786, 1941, 1374, 1787, 1942, 1376, 1888, 1509, 1377, 
       1889, 1510, 1378, 1890, 1511, 1379, 2029, 1730, 1512, 1731, 2030, 1563,
        1634, 1683, 1693, 1684, 2015, 1587, 1685, 1564, 1635, 1788, 1983, 
       1380, 1789, 1943, 1381, 1891, 1513, 1382, 1892, 1514, 1383, 1893, 1515,
        1384, 1894, 1516, 1385, 1895, 1517, 1386}], 
      Line3DBox[{1388, 1790, 1944, 1387, 1791, 1945, 1389, 1792, 1946, 1390, 
       1896, 1518, 1391, 1897, 1519, 1392, 2031, 1732, 1520, 1733, 2032, 1565,
        1636, 1686, 1694, 1687, 2016, 1588, 1688, 1566, 1638, 1793, 1984, 
       1393, 1794, 1947, 1394, 1795, 1948, 1395, 1898, 1521, 1396, 1899, 1522,
        1397, 1900, 1523, 1398, 1901, 1524, 1399}], 
      Line3DBox[{1401, 1796, 1949, 1400, 1797, 1950, 1402, 1798, 1951, 1403, 
       1799, 1952, 1404, 1902, 1525, 1405, 2033, 1734, 1735, 1406, 1833, 1985,
        1567, 1637, 1568, 1695, 1641, 1993, 1642, 1640, 1569, 1639, 1570, 
       1986, 1407, 1800, 1953, 1408, 1801, 1954, 1409, 1802, 1955, 1410, 1903,
        1526, 1411, 1904, 1527, 1412, 1905, 1528, 1413}], 
      Line3DBox[{1415, 1803, 1956, 1414, 1804, 1957, 1416, 1805, 1958, 1417, 
       1806, 1959, 1418, 1807, 1960, 1419, 2034, 1736, 1737, 1420, 2035, 1738,
        1571, 1643, 1572, 1696, 1646, 1994, 1647, 1645, 1573, 1644, 1574, 
       1987, 1421, 1808, 1961, 1422, 1809, 1962, 1423, 1810, 1963, 1424, 1811,
        1964, 1425, 1906, 1529, 1426, 1907, 1530, 1427}], 
      Line3DBox[{1441, 1580, 1579, 1990, 1440, 1974, 1820, 1439, 1973, 1819, 
       1438, 1972, 1818, 1437, 1971, 1817, 1436, 1970, 1816, 1435, 1989, 1578,
        1649, 1651, 1650, 1434, 2004, 1652, 1653, 1648, 1741, 1740, 2036, 
       1433, 1739, 1969, 1834, 1432, 1968, 1815, 1431, 1967, 1814, 1430, 1966,
        1813, 1429, 1965, 1812, 1428, 1988, 1576, 1575, 1577}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{620, 975, 989, 462, 1995, 621, 361, 1041, 554, 635, 1008, 
       1976, 824, 647, 1203, 2017, 835, 660, 1913, 847, 674, 1920, 860, 688, 
       1929, 873, 702, 886, 1867, 716, 899, 1878, 730, 1942, 912, 744, 1945, 
       925, 758, 1950, 938, 772, 1957, 951, 786, 1965, 964, 800}], 
      Line3DBox[{346, 228, 1704, 558, 557, 1842, 637, 826, 1849, 649, 837, 
       1854, 662, 1915, 849, 676, 1922, 862, 690, 1931, 875, 704, 888, 1869, 
       718, 901, 1880, 732, 914, 1889, 746, 927, 1896, 760, 1952, 940, 774, 
       1959, 953, 788, 1967, 966, 802}], 
      Line3DBox[{622, 1056, 977, 990, 978, 1836, 1276, 1277, 1273, 1275, 1274,
        1843, 638, 827, 1850, 650, 838, 1855, 663, 850, 1859, 677, 1923, 863, 
       691, 1932, 876, 705, 889, 1870, 719, 902, 1881, 733, 915, 1890, 747, 
       928, 1897, 761, 941, 1902, 775, 1960, 954, 789, 1968, 967, 803}], 
      Line3DBox[{623, 1062, 1063, 1039, 991, 1837, 624, 1208, 2018, 1209, 639,
        1213, 2020, 1214, 651, 1218, 2022, 1219, 664, 1223, 2024, 1224, 678, 
       1228, 2026, 1229, 692, 1933, 1233, 1234, 706, 1238, 1239, 1871, 720, 
       1243, 1244, 734, 1248, 2029, 1249, 748, 1253, 2031, 1254, 762, 1258, 
       2033, 1259, 776, 1263, 2034, 1264, 790, 1969, 1268, 1269, 804}], 
      Line3DBox[CompressedData["
1:eJwVz80qRGEcx/H/GCJ34QrcAwsbC2kWFhaShYUMZeGauAMUiqmZKaaGYmpG
eQk5R+bFWxKfZ/Hp98y305nnTCyX59cLEVFicyhiajhimkl2ORuN2LEz7HPA
Hnd6XoyYdT7imEMe9K4+53xKhRMe9b5ecq7x7HfdVnnXF+w5L3oj/S+f+qK9
4JIm39qSvabFFT/aiu1wQ5vMe3711XRX7rnlVf/T15yf0j3S3XjTC3aDPD2X
vknLbJEtevTTd9guI2ynezLQv+wHY4zzD9VuP2Q=
       "]], 
      Line3DBox[{630, 1073, 980, 998, 981, 1840, 1199, 1197, 1198, 1846, 644, 
       832, 1852, 656, 843, 1856, 669, 1918, 855, 683, 1926, 868, 697, 1937, 
       881, 711, 894, 1874, 725, 907, 1884, 739, 920, 1892, 753, 933, 1898, 
       767, 1955, 946, 781, 1963, 959, 795, 1972, 972, 809}], 
      Line3DBox[{631, 1074, 982, 999, 983, 1159, 2007, 1150, 1148, 1207, 1149,
        1847, 645, 833, 1853, 657, 844, 1857, 670, 856, 1860, 684, 1927, 869, 
       698, 1938, 882, 712, 895, 1875, 726, 908, 1885, 740, 921, 1893, 754, 
       934, 1899, 768, 947, 1903, 782, 1964, 960, 796, 1973, 973, 810}], 
      Line3DBox[{632, 984, 1000, 1076, 1075, 1999, 1068, 1161, 1162, 1160, 
       2008, 985, 1154, 1152, 2005, 1153, 658, 845, 1858, 671, 857, 1861, 685,
        870, 1863, 699, 1939, 883, 713, 896, 1876, 727, 909, 1886, 741, 922, 
       1894, 755, 935, 1900, 769, 948, 1904, 783, 961, 1906, 797, 1974, 974, 
       811}], Line3DBox[{633, 1001, 1067, 1997, 1002, 1077, 1078, 1099, 1079, 
       1007, 1081, 1168, 1080, 1069, 1164, 1165, 1163, 2010, 986, 1157, 1155, 
       2006, 1156, 672, 858, 1862, 686, 871, 1864, 700, 884, 1865, 714, 897, 
       1877, 728, 910, 1887, 742, 923, 1895, 756, 936, 1901, 770, 949, 1905, 
       784, 962, 1907, 798, 1035, 1990, 1036, 1037}], 
      Line3DBox[{799, 963, 1988, 1031, 785, 950, 1956, 771, 937, 1949, 757, 
       924, 1944, 743, 911, 1941, 729, 898, 1940, 715, 1866, 885, 701, 872, 
       1928, 687, 859, 1919, 673, 846, 1912, 659, 834, 2009, 1204, 1206, 1205,
        646, 823, 1196, 1043, 1083, 1082, 634, 817, 1151, 490, 1003, 1093, 
       1094, 1092, 619, 2000, 812, 988, 987, 1038}], 
      Line3DBox[{801, 965, 1966, 787, 952, 1958, 773, 939, 1951, 759, 926, 
       1946, 745, 1888, 913, 731, 1879, 900, 717, 1868, 887, 703, 874, 1930, 
       689, 861, 1921, 675, 848, 1914, 661, 836, 1909, 648, 1848, 825, 636, 
       1841, 818, 1200, 1004, 1201, 1202, 1996, 1085, 1084, 1158, 976, 1193, 
       1089, 1070}], Line3DBox[CompressedData["
1:eJwV0DlLnFEUBuAbDQRbMTHuKFgYSJXWws4FVDJDFBW3kRhUZgYNURxB7Gwk
kmhc4zIaEys7m1haZGKn2Ln/gPyCND5f8fCee897m1udSMdST0IIs9Tmh5Cj
4WkIr6giwwyXz0KYlsX2Jxyaf1HJJGf2U/ITBfZH/DQfUMEEf3U+ynH+54WQ
1flhvne/L8tJkSbJP51lnT3znU5WljHKGCPRvc68zq39rvMOpQzzgfec62R0
bnS2nbcoIcEQg5zqJHW+mzd5SR/9XHjXK491BnQ2zOvRX9BNzr5HdkV/ohPX
WTOv8oIO/uh0ynfRW51GnRXzN37bPZcx4rxlQadeZ9l8bb8ki2ijnVbmdN7o
fDV/oZBmWmiK/tz+tf2V94vOn3lwrpF1VEd/7/wIx9A/5w==
       "]], 
      Line3DBox[{806, 969, 1989, 1033, 792, 956, 1987, 1030, 778, 943, 1986, 
       1028, 764, 930, 1984, 1026, 750, 917, 1983, 1024, 736, 904, 1982, 1022,
        722, 2003, 891, 1020, 708, 878, 1018, 1934, 694, 865, 1981, 1016, 680,
        852, 1980, 1014, 666, 840, 1979, 1012, 653, 829, 1977, 1010, 641, 820,
        1975, 1006, 627, 2001, 814, 1040, 1060, 1059, 1064}], 
      Line3DBox[{807, 970, 1970, 793, 957, 1961, 779, 944, 1953, 765, 931, 
       1947, 751, 918, 1943, 737, 1882, 905, 723, 1872, 892, 709, 879, 1935, 
       695, 866, 1924, 681, 853, 1916, 667, 841, 1910, 654, 830, 1908, 642, 
       1844, 821, 628, 1838, 815, 1072, 994, 1087, 1086, 995}], 
      Line3DBox[{808, 971, 1971, 794, 958, 1962, 780, 945, 1954, 766, 932, 
       1948, 752, 1891, 919, 738, 1883, 906, 724, 1873, 893, 710, 880, 1936, 
       696, 867, 1925, 682, 854, 1917, 668, 842, 1911, 655, 1851, 831, 643, 
       1845, 822, 629, 1839, 816, 997, 979, 1061, 996}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsu3k4lt/7NqrMMs8ZIiRlSkWGPJcyFBVSJLNSKIVMlRIyz5QhCZmSMkeE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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"Axiale z- Richtung [m]\\t\"", TraditionalForm], 
    FormBox["\"\\tZeit [s]\"", TraditionalForm], 
    FormBox["\"Temperatur [\[Degree]C]\\t\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 1}, {0, 10000}, {0, 150.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.419318070453125*^9, {3.419318252765625*^9, 3.419318258234375*^9}, 
   3.419319226125*^9, 3.41931977378125*^9, 3.41932044196875*^9, 
   3.41932183153125*^9, 3.4193218875*^9, 3.419331864375*^9, 
   3.419332894203125*^9, 3.41933433765625*^9, 3.4193561175*^9, 
   3.447385491453125*^9, 3.44738721334375*^9, 3.4473880493125*^9, 
   3.447388422453125*^9, 3.44738897846875*^9, 3.44755661121875*^9, 
   3.481943428625*^9, 3.48194372546875*^9, 3.481943862578125*^9, 
   3.6410988681827583`*^9, 3.641099955576399*^9, 3.6411012130957346`*^9, 
   3.6411016457064486`*^9, 3.6416467323504405`*^9, 3.64164763486872*^9, 
   3.6416942854765253`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    StyleBox["Momentaufnahme",
     FontColor->RGBColor[0, 0, 1]], ":", " ", 
    RowBox[{
    "das", " ", "Temperaturprofil", " ", "l\[ADoubleDot]ngs", " ", "des", " ",
      "Stabes", " ", "am", " ", "Ende", " ", "der", " ", 
     "\[IndentingNewLine]", " ", "Simulation"}], ":"}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.419317968109375*^9, 3.419317975140625*^9}, {
  3.419319008828125*^9, 3.419319009046875*^9}, {3.641098554978798*^9, 
  3.64109855526005*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"TL", "[", 
     RowBox[{"z", ",", "tn"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{"TRand", "+", "deltaT"}]}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\< z \\t\>\"", ",", "\"\< T \\t\>\""}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", " ", 
     "\"\<r\[ADoubleDot]umlicher Temperaturverlauf \n             l\
\[ADoubleDot]ngs des Stabes am Ende der Simulation\>\""}]}], "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.41931826696875*^9, 3.419318272046875*^9}, {
   3.4193184328125*^9, 3.419318443828125*^9}, {3.4193185559375*^9, 
   3.419318616765625*^9}, {3.419318652640625*^9, 3.4193186564375*^9}, 
   3.419319870875*^9, {3.6410996509505396`*^9, 3.641099655638051*^9}, {
   3.641100989641928*^9, 3.641101003204469*^9}, 3.641646329599309*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk8Vc0bAHBblCL0Wq4skZCQLJV7bp5p+VUqFVIkS6HSIoWKbIXelGwR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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" z \\t\"", TraditionalForm], 
    FormBox["\" T \\t\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{507., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox[
   "\"r\[ADoubleDot]umlicher Temperaturverlauf \\n             \
l\[ADoubleDot]ngs des Stabes am Ende der Simulation\"", TraditionalForm],
  PlotRange->{{0., 0.9999999795918367}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.415780118890625*^9, 3.415944679125*^9, 3.419318055875*^9, 
   3.419318272765625*^9, 3.419318447984375*^9, 3.4193185588125*^9, {
   3.419318592578125*^9, 3.419318619046875*^9}, 3.41931865928125*^9, 
   3.41931922615625*^9, 3.419319773828125*^9, 3.419320442015625*^9, 
   3.419321831578125*^9, 3.41932188753125*^9, 3.41933186440625*^9, 
   3.419332894234375*^9, 3.4193343376875*^9, 3.41935611753125*^9, 
   3.4473854915*^9, 3.44738721340625*^9, 3.447388049375*^9, 
   3.44738842253125*^9, 3.447388978609375*^9, 3.4475566113125*^9, 
   3.481943449890625*^9, 3.481943725515625*^9, 3.48194386265625*^9, 
   3.6410988682608833`*^9, 3.641099955670151*^9, 3.6411012132363577`*^9, 
   3.6411016458158245`*^9, 3.641646732459815*^9, 3.641647635071846*^9, 
   3.641694285554653*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"der", " ", "zeitliche", " ", "Temperaturverlauf", " ", 
     StyleBox["an",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox["einer",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox["festen",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox[" ",
      FontColor->RGBColor[0, 0, 1]], 
     StyleBox["Stelle",
      FontColor->RGBColor[0, 0, 1]]}], ",", " ", "\[IndentingNewLine]", "   ", 
    RowBox[{
     RowBox[{"hier", " ", "z"}], "=", " ", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ":"}]}]}], " ", "\[IndentingNewLine]", " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.41931867253125*^9, 3.41931867496875*^9}, {
  3.419319016765625*^9, 3.419319017015625*^9}, {3.4819444561875*^9, 
  3.48194445978125*^9}, {3.6410985631819444`*^9, 3.641098583510124*^9}, {
  3.6416937944615517`*^9, 3.641693808899027*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"TL", "[", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0", ",", "tn"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\< t \\t\>\"", ",", "\"\< T \\t\>\""}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", " ", 
     "\"\<zeitlicher Temperaturverlauf in der Mitte\>\""}]}], "]"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.41931868859375*^9, 3.41931872815625*^9}, 
   3.419319874296875*^9, {3.44738793365625*^9, 3.4473879343125*^9}, 
   3.44738896796875*^9, {3.481944463359375*^9, 3.4819444940625*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwl0Xk4lYkXB3ChhJS6yBLpZmQnUSYvvq6dkmu7rzXZshWlKQY1FFF+ky1b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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" T \\t\"", TraditionalForm]},
  AxesOrigin->{0, 26.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{526., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox[
   "\"zeitlicher Temperaturverlauf in der Mitte\"", TraditionalForm],
  PlotRange->{{0, 10000}, {28.045991920984115`, 100.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.415780118921875*^9, 3.415944679171875*^9, 3.419318055921875*^9, 
   3.419318729*^9, 3.4193192261875*^9, 3.419319773875*^9, 3.41932044209375*^9,
    3.419321831640625*^9, 3.4193218875625*^9, 3.4193318644375*^9, 
   3.41933289428125*^9, 3.41933433771875*^9, 3.41935611759375*^9, 
   3.44738549159375*^9, 3.4473872134375*^9, 3.447388049421875*^9, 
   3.447388422609375*^9, {3.447388969328125*^9, 3.447388978671875*^9}, 
   3.447556611375*^9, 3.48194346634375*^9, 3.481943725578125*^9, 
   3.48194386271875*^9, {3.48194446696875*^9, 3.48194449465625*^9}, 
   3.641098868323386*^9, 3.641099955763901*^9, 3.6411012133769875`*^9, 
   3.6411016459408245`*^9, 3.6416467325535655`*^9, 3.641647635165595*^9, 
   3.641694285617152*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"daraus", " ", "ein", " ", 
   RowBox[{"Detail", ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.41931905759375*^9, 3.41931905990625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"TL", "[", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "t0", ",", 
      RowBox[{"tn", 
       StyleBox["/",
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["10",
        FontColor->RGBColor[1, 0, 0]]}]}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\< t \\t\>\"", ",", "\"\< T \\t\>\""}], "}"}]}], ",", 
    RowBox[{
    "PlotLabel", "\[Rule]", " ", 
     "\"\<anf\[ADoubleDot]nglicher Temperaturverlauf in der Mitte\>\""}]}], 
   "]"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.41931874465625*^9, 3.419318772625*^9}, {
   3.419318855671875*^9, 3.419318869796875*^9}, 3.41931988265625*^9, {
   3.447387948734375*^9, 3.4473879539375*^9}, {3.481944475828125*^9, 
   3.48194450234375*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwl1nk4VO0bB3BL0SJSKkKSVpXsLS/jxtgHY4Yx9p0IUbZXErJvYyt5yRIh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" T \\t\"", TraditionalForm]},
  AxesOrigin->{0, 74.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{506., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox[
   "\"anf\[ADoubleDot]nglicher Temperaturverlauf in der Mitte\"", 
    TraditionalForm],
  PlotRange->{{0, 1000}, {74.57918031936254, 100.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.41578011896875*^9, 3.415944679234375*^9, 3.419318055953125*^9, {
   3.4193187659375*^9, 3.41931877325*^9}, 3.419318871125*^9, 
   3.419319226234375*^9, 3.41931977396875*^9, 3.41932044215625*^9, 
   3.419321831703125*^9, 3.419321887625*^9, 3.419331864484375*^9, 
   3.419332894328125*^9, 3.419334337765625*^9, 3.419356117640625*^9, 
   3.44738549165625*^9, 3.447387213484375*^9, 3.447388049484375*^9, 
   3.447388422671875*^9, 3.44738897871875*^9, 3.447556611421875*^9, 
   3.4819434704375*^9, 3.481943725640625*^9, 3.481943862828125*^9, {
   3.4819444805625*^9, 3.481944503171875*^9}, 3.6410988684015093`*^9, 
   3.6410999558732758`*^9, 3.6411012135176105`*^9, 3.6411016460502014`*^9, 
   3.641646732662941*^9, 3.641647635243723*^9, 3.6416942859140253`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n\n\n",
 StyleBox["E) Kontrolle: eine genauere Rechnung\n", "Section"]
}], "Text",
 CellChangeTimes->{{3.419316484953125*^9, 3.419316505078125*^9}, {
  3.419316549109375*^9, 3.419316583703125*^9}, {3.419317019671875*^9, 
  3.419317040515625*^9}, {3.419317905171875*^9, 3.419317935453125*^9}, {
  3.419318898765625*^9, 3.419318919484375*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["(*",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 0]], 
  RowBox[{
   StyleBox["die",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["Rechnung",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["ist",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["je",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["nach",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["Rechnerleistung",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["zeitaufw\[ADoubleDot]ndig",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["und",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["braucht",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox["  ",
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[
    RowBox[{"ggf", ".", " ", "zuviel"}],
    FontColor->RGBColor[1, 0, 0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   RowBox[{
    StyleBox["Speicher",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[":",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["\[IndentingNewLine]",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{
     "Mathematica", " ", "beendet", " ", "dann", " ", "von", " ", "sich", " ",
       "aus", " ", "die", " ", 
      RowBox[{"Rechnung", "!"}], "\[IndentingNewLine]", "Abhilfe"}],
     FontColor->RGBColor[0, 1, 1]], 
    StyleBox[":",
     FontColor->RGBColor[0, 1, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 1, 1]], 
    StyleBox[
     RowBox[{
     "Mathematica", " ", "NEU", " ", "starten", " ", "und", " ", "notebook", 
      " ", "neu", " ", 
      RowBox[{"auswerten", " ", "!!"}]}],
     FontColor->RGBColor[0, 1, 1]]}]}], 
  StyleBox["    ",
   FontColor->RGBColor[0, 1, 1]], 
  StyleBox["\[IndentingNewLine]",
   FontColor->RGBColor[0, 1, 1]], 
  StyleBox[" ",
   FontColor->RGBColor[1, 0, 0]], 
  StyleBox["*)",
   FontColor->RGBColor[1, 0, 0]]}]], "Input",
 CellChangeTimes->{{3.481944531015625*^9, 3.481944568828125*^9}, 
   3.481944756421875*^9, {3.481944796640625*^9, 3.4819448518125*^9}, {
   3.641099047980117*^9, 3.6410991063708982`*^9}, {3.6411014074557047`*^9, 
   3.6411014129713483`*^9}, {3.641104712418977*^9, 3.641104820606797*^9}, 
   3.641646874147731*^9, {3.64169384819584*^9, 3.641693883820781*^9}, {
   3.6416943498827095`*^9, 3.641694358992076*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ls", " ", "=", " ", 
    RowBox[{"NDSolve", "[", " ", 
     RowBox[{"gl", ",", 
      RowBox[{"T", "[", 
       RowBox[{"z", ",", "t"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}], ",", 
      "\[IndentingNewLine]", "                           ", 
      StyleBox[
       RowBox[{"MaxStepSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"zn", "/", "100"}], ",", "  ", 
          RowBox[{"tn", "/", "1000"}]}], "}"}]}],
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox[",",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox["\[IndentingNewLine]",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox["                           ",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox[
       RowBox[{"MaxSteps", "\[Rule]", "Infinity"}],
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox[",",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox[" ",
       FontColor->RGBColor[1, 0, 0]], 
      StyleBox[
       RowBox[{"AccuracyGoal", "\[Rule]", "11"}],
       FontColor->RGBColor[1, 0, 0]]}], "]"}]}], ";"}], "  "}]], "Input",
 CellChangeTimes->{{3.419321652171875*^9, 3.419321664640625*^9}, {
   3.48194459459375*^9, 3.481944598484375*^9}, 3.481944688484375*^9, {
   3.6410986439477825`*^9, 3.6410986489165473`*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"NDSolve", "::", "mxsst"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Using maximum number of grid points \
\[NoBreak]\\!\\(10000\\)\[NoBreak] allowed by the MaxPoints or MinStepSize \
options for independent variable \[NoBreak]\\!\\(z\\)\[NoBreak]. \
\\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", ButtonStyle->\\\"Link\\\", \
ButtonFrame->None, ButtonData:>\\\"paclet:ref/message/NDSolve/mxsst\\\", \
ButtonNote -> \\\"NDSolve::mxsst\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.6410988685577593`*^9, 3.641099955998275*^9, 
  3.6411012136894836`*^9, 3.6411016461908255`*^9, 3.6416467328035645`*^9, 
  3.6416476353530955`*^9, 3.6416942861952763`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"lsf", "=", 
    RowBox[{"ls", "//", "Flatten"}]}], ";"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"TLneu", "[", 
    RowBox[{"z_", ",", "t_"}], "]"}], "=", " ", 
   RowBox[{
    RowBox[{"T", "[", 
     RowBox[{"z", ",", "t"}], "]"}], "/.", "lsf"}]}]}]], "Input",
 CellChangeTimes->{{3.419319097328125*^9, 3.41931910325*^9}}],

Cell[BoxData[
 RowBox[{
  TagBox[
   TemplateBox[{RowBox[{
       StyleBox[
        TagBox["InterpolatingFunction", "SummaryHead"], 
        "NonInterpretableSummary"], 
       StyleBox["[", "NonInterpretableSummary"], 
       DynamicModuleBox[{Typeset`open$$ = False}, 
        PanelBox[
         PaneSelectorBox[{False -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquarePlusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}]], 
               GraphicsBox[{{
                  GrayLevel[0.6], 
                  AbsolutePointSize[5], 
                  PointBox[{1, 1}], 
                  PointBox[{2, 4}], 
                  PointBox[{3, 2}], 
                  PointBox[{4, 3}]}, {{}, {}, {
                   AbsoluteThickness[1], 
                   Opacity[1.], 
                   LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                  GrayLevel[0.7], 
                  Thickness[Tiny]], FrameTicks -> None, 
                ImageSize -> {Automatic, 
                  Dynamic[
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "10000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}], True -> GridBox[{{
               PaneBox[
                ButtonBox[
                 DynamicBox[
                  FEPrivate`FrontEndResource[
                  "FEBitmaps", "SquareMinusIconMedium"]], 
                 ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], 
                Alignment -> {Center, Center}, ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}]], 
               GraphicsBox[{{
                  GrayLevel[0.6], 
                  AbsolutePointSize[5], 
                  PointBox[{1, 1}], 
                  PointBox[{2, 4}], 
                  PointBox[{3, 2}], 
                  PointBox[{4, 3}]}, {{}, {}, {
                   AbsoluteThickness[1], 
                   Opacity[1.], 
                   LineBox[CompressedData["
1:eJwBMQPO/CFib1JlAgAAADIAAAACAAAA4ScLwZmZ6T/ACPskWpOYv4AjHgZ5
3Os/cnpQh5xu1j/qWn1XCVDuP5K7ih5ptuc/r+pongFN8D/CUK87BHLxP46d
cUQ/bPE/ujUa8/qu9j9TbqBw1aPyP/TWyyAhFfw/neDJZqDG8z+QAqdF9GsA
QM1wGePDAfU/VsVD/9nXAkCidscSKDf2P6Bp73exDQVA/B1wDMFX9z+TpM3k
wfUGQDzjPoyykPg/7M3Z+O7ZCEABSgjW2LT5P3pl9LwNcgpAbCYw0z/T+j86
ypori9cLQL0gflb/Cfw/lpOs9xIqDUCTvMaj8yv9Pw4alcoYNg5AT3Y1d0Bm
/j+pB2LLtyIPQLClAv7Nmv8/NnA5bbjSD0BLO2UnSF0AQFrcILXmpw9AsTLc
klX5AED+sDHBQukOQNp6UGP9igFAbZ+lR/sLDkD10dd20SgCQNHi3Mj38wxA
42MO5MXDAkAZdr6AZb8LQJRGQrZUVANArv7zEMKHCkA4OInLD/EDQLBlMO3M
IglAnnrNRWWDBEA3d8OX6skHQNf3wBnbEgVAD3D3ndNyBkADhMcwfa4FQHOK
7Wak/wRA8WDLrLk/BkC/MhCgYawDQNJM4msi3QZAwss/TmVLAkCGc6iEq3cH
QIsIg92+BgFA/OprAs8HCECrPCvgePD/P2VxQsMepAhAKXVLE0Xg/j+RSBbp
CDYJQPRz0a7WJ/4/kFqZaBPFCUDN4sX5uLj9P4J7LytKYApAvh1MbRmT/T82
7cJSG/EKQHzT1YZwwv0/3W1pvRiOC0B2LZ/10lT+P0c/DY2wIAxAVrX8MJA7
/z+DS2C2aLAMQElWzbMzPQBAsmbGIk1MDUCi9bAadCABQKTSKfTL3Q1AYexd
q+EpAkCJTaAId3sOQFyS/ndEhgNAQAPGdkIWD0BHWcLdahwFQLoJ6Umopg9A
vd1CiejSBkCTjw8wnSEQQPiVkXD08QhAq0KpbbNqEEBsk2Azxi4LQCyTGthZ
shBAYCBYjj+gDUAnaxVkFgARQMwfdA9ySBBAg+uOIqBIEUBj/5rHgMsRQNFn
q5SZmRFAL++xNeOlE0Dwt3AR
                    "]]}}}, AspectRatio -> 1, Axes -> False, Background -> 
                GrayLevel[0.93], Frame -> True, FrameStyle -> Directive[
                  GrayLevel[0.7], 
                  Thickness[Tiny]], FrameTicks -> None, 
                ImageSize -> {Automatic, 
                  Dynamic[
                  3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, PlotRange -> {{0, 5}, {0, 5}}], 
               GridBox[{{
                  RowBox[{
                    TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "1.`"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "10000.`"}], "}"}]}], "}"}], 
                    "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"scalar\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"5", ",", "3"}], "}"}], "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                  RowBox[{
                    TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["False", "SummaryItem"]}]}}, 
                GridBoxAlignment -> {
                 "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
                False, GridBoxItemSize -> {
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                GridBoxSpacings -> {
                 "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                BaseStyle -> {
                 ShowStringCharacters -> False, NumberMarks -> False, 
                  PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
             GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             BaselinePosition -> {1, 1}]}, 
          Dynamic[Typeset`open$$], ImageSize -> Automatic], BaselinePosition -> 
         Baseline], DynamicModuleValues :> {}], 
       StyleBox["]", "NonInterpretableSummary"]}]},
    "CopyTag",
    DisplayFunction->(#& ),
    InterpretationFunction->(
     "InterpolatingFunction[{{0., 1.}, {0., 10000.}}, <>]"& )],
   False,
   Editable->False,
   SelectWithContents->True,
   Selectable->False], "[", 
  RowBox[{"z", ",", "t"}], "]"}]], "Output",
 CellChangeTimes->{3.415780119171875*^9, 3.4159446794375*^9, 
  3.419318056296875*^9, 3.419318949625*^9, 3.419319226578125*^9, 
  3.4193197743125*^9, 3.4193204425*^9, 3.419321832078125*^9, 
  3.419321887984375*^9, 3.4193318648125*^9, 3.419332894671875*^9, 
  3.419334338125*^9, 3.419356118*^9, 3.44738549203125*^9, 
  3.447387213703125*^9, 3.44738804971875*^9, 3.447388422890625*^9, 
  3.44738897890625*^9, 3.447556611640625*^9, 3.481944639109375*^9, 
  3.641098893198454*^9, 3.641099993560882*^9, 3.6411016983941154`*^9, 
  3.6416467863505993`*^9, 3.6416476805409756`*^9, 3.64169434160147*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    StyleBox["die",
     FontColor->RGBColor[0, 0, 1]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 0, 1]], 
    RowBox[{
     StyleBox["Gesamtsicht",
      FontColor->RGBColor[0, 0, 1]], ":"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{3.419317993390625*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"TLneu", "[", 
    RowBox[{"z", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"TRand", "+", 
       RowBox[{"1.5", "deltaT"}]}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Axiale z- Richtung [ m]\\t\>\"", ",", "\"\<\\tZeit [s]\>\"", ",", 
      "\"\<Temperatur [\[Degree]C]\\t\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.41931803553125*^9, 3.4193180685625*^9, {3.419318245984375*^9, 
   3.41931825771875*^9}, {3.419320803140625*^9, 3.419320803796875*^9}, 
   3.419321808609375*^9, {3.447388011984375*^9, 3.4473880125*^9}, 
   3.6411010224545317`*^9, 3.6416463988651304`*^9, {3.641693901773879*^9, 
   3.641693902852002*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx0nXdczt/7x5NIIqWJaCgqpK1U931KU4uK7JKRFYlsJUVFQkVkZJattAca
RqGkkhFFQzTNSka/+/P5nus6uj8//vF4PDuP8z7v1/0+17nOdcal5LnGeYmg
gIDAV2EBgb68/0/PupweOn4dJ+miXv0rL2uuAP23QpNzVNX2BpefX3n/okfF
Nv8/XCVLSjfd++F/eMndsckqtmX/4Xs07z7yrqr8D7eK8XyX5l3Fx2eTPv/+
/+Y/3D2lJFzFtvY//OayE8NsI+v/U/+Ikavivave/YdvfjJZN1Llw3/4s10i
uWnezf/h+pOf21eltf6HH2yLf9HT0/4fDjoneB1YMtV5N5Hr7x+5eMwdU9AZ
+KylciPqYzhc0Bn4Um1tD/I4lgs6A69/YSWpcKyOCzoD19HxMxudIEdAZ+DX
h53pOK5oQkBn4BetDPSf/XZCnYH77FoZpH3QFXUGri9gHNDc5YQ6Az9j8FSj
n7QJAZ2BF8rezJhzWI6Azsi9WlsEQ+u4oDPwgcM7k2uuxHJBZ+BfV33/0M+L
wwWdgetOGvr5u8AdU9B5947pl2ydD5My10MPN49ZzAGdgf+weXvf72cq6gy8
z94Ns2ZefYc6A395OFA/e5cYAZ2BJ6m6b9zrNA51Bl4oc33wo/0EdQZOLp79
dLfcDnUG7ileMcMiYBrqDHxsYnLl3FI71Bm4sVOkVvxegjoDl1gp/7mP5TjU
GfipmS+HHfETI6AzcFuf5LyuE+9QZ+CPnI3WGzalos7AN032bM2WXMwBnY8v
bRVPv3mKeM56VHdkUgzqDNxH2GnK4blvUGfgn2NyTa619yGgM/Ct1d0f18iN
RJ2B3w0qWf/imzbqDDxtccgyrz5mqDNwjSGe8YmvbFBn4EacZT4ndOxRZ+Cu
epK1Pi9tUGfghXGv9jj+ZjoD1xKN/l7/URt1Bm744l7f44NHos7AB9R4NJs0
9iGgM/CzeyseOzm/QZ2B35Q3ddFXj0Gdvw26YW/rHE/OqnwJPX8nEXUGPiy3
aoZa3RfUGXh6delkyVHiqDPwZ1vIlGh5FdQZ+JOMiSkJs/RQZ+DBI1e9XFbI
vmfgmQWRkufPWKHOwFfVBfX1FLBFnYEnLVP3ED5thToDt1V/dbrPPaYz8N+n
lrZMcdVDnYE/7TIeWiCjgjoDj9HeO91IThx1Bp6zXrEq5uUX1Bn4cfm2H29z
ElFnx+QNoVXvLpPTLrVteftvoc7Acw0WzmlKECCgM/AR4q+HTCiWQZ2Bl+rr
Vgpy1VBn4BssDV3Mz+ijzsDjmi2+lroynYG7nH8uPPidBeoM/NElhX2+161Q
Z+BOI9s/P6m3QJ2BVypKlNY5M52Bp61Z5LDqpD7qDHzfA7LawkgNdQZ+62bA
iLX3ZFBn1KdSeZj6GQECOgO3erpRPiT4FupccWVkbdrNRNK/WTw+Zcw91Bl4
/eALIR4DhFFn4PJfDngGr5VHnYEfl796/oXBONQZ+LCATRULrA1QZ+C7Rjd/
WhbHRZ2BN/Y50kdhxxTUGXhcsNmpz+8tUGfgPhz9byoBU1Bn4G7BsWtNj3NR
Z+Chr5VuCFkYoM7A58b3v7BEexzqDHx3hNrEDSvkUWfge/eeF7jXRxh1Br5V
XKdMQPEe6vzva4QmkwBn/5ZOvUeoM3ChM459fwYMQp2BB0eLPVy8QRF1Bv75
wFGnlzYTUGfgYdwVZ1NDmc7ATSZOmaQYyUGdge8Omfpz+Sxz1Bn40O0bs738
p6DO2P7HJb4n3MxRZ+C1E85FbtjPQZ3xvY6b3ryzi+kMPNqzQrFwygTUGds5
q16s3lcRdQZ+4orM+EGbB6HOwOUeNq8vmPAIdR7vUjvS1jmNiHd7vH4VXYo6
A888t/nJWF9x1Bn47U3zTt1SV0adgYvm1AyVvaKJOgMXSiBXlPcynYHHTzPv
LxZhijoDt/xETjxfYIY6A1dNrMra4GqOOgM/v22bzwReedAZuETbF/nCvaao
M3CBxXI9e0KZzsCvuTyyXJ2giToDX6Hio7pwjDLqDPxn1ck5yavFUWfgBn6f
hY0OlqLOs+LvGEfKZ5J7l58NmxNYhjoDn1jdJCGnOBR1Bh7XvdpVfulo1Bl4
ZmJ5tN+eiagz8M6swXbrFzOdgWs8vPncPIb5z8BtNm+a5B5KUGfg+7LbdxXP
NkOdgcvsHuRbHEJQZ+D3UzmP7Q4x/xn4qvPSxWqeTGfg13xuPtDfPRF1Bn51
V7DmZ8/RqDPwx32qVO7ID0WdgdceXmtVur0MdQ7+Hj+76l02eS7gnLS/rRx1
Bq5kovVJa44k6gx86uG4X85EBXUGLqMxx7ysjxbqDPyYkaOxqjLTGfjj9WNs
Zl0zRp2BG8zYlGIay0WdgVcP33C3ZCdBnYEfum0kb36UizoDX7Q10PT0FWPU
GXikbuDSEYpMZ+DuIpbzinqYzsC3pk+vWWSqgjoDv1z8S0fMTRJ1Bt6+cNtX
veZy1DnRPmyjStItEqHsqznpYwXqDFzszJD6RF0p1Bm4UWiO0JGHTGfg4zfk
fHkty3QGPtAxLqz1EfM3gMfb+ugFl01GnYGXjIu9edqRgzoDt59X8uhiBBd1
Bt63rWXlPQcO6gy8226SseCTyagzcPcpccXyD5m/ATzkVNxuBRkt1Bm485Ou
We8Kmc7Ahy+bFHVfSwp1Bt42L/2QTGsF6tz2OPVB2s1ccq92/XeJ2KeoM/CY
Ftsz3beYzsAvt/cVWSWnijoDV9z/WfKIONMZuP2aNfnXVzCdgQceOJOzS5Dp
DFzcIj6Oq2qKOgNfPMkmtNmcgzoDX50v99NfxRR1Bp7a52ikVh+mM/CGUOHB
EsuZzsBr9+Ua9xvCdAaewxnQv1NaFXUGHqG2PsYhh+kMfGFgg7BWzNPedkM5
n5yS/HW9+NfT3naDxws+7FdRHSTd227wePH68BMb9FR72w0e/2oqJ2v0bmJv
u8Hj69de2r2nR6+33eDxxNDTvwaZGvW2GzyefzffYqusSW+7weP2G2ZrRg0z
7W03ePzoivDhT2RMetsNHj/4sG1StbFRb7vB45lLQz7I/tbrbTf+qf+Cpumi
Oj67wePn+krEGeuo9rYbPL5u4IOGZBHp3naDx23rJpRr/GA6y48+8r4npID0
VCZe89CoRJ2BL1qZcfKcGtMZeL/8F9fvajCdgWduuqhZGcZ0Bv5l0/DjfhFM
Z+CXl+4d27DDEHUG3vHok46xojHqDPwMt9jik6gJ6gz8RvMQs3MKxqgz8OcO
3xOeBRiizsC1IhRENfYxnYHP+hXe1zaE6Qzc6puXVJ4a0xn4SochuavGMJ2B
L/Hp29A9tpLztmfTo3TvbG6TvtgrO+cN5MK+L0ui1yVzlk3fOGx11T3kgtYD
9LYnuXB9JGaPERAoRf5Q0uLSqIE8f25LB9c2sgL5huULbywpG07O2Wmvq0p7
jXzJu8dxpsozidYcL6tIlbfIi19IbR2pOJO05At5VKU1IL/WUJEvljmcTN1Y
3tLT04jc785l5eg3D7gXxp3ZrGLbhPz7wAyVjt0u3P5vfPrbRrYgl4k3naBr
msxpyOz/aIztGe6El+Gr028eIKZV3fdbf3txQQfgM6c61iqNSMR6gMvq2Kfb
iSZyF0Vzo7yr2pCvzTLK9qv14kL9NWNk3lW9O0bGW7bumBmaiuWBu/vWjbq3
KRXLQzsv2sYs/Or3AeOlwBdNLbDsuOGC/QK45Yk3W+4N224C3z9wabLyrNH2
ARjfA76l2WGb/LRojKMCl1t2tertmk78Hfnjuu9ro2ZHqrzA8pP6GmYfdrQi
wKF8/PH8iEM2O8fB7/63+DbUc0Bpy+Lfh93we+AvHyFmUJ7mXYfl29dZv2m3
sEIO5cOsjThjJlmMg+/nb/FwqGetX824z86dXOhfwHXWXHoZpxGNcVrgp2ra
kyLJAPwdgdtcz/GPGfXBFPoX8K99xNWjr20zgd8RvhNduajOt3YRXOhfwH32
eH8wi2nkgm7AB9Sbx/q4Tkd9gH8m+qXjXKZjfwc+wUxkwxeNCPye4XtTNj/f
YPeuDusHfiKla6A91wHrBz45NunjPVMH7L+FmY81BULPkkNRS890Z9tieeB3
Z9/q+JJli+WVPaJXRMpfJB9+iC+LMLbG8sC3tZeGlUy2xvJb+8+OV0m6Roq9
Fu04MtMSywM3X3n7khCPQ/kVlWJrq5RvkAiPlgm6z6ZgeeDr64te5lROwfKH
1T9FqLSmkKLorSG2J82xPPCaipcj358wx/L528qveKenk2eNd739j5hheeBh
x77uGM/jUP5fPyEwi0SGdO4UyCRYHviLVUu2ZmUQLD/8Hztsd5NETLHJKWvl
YnngUpw5u2bzOJQfbWwapCKaS5ZPbh0RF8PB8sBP7NKbpM/jUD5zseZQW588
kjXXreTdElMsD1xiW9G5MB4H+zMtQuG099N88mTjmMGGsv0I2BngETEu69SG
V3KgfuADVCft3jbdBOsH/nz+BSUNHofyMO6YHfYWDCg1xvLAax6oLNPmcehf
UI/4uZ0rK6X6IcfxK3nu8tvK/bD9f1t3g/64/46n+sIUPRyXgdfIl9U6XJiO
9f9tHRD6110rkq1+vJgLdgz4VVcNxSRjZwL9HfqRZ/fT6o8/H2N54FFbFayL
nB3RHkI/2hJLHhv5TUUO/SXjSUPTrnxr5NAvRvu0//S6ZYkcvn+j8Ncauhos
jgrfefeQa+nHa1k8Cr7nd6tOPh5UZtbbP+d9t/nH5vmsbGLzffg+2+1mnRmo
zDh8hzrHv9b21LH5FHxvd1bXOCy7xL43+B0tu/w8hFT7YXn43U/pl0Sd32+C
fgvw/p9GbT0nW8n5pbD/e5p3OXdtmUiRo/NS0hqns8Lh4Wvu3Ir5u6vSniL3
U30iHzJDipSfP5LpXVWN/KNvhLph/Cwid1V3tG3kG+QyX7KUrpyfRWyEjy2v
SnuLvEt+sYvz/JlEyMcwSMX2HfJvov0KQ/fz+lvoeEkBgefsueVvnx4baIT1
8I9rL0tjtNVtI7H8kQM6dZfPTjeGevi/Q9AHyleofLnjXj6LbFgomOhdVYt8
06BR5+0uOpItZuvS0rzbkXu0RQsGjZ9uDM9Ne151J02zgMyW0tW6NfIbF/QB
/to7Uuy1qQnWA3ynimq814hvOL7AuqSzkUJp4M81OK4B92+LVdsplo/rbtDv
jqyb2Bnr58IB/wrKB4gqrttcsgb9IliPc+v2SbkRegTXNdBPO3d0bq67Fgf6
L5QP2WVpe8mXlYd+57V5T9RHbhBnTEzVjdVVaVzHvIfqGTd3kGer3f0TxSWw
/fz6DzxxIdw28g6W31x28kb0qyD0h/nL71xdd7sqrRj1P737R3rYHl1u3Mrc
VZEqT5BbLF7f7XkjkgvzC9BHcvHKR1uuTMf5AvrPKwIDV8froT/M/1ydB3FF
ad6NWP/vg7NUlgRGcj1VhMVtI98jj5lT3S5hp4v+M389B/xXz6xK+4Dlt+4w
C3q+NZfTpmNa19PTjDq4Lnbwcf7pgL8X/I43O6yHhzoKc2Ecgd9LrnCfmOp6
LQ58h3MmrAkXCI0ip0p+q0w6sYYLv4uA2IzTr97tJS9i+s/tq7+T66gnuk5A
IBe5kMe3niiTBPwO4XcfZj7xrEpiKXfUvnPqkSqtWD7hTe7Bc6N2ov8G7Zy+
bLbmKVVhrn2jqI+KbRuWz1r4foNTgRtyaGeR9nGJwaXR+F7wXblZSDg4OgZx
5u0168nwvsy9Ua5bGCl/lChtdi+rakvjQj8CfqV9W/7K6YewHtC5pbr7bNG9
DqN7/aziI1WKUOeQc/mxKtuSubKmP+JUbF/i7zIkz9p3Z5oj+uHAb244+O6a
niWJz17e0dNTh9zbr/L9ha+GyPl/d/Crofy27QvPqY21JPBeoEPsrvr+MfXR
+HsB//qA6I4+lcwFuwp2Q8i77VHKH/aE/7nwPcC4YFDXXtM0+huOm1CPwYFt
dmIObFwAvk1Q+5OxUiV+V/z1g57wXpFhGm1lObkcmB8B57QWnX5z/CfH71PR
eNvIV8jDP01J3OAxE+0tvz2HeQSUvyIXerLW4CcH2gncyux8jqB6hxHoCd/b
G9J56WKdGxfXrSjPvVYzunPcavTb4bs1Lh/zbrebC/pRuJ9kibh/yQwXHNeg
nsfSs313D3TBcRC4wfhoxamiLmx9inK5mJnPDji5sHUi6EdFgrY9Qqw90O92
66eEtsc5YXuAm/7adqXPSSdsD3z/t+Viy7IsnLA9wBN3i80/Zsn25wCvS+Aq
vIxyQn8S9g+obu/I8nOxw+cCX2xXUmXkbIfP1TlQHVelfIZITJ8U8VDaDp8L
3OP06LkLZNh+FeDDgpOfb7S1w+fCejpnwoPs0EU2+FzgQQ4jhC552uBzww3O
VnmnJ5CDcxUfBxrY4HOBH3L0eNxkwPZvAF/l/KrOZ64NPhfWl2vy72+5ZWSF
zwXu/0HxtwyPw3N5H6esgP1VsnbO0xxpWSt8LvCMyoLNS2TZfgbgy05anBql
a4XPxXXeiN+tgeEW+FzgkqPW6/3ea4HPjTM7rG7rk0QKIp5UPPCxwOcC3xGs
91NkLfNLgadZedb92m2Bz/33z6HJpHl7jJibLpvfAY+7m92vRWcKPvdh9Cbr
yMkpRDmw0zBEfgo+F7jxkrySLHm23g1cImfw50uabJ4I63Fzn/840iTN5onA
H4Wt2XSQx+G5nY1zllQJpRPF8Y4nUgTN8bnAlxvOvFkjyPxt4EP7DVJtkGDz
TVifmpUiveawCptvAlepflI2lcfhuf/6248zSfLvjcHDpMzwucCdxPcbcKTM
evvnPP7qzJA1kkps3grrNeFlXsezXNm8FfiPxpLwzTwOz3X6xw8/mkOM1CMC
Z1kRfC7wQdIHx26yYvMC4KMd8wTiprP5L66niFt+OG3K5r/AUy17srR4HJ67
9W2f22mLbpNNDz9/Hq/CxecCd3/3cthiFbZeBjza1nGZuCG39zz9Zi5pU7/d
/0a3ae95Oo8/niVw35HH4bmuw33bemTySEto9oo3dab4XOBpmm+fidezdQ3g
forx1+O/meI8GsappaeeZSSOZvNoiHtfPj7Tf9lzk9768/j0ldpt4jwO7Wma
smi7yrZ84j10+9n0AhNsD3DRzYe9agtY/B/46N/OVQ/KWXkYZ+/ol9RK/TLG
cRm46/bxJ88ofUO/C/yQFIuBv210HNFvBL/OXPSF1tvgRuQwHl2aWjJrbHce
+mNQT5W+aENUmziOd+A/mCyKuTD71DkujI8wjrx79bTn+s8EjMeC33XA6fnA
oS/rkEP58PWpbQfOlqLfBfX3d2xY/X3rGvQDYd49L/qjipdoJXIYR2bPUzk9
P7aQC/4D+OHL9HcMzlf2w3EQxvcBunYHmjrcSIX0E5NIlQY2T5wz61q6oRQB
vxp0iBNQy9mwMBnfF/T0+zTql13mVvSvgCs3xj+xLovD+CTw1U+cGmV3FnPB
P8dxXH2cQrtyAhf8IvRLR5alfvU8hH476FDv5r2yWqYSOeiguVR7mdXFQpzH
gf47QlRSljU+Rj8Z6h+Zousz4nUa+qv8/hJ8h6BD35dzxn2+OAO/c+Cjx3Ka
Wy/MYPvBKL94Z1DpAaGZZNCWNYP6CCRy7/T1/1WlHEk6y1/ZtYyO5BbWDhoz
NTIFeU3L6s3di8/gdwjfwyiFrGd7I5LxvYA3Zc598TX8HPqx0C+2XT9R2vrT
GNsP5Se9379PY8R0bD/wpaFWn48Mn47tB35E4+2QTw7TsZ5BW7r6qiad5M3L
vNTffLPHeoAfCBonO4HHoR7g23Yki5nqOWA9C+pyb6q0niN7juqNnBBqi/UA
P1fJGXojxBbrAf747lfzXzdssZ6MsF3f0wIvEePfGTVxUtZYD3BXrlm7hRSL
RwF3e34skatnjfWIyJ2PVRFNJBpW78z7GFpiPcBbzJqPZ01i8Svg+XPd1x+Y
Zon16K8MyfB+eoPcqf29Z+4tNu4DXzf7VILyLTa+A78f+sxKuYz5AwtvLa9M
i0sl8yVnmsWEsXEc+NKDZvrLwth4DVznQ0z3t6NsfN8nYf+1Z3kGKRo+v6lu
NxuXgQvLiBnk7GbjL/CI5sHSt6LZeP1vfEwvm9zfNzWt4CIbZ4FP13lz7fRF
0juexuPpIn2UU1LZ+NuQLq4V+fsm6SuyrlSknI2bwB1I1MOSMjY+AjfPK37+
uZGNp6G7vsd7L84lQarrB+UHcLAe4C4Zc5dHBLD4HvA3dh9Gu0ZysJ5R15v0
I4vySHm4g+3CaWw8Be64e16J7jQ2bgJ/lrirj/RCNs6CfVseIiM/sI8zcrA/
Rpe9LHQHOyIHO3bue3DiQaupyCGO2q87Su/IKfZ9Qhx12aoglVnn2PcGcdTB
Gvu6FkozPxbiqEaLnQZsf8K+B4ijnuIIm50pYL8vxFED/d44DKpmvxfEUW/6
cM9yZUlv/000l5TO/3SjvpTT+zvxySNhTgGRVkeZPhAXNbnkLTVihwnJff70
uHdVE9rJ70Oco81vBnGBw7iwp+vtYIUnhWgPwW6/z0ntf28/GzfBzhhaRfo7
pV3jQhwMxjXfiaO8zV0n4Xox8KRqebkzlgE4j4b2qNWumzCv1ZkAh/FUKMxa
Y62FK8ZFoZ2WWw8vfWU3Fscj4MXWOgEljWbon4Bd9e8aXWQxphTjQsC/OC/4
0SiVj+MsvNfXqfO3T/MtxjgefG8S93IrOpIkCXDwZyKyddRHG/fB+Buux2WE
3w6Il0QO5QUE73z4MJ7t/4fylw0njFR1FSDgV8B7VQpHy+3f/g79Dajn5ApZ
LXWXcoxnwncelL38fP7C8xz4vWDe+tn5/caTQbcx3gj665U+npKZ1IPxQOA/
jlzXddvxCnWD+hWMmgZrW/9APw341e0XgrNNmlFPeG5AZ8ZbVa1XuK4K77vu
bszPQbYCBJ4L7yvh3XwncVgfjF9B+R9XWk5ov7XCfRfAPavyXl5IdcDvB+o5
TQ51H+87HevB9ZcPZkuqX1liPbi+edt0Psd4KtYD33//NxJvPzXZYz3wvhvD
3YbmHrHAeoCbeDxzzLtijfWADlNH5Jzt4o2/UA/Yn9ZdbxvivKZgPcAdu/Ie
7Eq3xHogDlD24YSK9DBrrAfs1a7tow4NmG2O9QC/13faCWENC6wH5vXDAx/Y
BJhaYj1g3zolVjwduIqdKwF+eLat/7kGc6wH5umhmgEBXwumYD1gD0f9eL1s
8HG2nx94QPP9lnOVZlgPzLtn/1L06Igwx3rAfk4t76ifVcj2qwOfleDWebed
YD0wj+4s/q7UvtcM6wF7K6pUITNhB6f3PjQefyOiGH5rLKsH5sV3J/wy3XSN
YD24zhW9fc2yWWy/MfAvKQo6V9o5WA/Mc6+GSJ17UsXFesCeb4vdfdDAju2n
Ba47uuP8yDRTrAfmreevVHO6QzhYD9j/4gezZjW5sP2iwK+q+0hNOWaC9cA8
tHt1V8EIXvuhHhgvJskOrixczfbpAW/fWDF42lFjZp/p/PHEpKkiGpYmBPaH
QH/saBlwZCBXF/dTAbdNOycke0+FgP2Bftps8Dqve4IMATsD84vso6HyTfWf
cL4D/cjf/cOFR8HtuC8F7GEIZ/GM7NbxBNYB0X46eg40WaeG8wIovylcZYb7
lUk4XvDHh4FD+X1y+rGlJRFcqeJ8eQGB/+6HyfjLOh1wqMdm7oOLH/eak3kW
h0UEBF79Zx4kQP0fKL+GnkMse633o6eHxXXnGE1uf1g2jZyncXscj1KqH8vv
Nicbj5781NPTgHyDQJVR7q3xxPYv60QjZgx439Pz33OgrXT+yM9vi/tW9/T8
9xwo6Azz7vQR7+qW/kpEnYEPGi92aVm/Gm7M5Wp3AYFC5NNG5Ax7qtsPx1ng
KXfdlbdvUiKgP/CqQQfjUr7qEdAZ+GLjK7sfeExBPYEvpOcNQU/ga/uOsb9b
YI964rm/hOGx5fOmoJ7A3x+XIQ5teqgn8CU7bH/qrlUioCfwDJvpno5q/fA7
hO+8Lf2n9p6TVagP8JJ6IbvRtd2oD/A9jQJnDMKlUR+MbxsPXvvNWB31AV57
YunG1O5JqA/w6UN+pxt1maM+eI6PnhMEfYCP6A5UXLTJFvUB3mpxSdHtG/ve
gL/4rSQ09dsk1Ad4SN6ubjs9ddQHeNxa/7ZXQdIEvjfgkm9E56o2/OSCbhBX
V4u6uKpg6SfUDbj0va+1gRcHEtANuETrqD0CExVQN+AmHY+fflqqiboBP/dh
9fp0ByPUDbj4/dT3nRymG/CV9Nwf6Aa88a2qiI+ENeoGXGXzGokCE6Yb8Ngp
qlfH2RqhbsDXngj2O++uiboBT1R3nxGmqoC6ARd5kfLtQtxAAv0UuLqGQR9L
90+oJ6wXXDtrO/el6i8W36O85bO2bI2mJOoJPGH9C8OX3qNRT+ATP6rVvH2j
hXoCV3xlMK7/XaYncNGX6t8VNpuhnvzn+0BP4PMOZOvXGVminsC/xRXOct9o
hnriecPfK8I185iewHc2mZmHvNZCPYHr+op39ywbjXoC11K/0zlMXRL1BK7Q
v7964YhfqCesg6z3EzjrOlaIgJ7AJTLezploIId6At/oLvzygNsY1BN4yu6E
8iWftFFP4LnbguI8C5mewB9OGDXicTZBPfnP8YGewOd0CFnOzZ+CegI3NWu0
9sgiqCeeK5Rv/z7sLtMTuPuRoQVz27RRT+CZ+VVJT53HoJ7AF8qvWyShJYd6
Ai+uKl21T0kI7eS/rxGaTI7fdMz+2T4A9QTeP7kn8bCZPOoJ3Na3wbRtsxrq
CbxP8LElBw/roJ7AVx6tijUNZ3oCjyl/GPVuENMTOJzXAz2BDxi8R3Ytz48F
PYFLWyaVJ4syPYFnDbXw9gpjegK/9K58aUWUDuqJ5RcMj/X1U0M9gXfPfnFs
o7E86on6LGivbvowAPXEc3ku7z/evT8I9QRuP+pD/di5Cqgn8JKdbY36P9RR
T+C7zJ8Pj/nI9AR+yqpP2+TxTE/go/SdyztecFBP/nN5oCfwj9zNvv3DzVBP
4G+0vhW3POOgnsCL0qc25akzPYG3W/WIK7UxPYH/yLs4W6RTHfUEfrn1cQRn
hgLqCVyz4aViVt4g1BPW4yZ7eyzXyBiCegK/GXPA7EipIuoJfE3LVfmKnxqo
J/BLRdl7nknpop7ARfIm5gamG6KewPsemnrrdKop6sl//g70BD78lemDFt68
BvQEvtDOL7om2RT1BH5AtKF1Rqoh6gm8XnPyi9NDdVFP4NFyaj4/uzRQT+A7
7/iPLSlWRD2BzwvesMftxhDUE9YZBVwbu5vaxFFP4MYZ8+cFH1NCPYF3hg/6
vCR2HOqJ5/i0K279kGB6Ai9xUvDIMGB6An/fMvns9IsmqCf/OTvQE/i1gsi5
mq+5qCdwn/CJfkUJJqgn8J2OSjHFekxP4KNfTR8oIM70BJ74YLlD3eFxqCfw
2X1fX205ooR6Am/evj56fIs46gnrp+ryqz9NviqBegJfNWeIopqCMuoJ/JGV
r69mE9MT+Ijaq7eWfGb9HfjiK1dF+l9nfibwiflZh/cmGaOe/OfpQE/gn4KS
ek6FcVBP4NtTFlvrJhqjnsCPWWVUOl9lfibwb2sVNE5+ZP0duOazc0W/3jE9
gQ/Yo5R6V14Z9QTudOHSg2uXJFBPWBfuLNPbPGLsUNQTuIv2oLlaK5iewAuv
TDv+7hfTE7hBj1bz2ZtMT+C3j5kLnBrN9MTzcdsX6es9nIx68p+bAz2BC18o
a/s82xT1BF7/qWu80IPJqCdwPZlRNfLKTE/gS0UXq4jmMD2BNxZ+Gd/3B9MT
+JiU9Z2Cy5iewGP7pgy5ozK0d39XzifNId8vn1oxtHd/5/Ey1+zY16HKvfs7
j+8qC1I/UMfX33l8ks2IMJfNOr37O49rDLded+ywQe/+/s85u2fL91/4YtS7
v/9xPq5Xf+fxwkt+Q5SsTXr3dx531T38MfazUe/+zuN7x7dZmR8y6N3fedx3
/pA79Rt1evd3Ho/aU7fw6xu+/s7j4kL99ep2K/fu7zz+YpTwoe3LmJ6wLhk1
ZFhf+SCmJ/CPC7Keqe1ieuL+uugRPRPjmZ7AL8Smz05UZ3oClytb7OMuwvQE
biqw5FKWGtOT/xwc6Ancf/TTPfftjFFP4E7fOCUPxjI9gYsbfFIdN4DpCdyn
/zorLzWmJ3C34TUilWeZnsAvvnXyWhCkjLptkbpm3Sc0iOzS51g3fzLgQvtP
0PiJL18cZjUtHzFz6zX3XdOx/bY0fn5O+MXkzLFsfqf3qky2+t1WYvDZMXeh
1nB87seZHiNUW6OJ54rYsGP6l3G+X0DXqd1qbJ0Pj+jC9gTSeMIivjhGE63n
5GKlope7HLA9bnS9Y/tWk+DOpRbYnlxYH3+asdd3sC6258mT9UUqoqfIhDnx
nhoZz3A+KErXRza/Vzcw+9CB7fSbJuwnYH+CHJydL7iUy9ZHIK5+Ks2/6sA9
Vfx+bH6puKUHxhJH6+TRH2z18TuJpfP9yXzxhxLanrLirCVWX1j8QYS2p3ZR
2esnN1h8xpe2Z435ily7OGbHXtL2vGru+d7YoILfyRTanpKiVe/1c0VQB41N
Rv3S486Tg+dHjH1k9xF1gPXx36vs/Gva+2M/ina02RA5+RwZmLa+5+IOedQB
1gV8fFYnFpwchzrwHtvo/fQM2aZWFt7xeBLq8IXO07354gljaXu+nyvZtdOL
xROgPWItH9aOfMi+t0jans3HG+YuWcf84Xu0PaeFb+y0+jkOdeim7Vm05aNA
jLYc9peJNO56d+ULt8AnPTjPDRr1m9jqXSa1K5K5f8YNYN1fOnTKdKlZQ1Gf
1q+Dbqg8vkgWj2v06DdBGfWB9Y7anc/XhydORH1mPhwxWmDFBWIU/CSkX6ch
6mNP593FfPGBHbQ9rw8myE3fwuID6bQ9JTqyKavesfhAM23PI4uCD8Gyk1Ef
BdqeMUEFEusMWXzAhbZn1Jp9imvKFVGfULouM3LHUfLGfhDa55zTGtFVQglk
xfq78n/GW1Z7LrzlvTiRyJSYH/ozPgD7HMa/NjykuEIWdbM69qQ1bdF10nhu
15ZcG1XUDdZ3BAYXKfjosvjA9bVvFkT+vkqyZ2WXaC1kdriczq9P8cUBvGl7
Eopial99ZXGAAbQ93zJmhDyUZLpZ0vYM6+v58Koa020zbY/fwuQD+4+xOMBV
2h63YbmtuRtVULe3dB3qfkBK9OBvLK4iY9P+2PvoFTLxxzaLP+MqsalTXqVp
JhPxSTrX/4wDwL6OnW/2mJ2NHIG6lSo+jFbZdoOMVzO2eHJmLOoG61ktSxWN
JYaycU0o3NkhsiiJqAYGz/ZaxHTr+edfyH/n+0dpe25FF9svSWfzfT3anrI3
U1MOzWDz/ce0PWPWvRHQaWP9cTltzyphq4Vffdn41Ze2R7roqNg39bGo2wm6
7hZI3qp1V7P4iWHni34CsklEcmHLpj/jJ/cGjOnu6UolI0t/v/tzvg/7WBaE
ffU5UTIKdfu57uoNb6tUYujwadJXNzbfh/W7W+n9m+7HMN20avRWVkWlkC+W
WwvTNJhu4/4yr79L25M6tGKE/DU2r/eg7XGcM+rxOVcu6vaDtif98aqZo/cy
3Q7R9nyqlfh4s4XpNpG2Z+rDiJ15cmxeX0TXGRcb/24RLGRxksVTc0bbvk0m
JtnP3/8ZJ/k8d4CcbUEGsdl0beGf83rct+Oz0+hlLJvXq93fX5omnkGyf4z5
rrWbzethvdL/EaeJ+5rpNk9HNkxlQTqJjG7PufaY2Te3v8zfP9H2rN97T7/h
IZu/h9P2XLS6GjVEgcVDxtL2XBEQ2XtHgumWR9ujGWH8uUyVzTfn0vasXypx
87Y3m79/o+uqCp0L8vJzWTzkwImTZpGX04ia+T61P+Mh/+7b2ZdNnrwf1PXn
/B32KW0f5EfM1rP5+7/rki+zSIxzrO9BG775UWAW+TnglWDiF6bbv/uL1LJI
gkBnkboH0y3oL/P0kbQ9Q/quWZ4gzHTLoO057D42wb0fi3u40PYssyjcNzic
zdNbaXskpI/f7K/NdAuh7TET9RvaOJX5mUp0Hfn3yCnLZb+xuEfOxx3uVX6Z
REp2/IE/4x5TBYtdqtx48+XiFe1/ztNhX9Z172Slrr7Mb9/h7TrI9vxNIrnq
/v6vqUw3WI8Wz/nZ4N7IdEv5Z7/x5xwS15P13Kae+RvX/zIft6XtETG30bmc
yubj9bQ9te836g7ty+IbAbQ9nnLRG6/1ML9rGG3PkBUHNowcwXRLpu3xWD/A
WO8h082BrpvHG9S/GJ3C4hvv/1l3JjlE02zT4T/jG9mXnhkOPZhLFo58u/HP
+TjsQxN8bzH6/iymG89Nli6alEt+NaQOl33LdIP195zP0lVWeUy3N+Nu1fbk
3CYdu3OP91/IdGv9y7w7i7bHOLlmz/hANu+G9hT9bB0wU4rFMWbQ9gzxne0v
6sN0U6btOfv+upBEK7NvNbQ9+qf2DKzvOx5120z3CcgoX/Qz0GTzRKkYy2Pe
A28TvarfD/+MY0yvKLxv0JFH/MV1es27Yd/d+EO+Uw0DmG4tYYPOtR7PI0dP
lWoPesF0g/0GU3c4OkiEMt12c6ftODcljzwxPJMR+cKgdz/9f+bX02h7uq6N
MA1YwebX0B5b2+/L+huweEUzbc8LgTY1sxo2H8yg7Qld/XjGwqtMt120PbeG
ur073o/p5kL3RXj6cPOur2W6KX6Lmje3KZdofd8q/me84sOvzJlz5xaQYIXr
mzwDmW6wnz/H0e/9kUCmW1DyL52hggWExHBmlV1kusH+ig67cskiwnQbudxs
SNGFfLKs+PfOQdOYbiP+Mo9+T9tjOsAgs98qNo+G9ohInxQ6vITNo6E9Bpat
x646Mt2caHtSP8frV3v8MY+m7dFSrfde+pr10w90H8iaK45OW/Yoow7r6H6/
S//eG3OWAzoc3G97KvOmD7GeF3CiKnMK7qMIp9w9Sihs+PVBbJ5I58vn546R
OWQ9HNt/npa/YzDDSThyELa/ku4bnErvgQH+m3Kx+//j8F7+tB6/y9/F9fZP
Qe5Gnyv2Nis68vpZLryvAX2vuvP/3BtzlgN8IZ1f53ccN/SMe86F7+cpnbfe
GnB1mFD5C/Rj/UX7nHV1nknvdSkyBQ77Hqt395/feN6BA3oCD3gVa1Up950D
+gA/1BC06EG0NMZhXGj8QSjU4pjvRHP8fv62zwTvQ6D3rsD3c4S+7356PvT8
/3M+lCROV4PfhX8fCHCoP+Hsa73uAGn8vYD3udv7dwEe/Sm8T1v5RtQf+JDi
2XbbXnZxQGcRqueda//cu1JkCjyMxmdekYzTFsUGqD/sR9poI/FjitRujGNM
WDjptmpSBBldJBC4bGAjF/bnfKFxlY9a8/IHhTlgv3uT5RsUJR9GnH0Kpox2
noZ2A+q/GD756/xRoTgvTqb7CQ++G6zwxLYB6y+n30lwRkiA2zc231e+ZG60
Oj2GXNXQPZE2zh73C42ncYBr6dYbu5dZY/kVP5bMsvU5TZJ+mSYcHGqL5XfR
eXFn1jt3762WWL6Azk8XT43S2HzfCsuvofNB96qpC29+Y/MdeTove6RVd2pU
H0ssf4zOg+7/umEjn8H8fGM6H/nkFds28NAULH+f+v+qsY+fpVxj/q0X9cOf
lR4cqbWc7Y/6Qv3e5grRfl6PmF8XRf3PBcGxeldXmWF5BervPe+z0kJ2ACt/
m/pd9297pgyIJljejvo5N5Msf3mnsXG8mfob+jWBHdbXuFg+h47v5/tk+D8L
ZOOXLB1nm8pvjVL24GB5ZzqucZvHjpVZyey2Mh1fnn20iM/TM8XxJX3UruYA
J974eEv8teCqoVgPjDvdygUhe3l2HurJoOWXe7nM81I1wfIQ57S5XTrG3t4Y
v880Wn7pq/uZb5cPRd5E6z9VsnX+qgDGoZ69Hw22qweycfBv+9ygn2bd+Jqw
yJXpD1zhUW2h2T1nHC+gv3Sm6s58XZGPcU7+e1TguRBXXKPC2Xj72gMsz3+P
CnD+e1SA89+jApz/HhXg/PeoAOe/RwU4/z0qwPnvUQHOf48KcP57VIDz36MC
nP++FBgvIqmdFD71z70oxajbjg+l//6O/8Y5emZhPTCeRtJxAX7HL7QeP7Eb
6hevMb6ejqdd8iNGlAq64nitRctH/HsvSjEXvpP5dHxxp/eiAN9F+VrKof6/
jV/8958An051iKM64HdO38uqyXJgiK0DjuOwTzJ1xNzaa/EROI7jefaZt39U
dCTheMH//UO/g/pDN8z+4dfljOMm8MNSwQck7QmOg6D/v+Op9ikTGAcfUd1S
/71nIxHbOYuO79+W/++eDeAWlCvT+zeg/fBeo163+qzdPQn5XTp+nclZ+kl8
vhNyEzoOdo9Zd+PawR3IO+k4eNj9VIbxqMvIc+g6gtLyaUsLPh/EcVaejl9i
CxWLL/ilIYf4/+YqwcUTs+6inlOo33X2buT+pgdnkcO6TD756Rf9KJsLek6l
v7sZn38C38NeyuF74L8vAuoHf+x/9z8kcuB3tKC8qEtplnGiG9rVU/Q7L7rk
dmtTf1e0SxVUzw1zbiadCXNi/gbVU01g8+Fx53Ygh/3JRxKu/mwQW4L+APxe
9kP8vX2fTsP2J1HuTdehgKtRO3mN2kng/Pc24L4gyn23G+90+bIYnwvfudMj
L7fSe/ZYz17KPeh6E3BYTznEZ2/h3EQtvZ8B6of9nAkaIc0Lt9hi+ZOUT6Lr
PsBhnWIrn93mv4cB6sd8ECdP/Xo9lNnzTr79mcAVqf3P5LP//PctQP2w3y91
VfTi75PZuDCN8od0PQI4xMNV+MYR/nsVoH7Y/yZ4PilnUgHbt/yU8pM0bg98
+V/GI/77E6D+f/8cmkwU7r4mqvvNsXwfyiVofBv4ob+Ma/z3JKBfSuO9Ay9P
lD8Rzsa7CZSr0Dgw8Ly/jI/89yFA/bBfaFChez/v62x8nM0XLwXe+pdxlv/e
A6gf9s9oqkccEq3mYvldfHFF4MP+Ml7z328A9cN+kqr64MKFe9g4nkS5HY2/
AVf+y7jPf48B1A/7K0K2rzI6Pof5A+2UL6JxKuAZf/Ef+O8r6KWPcj7Zlj02
Ks2a7Y/aRbkdjef00uEPPwQ4//0DMN4pUTvprlwdd3HXO5wPFtHx5fZ+TsCp
QV3IwU72E78zqTSwFO0qnO8TiRcZf35oHI6Pl6ld+lhjubSfSQNySbqOLPZF
ZnXe6w7kYA9TNcSM8tqrcbxbROdZRzu6d0z//Rr5BDove+eRMPOCxUfkYPeG
z69bWRBRheMa+ANq1jvnKA1Zge+1FuatU2vTai9lY3vAH579bcvb6oJ85B2D
/2fPhem5fuADqZ2/RTm0B/zkARWdUxOOP0AuTcdr3yCDzxcXpSGfRsfrX1oK
Bj8u3UW/EeIq+6h/CBzOD16g5/GhHvhdhMrVPX98PYn16MD5R77xi/9cPPB6
2v6DfOMO//l34A/oOLKJbxzhP+cOXIWOC+l84wL/eXbg26mdV+az8/zn1oGv
pHbbkM9u859PBx5D7fB3PjvMfw4deAG1qw18dpX/vHkv+/D/2En+c+XAR/zF
7vGfH0c9qR3T5rNj/OfEgWdRu1TAZ5f4z4NDPwJ/L9Sn+XdPWhL6bztpP8ra
KVy/aMN0tGOwD0f+bPu2Zns2r9xA941cPjPs2qn0Eowfgn/VQc/zAofvViKz
Nwe7JE/P+WJ8iZYniQpWDwU/oR1Av7Eg68zEPsw+QD2v3y62WDHnEcaRwP8J
TEktsIpi+zFgnssRafFZptWI3IvaK62gcXoX11Ujh/0nadvyJ3tdqkf7A+0U
sT7xcU7HR5yv/aR2puHVyUG5m8xxvjaP9tOat8VP/TOYPwD17KnU+bThsyPy
R/R9v2sfmRocOI39LtT+22t2eK2tdmL7SKndltyxyWiGwRTkYrS/D0yof6e8
hj0X7NvBbVcKzX5ORS5H7duZO3M+zHVn8TR7at+OPx6rIBdlh/VrU50PbVpz
U7KYva8HtRs/KxZuiE5k/gnoLzEh++x+LeY3LqH6G0kPOV+hw+JyPVT/vJu2
31/F2mD9e6j/mf5kjIeQHHtuJrU/dw0lvQ2rmd8CcQy9TOnPIXLMn7xN43t3
Z8rJv37N+Gy6j0Xs0/WNDsussP466pceTEm60zLTDDnYsbPCA0MWSLHnQpzk
/iupynF+zM+UpXFCg6jpavckWJwwie4DWWM+eF1BsgXWf5L6q6+eTEyoOUGQ
G1B7+KBi16Z9c5gfBXEYlxE6GgOU2e9uROONk47szRU5w3g/uo9CzKLe/5Er
+34eUD82OzIgeGQDF7kntatrRveslFrE/CuI8zx5ul4yYgD73ZfQuOWafH3N
xHWMa9N9CCvXr48v1mG/YwecUz543E/3Mgd5BLXPRk4vq4snsvghxJE2Tvoi
9XUY0/8gjX+edD9Rs8iP8fl0HT8h60L4S1P2OypTv3d4R2Fn+l5T5FnUzrdM
3X7dXNa0tz/JGxfsPzwVGWLP9L9J46i7y7OyVh5jPIyug5cdE1syYiX7HR2p
P1wtVDbXI8gE+Ts6Xti2d0zfIM3ilhAHO/r8YoX+RKb/BxqPXbva6opwNuOp
dB3ZadTw5ltL2O+4hfrJ4r4/PF9HGCMPo+OO/yGpsdVjjLEeiLMJfFjX17+N
6SBN47pGq0x+O6xkv8tbug7b7LXis6gC+x1hPTH+6vaBhpcnI1eg49ct9V+X
ttpMxnogjqfV8UGwpZjpoETjw7tmP066ymHtCaHrmC72equuf2d6gl/9xenZ
h6anLJ4GcY+PnEe/KzcaYT0QJ9Qf3Tpu7n2mA8Sfr/v3T3DWZO2Bdcm7bvtF
TduNMa44jtrtuVKTT1zYxPbvwT1L3oc/exi9YPvTYFzYYXOsbOAAxmG8U3tq
9F7rvhrySjpeXLWqu741UQPvT9tKx3eJ0SrTYoxuYf5T8BufD/by/q03kwP3
fqM/qTbR+UUNy+MDXCP4aW7AS3u8Xxd44J0DUVmVLJ8dcOsvVx6F7x6L7QH/
YYNC8rgQmT0cuCccuEDX7p/DrnRj/gXgbrLnxWe/l8Xz8sC9P3gOiZylhflH
gG+33jCmuJLlewJe4Pn414UOW2w/8Kg8geVO5SzvIXCJqoWbA1y08J5S4IKG
+sIR1bKYTwT4i+w9Dy6d7Mb7aYvoeHdr8ru8vZHx+L7AkzS0ZzdJi+A9J8BF
v1WPXOqqhO8L3G5UQDQZq4vvC3xk3mal9/XsfYHvdByllHPTGt8XeOjieTJq
tex9gcvO/OUbrayL7ws888aQPYWOSvi+wOVPG99/JiqC950CP5A1sOB23xa8
/8SNjqdKZr7f3zd3oT7ALSrHTyz9mIr6ADddm9qUEzcU9QH+bcfcrO0XVVEf
4Ptby66bVbB8NMBLVoysH3KC3bMBXH1cx3GHz5aoG/BV4bpu67otUTfgo/pr
rauMZboBD1p9V1yylOWdAb7l/s3o5LOqqBvwMe+sTCOODkXdgAuvKMk2re3C
+2qAv85Ten+7MRXz+DRQP2RPy40GYSKI/Qu4wvBhdYd6clFP4K8G7Kk3N5BD
PYEHXZfY0/WT5SEFXuMSui7sIctXBVxNeu3TMF2mJ/Bw12jngaEsDybwmPM7
kpfuZflGgY9TJ3tuaDM9kYtGLS27z/JSAQ80u5Fj38nyjQL/9Gm5h+9EOdQT
+Jegvi7ikwXx3mPgw9cb1dz4not6gl/k9Ua+0yVdGPUE/jWmWmz7+3uoJ/AX
mwVFWgVGop7Ax1xuyhq2meUbBT42fea1MCeWzw74T5XDL29vZ/e3AC93u+Ox
Yza7nw345YYnZl3pTGfgkT7vhfTmsHyjwMMysw+d28LsM3C3GbuSTexZPjvg
tfMVO5PWsXyjwAsif656853lGwV+5brkvWuJLN8o8BLrsDGZb1n+VljXnjIn
IKZ2nDjqDLzj9rbcA5alqDNww5wbS1y+KKHOwC90bNhyPYDlwQQu/VJV9Oke
pjPwzas87Q9cY/m8gAvcv+czdzvLawlctONis+kVltcSeB/R1wY6f+S1BL53
xoTA71tYXkvgDZdO7vzUroS6AbdeOeiGtxrLawncrM58VJsZyxMKfm/Z/pI+
x1MkUDfgs3syH0zuX4a6AR87Z0WjkCzLawk8Innm19fOLJ8X8G6/OXUKq5lu
wMNaRp37VsHycwHPDLqwdslNlqcS+Iu+V2qbylieSuASMw7PzlvJdAO+Wj3w
Q5Ajy88FfL43t6VYkuWpBD63y+4zN0kCdQO+qeTJhkuCLO/nDLpPtdFwwwmv
+qGoG/DPisFHji0pR92AN82d4O/fxnQD/lYmt0mnkukGfORAg7eCxkw34Nr6
7pzEfkw34GNuHU5+MpTpBtxmrZre275MN+AW1V2r3hgy3fC5Wjf66ZQx3YCX
3BEy3dzMdANulJforfOW5fcE/nCGoe5Ez/LeeeJ48wu59rimj/ckSa+8cjye
IlG7ZtGaCk6v/HE8bj5EM/DbLpXe+eN4XGma6Ijng7R654/j8bKCDZ5hnfq9
88fx+GR3O85qYtw7HxyPP5wpaRH8hdM7HxyPX1s0L+cJx7h3Pjge32QsPvz4
N/3e+eB4/NjQhcMFRbV654PjcS8LVXnVIJXe+eB4vC52eF1TgWTvfHA8vqZm
2F3VVSwvZx2d7wj6L9nb4iWFugE/pxE1+cPEp6gbcCEnt91e75luwENul94e
Lc10A75zTusCmQtMN+CTVILuBwez+6mAz1atucx5xewe8Evzf522q2b5IoEr
fPxxTDKI5YsEvnb+0iWz4pmewMO+773kJ8n0BD4ntvroowamJ3ArrZKKYUtY
vkjgsZdCFd+Mf9q7//LmibUrq8wty6R6918e/9Um0yiQ/LR3/+Xxr+Jjrq1W
UO3df3lc5stzbSMRrd79l8crJ/qve+ek37v/8ni4Y2342CcsXyTw1waic8ze
8PVrHt90JTVI8q1J737N4+PWt/2oemzUu1/z+JwdY+84O+r37tc8vo67wTVR
WKt3v+bxjjVTxw8Yqdq7X/P4gNMi4xIeS/Xu1zxedTQ9SzOR6ZlJ562d3ysk
U4ew/I/A14+qDCC6TDfg9ksGZl15yewe8EW+sz54fWL+NvDVd6oFQ1WZbliP
jvDGj50s/yNwg8mVQtc7mJ7As1/OC2juZPkfgb8Y8XHJfBWmJ/CElVkTutuZ
Hw681bf7W80zZieBP3+b7TBIm+kJvOzG0D52g1n+R+CZYzRMbQUrOYNpfBjm
16H0POz2CN/MSJU85AeClC6U5e7lfnO/2qJi+wD5Js24+LMDK7npcl/3V6U9
Qa4UpVdUaCtO1gUevKhiW4m86qKC1PG7BmRik2aBd9VL5MWpaTL3Ix1IOd3/
AzyEnrfVjuwbqmJbz577ROn9yGGE7Lcqk7KNfIfcTHRKtrDCMNLWfeq0d9V7
5KNjPafI1r/h2l9foxmp0oy8n4R4QK5lJPfSIk52mncrcsORJ9fOmK7N7S83
2KYqrR35zPGqWy4OqTC9T+/nhPjArW1tz+7qC+J9d8AX3KnxmRKtTCAvFXCL
fcmzp0+cTOB+bLyPelzh/a1zbDE/C/DN9Dwv5J8C/vhbQD9lrjbeqwlc6bPJ
u/M+EngfLPC7plbfV0k0co/QdQeMG9DzvKG3wm1tI0uRv5ra3/2FkzqxGKux
KFLlKfIOKdHllz0mE4ED97dVpb1AXvE57FvZcSuyie4HA76Cns+tdPD2V7F9
j1z4UddWJcfRRE/QRNQ2sgn5m5Ul8nHH+5PItIFHvKtakEcvkN2m1FXLXUv3
1cM83Y+et4V7AoF7uZdHzygwIh/o/YfAN9H7POG+VuBH6TlZuMce+NJ+Fy81
RcoQuGce+JJhn56HVvzAe+OBu9L75KVpXAvmv8b0fOtI2H9OuRw9Z7pF5Nl6
FdsW5MFic4fIzh1Int8838c2sg25UeMown3ynttO139hPnibnq+E+9iBJ9mk
zOR86eLm0vVZmNeI0vODktQOgN+uTs8PBlA7ADxzwcoruwsVSQe1A8DlYxqK
PBrGE7ADwPXG3fhhF6GPdgB4sGPjd8+rJmgHgOfoqpWqapqRCmoHgCfT84M6
1A4An6AissHAh0MOUDsA3Ph12NplYZPQDmA75bQru4y0CNgBrOfKKyGxPaMJ
2AHgYTJCXw5tH0rADgBfGaV2efjmV9zpdJ0O/PZIek6wkNoH4LdqU59Z64wn
p6l9AH5zSvzwl6f0yHxqH4CP3nmyeLKUMRlG7QPwjZ++V1gaEJJA7QPw8/Q8
INgH4FGTBp8+MN4Q7QNw7uji5g3rtdE+AFffPFNPQm8MgXuhcd7kMu9awQUZ
spXeMwx8xAf9srTVH7mx1J6AH36cnu/bQ+0J8LGHuqY53NYlVtSeAFeaaFp0
5oYREaT2BLispikn6R6HbIbzU5Qvouf1nlF7AvxL4k2jW4t1iD61J8Dfy8fG
3NikRqKoPQGeL5S/8+Sp4eTjihcqkSpsHnG/cICr+rgf3HV/3o/xT15Oes5O
i9oZ4OfMatJdtxiSZmpngH+k98fa/Xl/BY+L0PNxl6idAT6t9eRLt8UaZAC1
M+j/r2y9cH/GKLL4zzyYPN5m8DhwiFtfMozaGfA/f9Dza6OonQGuSs+RbaN2
BvjiqX2Cq98okhfUzgB33zlia7eJCPlI7Qz4Yy70/JQjtTPAraKEJf2GDyEu
Uts220Y+wnHzwuJhRt8Xv+Hacidd9q5i4/iMSQ6PXLMNCOStgHEqgp6vcThT
tjjb+xja/xE7x7maj0nkPqPtBL63cvmIWPdCbsHvzJ8TbHdi/fKNWY3uthWY
Txn47kib+795fg74jcD9nGe3B4yKxrg98F3+VWLtma8xbzJwtZyyiFlfJUnz
nmWjbCNrkauM9I9p2euAfh1wzSK7CV8aJNGvA77ibkntteOvMa8H8OCDTi+u
C0Wj3QaeRs+5gF8H3Pfs0/kb+9wyhXvaQc+MgZ8V7ZUbuXCvL/CEDKkoF44T
2Wl3iRulkol6+iUP2X6ybx03/OQvp0iV18iJaLn2+TH25FxQcYp31RvkDRFt
fbcMcyBnaT4UGAej+fIFA4d8wVA/jGvVvm73pmtYk5yuxYdVbKuRc89nHDPJ
tMbnAt99ftP4Cxm88lp9nqd5v0VeNNjr9jwpa7KBvm8D3z3YZZA3gfJ0mg8L
8yZQ7kPzZ1nTPJ7AbSyeOa4caUnW0foxHqUVV7Za3Izsoe8F9sQlsVBugD8h
Z2n7gR96rCytmUTI6T/z5PL6dTjNC6z5Z57cP/ICH6T14/z6y5Krj/ZzSDrV
DbineH1sn2oOiafPxXnuBUnppNcckkV1A54e5xn8IphDNtH3gn4N90iXUt2A
p9L8R8OpbsCbab4kK6obcKKwdpqQpSk50vO/fgrzkfxYF3si28D9vPl/fghw
TXouBubLwI+nlHnUC1VySqmfkMl3LuYO7S/Ajej5F0E6jgPXS7lxsVqqgQvz
PuhHXhbOfSMsJ+M8Drh9worClV7TcL4J/Sj1uNV9D6lqXCeCfhGXN8nv/PgK
zGOIfq//B42gAgecP0K/2MyX/xe+k5wyzaIhpSwPCNp/ui8L7tOGdh6Lzer6
+csL85nifGe1fNZ69WzMdwO8cYBMgxvPnoB/C3yf76ee9VUsrz28b8EMH+8D
oXvR/mB+pTVPu5IVZmI+VuAvcq4IfF/NyoMOPsut5PYL7eFAvh54rojSrJED
Vmtzg6ldwt9luMilIHMPbpW5mVW6dwFyF4fceXcXRPL82iHlVWl3kV+surPO
zj4Z86uiXdUd4nV9xTScjwOPmrJjh7vRZPTD8Xe/cVT4fvwi1AHtP1f6cuOW
Puj/A1fffSXFaF4fzA+F+ssdjNYb6Mrym1NuvHO6qecAV8xTBrotCXCcqBc5
DcsDL6wxcpE5OA3Lg563x3RtmHnHHssDD7636XJdvj2Wh+8N8rkDB/vJsen5
Gb7L+q92GziU/7170bK7wdYkvPLoQRVbZp/PyfR9HfTTmjQ5P3qV5l2DfKz4
6PkZP1n+IOBDhy70+iHG8h6CvZ156ND2cYUsLzxwDw2fin33Lf9jtyHvYQWf
nefPe9jwl7yHMD9qEOw21XRneQ9xnWi/SPXVBRb4vsCTwsKyqq9Y4DgFfGXl
meDF/hakmeoA/ICQseNvXvlsareBrwob9u2uP8uHCPOODfePuQoasryEwA/O
e6CUMInlE4TxSLbEe/WeBSyfIPBKk7qLxgtYHkCwM9NiXUTa41geQOCnH97m
XoojvfO58+zPPjpOAYdxpGTilMcKeZzeed555SXp+AUcyp/RHyuXksshe6ie
wCuSv6yQEeKSdqobcOs8r9/aQiyfEfBa39OqA8S4vd+LN+6Um+9dYZ9o2vu9
eHxNU71+y3VTIvOX8avyL+NdL/vM4+vp/nl4Lowvebccd1xNY3n9gH8aO8TY
jccP0PcFPteiedn5NhNymn4/wGs4z2zqi01IA9UB+KXOzgdZvPL59PsBXrWn
w1e1xIRwUqxnv0q7iXbGvKFUeM+dRZinD7io2pwfeQOzuRBvAR6royLSqeHB
BXsI9mT+vjyjJUs+4ngBdkkqMPTVovg7/4mHrOXLrwf1dBXkeBV45XCFLlTc
SfNm/nCNl+8d7a9P0R9Gf3VxSLb/79fcamqHof5XfHnroP6f8Q+k6rfk4HgH
/FzXxnHtChVc6Hfw3LjK3NCcHa7Yr4HbVrqmDxk5A/s1cBmrBL0FAa4s7yTl
g1Rz1N9OnYF+LDw3Vlhr+OHhDmgPgUuvnJLhes6B7KPPBX4wQHXij7MO5Pxf
7Pbf/Ad4L7APr76pteY6meN7Ab97SmxT+2pzfC/gR/c9r9zmxPKgAb/8KHOO
wUZz8oT2C7AnhTQPmiztR8AhD9owPt6fLz9aBN9+9Vu0/WB/rgw8Le/J85Pf
U92A34l2iZJ9QEgEfS/gIl4n9/fn8QQ+exVB7dXvf8+/1iCH/e19/+JfQb4t
+F3e72xMCwtkefdA/7N8ecdgXHNQ6Q7Ma2Z5x/jHo/I/7Qyv/ecCpQXfF5De
+Tp57cnhyxcGdk9GeenSc92c3vX8Ya8gvgrf59WVkjt/6Cdz22ncA94rZ6pM
e8fyG9x+1E8GPmZlhKNr2knufNgPTOu5Rffb76PzEeA35hSHrVV2IWeUzzWs
qYrHeoo6PlSbjrjD3bm67nZVWjH269uFuZNWbJFg993Rer4ajUrul9TNhTgt
cNWF2QGLYtn+Oqjnjpeb+sdVwphXC8rnSxbO1NEpRP8Tfq8Qmj8rhMapoHzF
9H0NPWECGK8GrvzNqPRrzlduNfW3cf8YX54s3BdH82TBfB/aKSpmtNfZXZhk
0n2bwN/SffXgrwKfnq+zNJ3n15XqexjYRj5HPQ1sJOMF4lleKuTlu9tj62xJ
I1/cewNfHivgkMfqCa0fvtvycUKjy26bk579/4vLAfd46qC90MCCLKDfA3Bx
us88i74XfOeRdJ85rHcAX3Vwa8meuClkPd88fRidp0N8GPyill3hHcN+mOP3
Btyn+paBsRp7L7BX5deVkx5uY/mtwM5ME18WMzSHkBL6vtDvvqeq1aU/NO29
TsrjYkMT4mQkCGngi+818+WHAv6Z5od6SuuHfmrb36xbpNWY/KB6Ai/23ztP
4pEJuU11g/57ie4rHkp1A74ypOdHtIkJ8eWbp3fReboa1Q38geFzpC86XjUm
i2AfMuWJdN/vbqoncKUVpVOKIkxwnRS+w9+tfThPBqrhfBO+t82cHd0Tahox
TxP0F6l5bgZHB6mj3ws8c+KiZwd546kNjQ9A/f2G7c+ebexECPVb0G5Y+Efr
rv7IhTgP8FyBgd6fVOzJ8IbHi6vS6pA3WzqESA62JC18fsJ36ifU8/Xf8bT/
wnwZeMUpn7KAI3L/mQfdofOgCDGD8jTvOuSPr3WaGZVakJZ8IY+qtAbkVh+H
BPqoGZPZNJ4J/eVlblvlmx/vubvoPBe4wqaspdXThMlkOp8FfuDLMlUxc3mS
VDi1/+qqEuRvdvgui3g4nggaHjeLVKlDfstBcWDWFAvi0bKiJM27Abn/9lkJ
TUNNye1TRnOr0hqRH5m6ysaLq03qaR5G6I8zTJSXLBrQiPm5gJ/ylPiWlDaQ
iNJ4I/Clc3JOOqaOIkHUzgNvSqjd88l5AvlN83YB//GzvnuvkiHZuFAw0buK
7bfcFb9URZVnH57SfMrAz6qdqZ85mEN0H8QVpXk3Io9aJtr+67guOUjzLAPP
unhIzjxDlVyn8WHcT3jJNKXfjlfcOzT+ANxz5uRXuz0HkRc0zgB84/Gh+neH
K5LpNL4N/P2AshfjfCeQBt+5ld5VbJ+k/NMnAunTJpEmGh8GHvgi4/akLnNi
Q+PhwJ0axeau3swh8V/6GUaqNCIXfN90ItdJn4CfDPzovNr1h16oE895Z6dX
pbH9jYGNQuMzzg3Hfgf2MO+t3O/+a8zJGpq3EeyhhV5InIqWKHnK59dBflvo
p8AfH9jx/ecQM5JJx3ewk1uCw0VvaQ0gNrT/Aj9xv2ahoZgiuUn7L/BoW0nF
lO2EjKD9F/jl6d1Vt5JMiWDW//ov2FWLE13KN3SFSBvtv8DnxLtuT9w0injT
/gt8llm4r7ChBtHhm4cOpfPQA7T/Ar+zK2Ocsr4paaX9F/h89wP9arINyVHa
f8Fub9jZabh1VA83hvZf4EqZ9ofifOUJof0XeHBus0SSqDrJpP0X+Iko7ukW
GR0iRPsv8IV+3pPFkkzIItp/cbzwbCgSfmBI8mj/BT71dnNH1DldMuHJ//ov
jAsfbNZpqw/6xjWm/Rf4p8vbbTaqDyeStP8Ct+kbZl/zcCwJp/0XeFbIqURX
e20iqPi//gv84jdjCWt3A7KZ9l/gNyzEHs7UMCHPaP8F/jHWddmKXEOiT/sv
8OtbV2obieqRKNp/gV+TXpIns2gCqaX9FMYpjflfm6enypL3tJ8Cny2duF85
YAzxoP0UOGk6cTVktxZpof0UuOKBey9T1+iTNtpPgf/sP7nl01ljYk/7KfDq
OtcbwvGG5BLtpzie2u7fVjRTjwyg/RTn40+ku8TCNclS2k+Bdzyb2DmnejTa
DRgf+5LE11+0h5EEWj9wD/VynV3xQ8npqq72NO9nyNc8mLr3jQLBdXOwA3Af
F9gHKK+1a7N1/v/VdeZRVVVRGAcx0kfKKIUMy4eIA4YKoYITESkCYZIQ5jwV
qKEoGCqSmYSIIQoqmpqKGrpAtBwSiUGGhESGHACnJcuQeE+MQfGhUY+17rc3
92T//tZZ9+x77rn73HPP3t/eH0/5p+BFku4K6tRjXc727eUc7NDD3Uo6T0T7
DilvXed/9qFO0vPFdYoXNTcM2GZL9sPO8jMmRqWj3YnDXymyBrjuiJzoPlP6
bsE8/1PKw0qT2mM8A5Znt66Pc6W6kOi3ftKdocGruU4ZnaO1DC/pW29H+VPg
x8Nij5yZwzrP4Bb3Zr2mCmTddfBe0W2W42IHU14w+Bxpn4Jxhj2rXup5tbzT
SXWHKY5oSN62yOmWZCf4eNOqiIV1TmQPeJSg80/1ji9vWnUpw5nsAW+4Y3hn
tacl6TCAq9zOqaYO7CQ78R21U9D5B6/8uE6nMdWe7ATfqvfCOHTOaLIHXNTn
B/deoOzYqBlE9oCHVKibr80won7pP5Kgqw9uMy1nxodWrN8LflTQvaf5eUD/
/eRdFqwXLfFn5rUWfdfr0fUp3kaK27EU4naUgj48+MhUc+fQ531IDwH8+OWE
H3+62Ea6Dfg++U3QRQdfmjYnOvOnTtJnwPvST9D9xvsi6n6D3/i96WSdGdf5
orj9Ys+M0kLW/aZ90/1Uv0W1rFMKfmZtve9jB843BJ+cnvZ9jA3XRQLfXRR3
zcuc9b3BC3J1Lo7xZp1q8L8eF3hd6aZ/C15doNiVXMr63uCHOoZPnddgQ+NG
19c7X+7owuNA/5cEHW/wdp8TmdkZrOMNbuazIctAw+MA3icqKujtfNahAk8T
dLnBj8z0133awvOT4mruZS1xs2KdZPCASlWCdz7rcoM7pbv+cSKa9aXBV4cF
DZp2uy/dF76jRJ1tcGfT2maPF3xf9P9/wOv6u6eNZb1iiX8m6GOD3/imxKho
CNsPHtp885lPCOvH0n88o0SDHlNY5xl8bdjg8g/XGMnr0bxC1xr8bduYusM1
Y+R1YV6hOw0eeGlw8+UKoS6Mllv//UFkz1tKuf5hV77A7W/7V00wpn6x7kAX
2lKIqxH1mcELDX3iq8ewzjC4v0HfDxLLjOXj8wpdYvDPz02uXeloQvMNfrLC
Iq4q6uh79Nzhx+xaC9Q7rSypPfip3sPSR9bw+gWeNzV+g8belfwJ+TEzd6PN
K56RHgX5PdUvHjfSDalf8m9Rw7JD7JT0HMEvzjMvGzR3BNepkbgmoKBujzHb
Q/tf482VHYXsH8DfXK7/fJd6BNkJP3k49tnPCgcd1lGXeLrqnqptjxnZCT6r
6YK63MGO7ARP6Yz8Z4iC85TBnUZsf/zFJleyH9w7rd3EMZDrZYCr9u47ltzI
9oO/PLYuJH4818sA990Ws3+jtR3dF/x8+5QIE6+bXDeE8tEmfqSbUsR1RcF1
mzyfVOzluqLgl3NiMhI1fF+knxDtuOXicfbn4Nf/sV9wK531PMFbpO9JjAP4
zdvtNUknuP4F7YuT/F9ML+NxALcN/77xK0P28+DVhUUVW/dx/VDwMMdhxTGx
b9H4wO+ph+6cfsqXdfXhTwJ2jMtbfIjrEYD30vgt6whSkv3gdfrzNOG2E+R1
tbR+oF3/47aTs4zldbW03HmU+r79A6W8rpaW96kJTQ077SCvb6Xll8IVbRrX
8fL6VloeHHja208xlvqFf7B+XpCy5gH3S3kxypOH28ex3jj41zX7FFkP2c+D
JzW9SEoo4+9GOm8NGprmuZB16cEz5n8ZmrCF/Sp4e6mBX5t2XZaNs9YvefgX
W3zqZiIfZy3/zt9RxznMVr4edZ1HhFtXD3kirEdanpc7aX/tEWE90vLSmZsq
3m0ZLX9eXfkmi/12Z6a4ydeprn1on4m7574+Rr5OaXl7tsWE82ed5OuUlis7
XD4y6zGc61ZI+4i1nT03/BDL9oPf1URc1avupocvcfupJaqRy9h+8IaAzZHm
X3LdNPDWpEPZJQ/Zn1Bc09d7bPrfZv12smeUMt4ulvXbKW7KI2LAwG51ZMB/
DU4wKrrP6x3tf4NO5p/aYkvvNb7/D/g55agVfjQOWF9GOHz1hkN16yS0By9S
19nmn2Z9LXHfh/bgAdO/MVdM8CIOf77tgmf5siCu60R50G0OuiHXuW4R3vf3
tya7nKlnv0TxCeqlm1aNZo7366DRkmTNKNYPwXxulPaPaE/5ayUlHhX9Jsqv
r50nd5aYNhqYsn+gPCApPq1KiEMLluLQcoU4NOgwY9zEuBfS1xLiUsBh5wMp
zgFcjEPAc6T/A/cUuzqCNv5nv39V2u/n/k986WzhvO+SdN6HeQVuqsns6fYe
651S3KyUT1Ql5PXES3k9sF/MB68S4v/PSvH/pFcm5FvBHsxPj5aZuZVlrXRf
mIc7bOrPjy98RPpXsGeJj1x/D+/FfikOGfeF63hIulu4Pvp9dPDBmoR1lfQ/
RIwHABfjAMHFc3Zw8Xxc9ty7xQeCi+famA+w/8hA05X5s/XIL+F+RV0vyj/6
JTUqRteP2sN+3wNx65/M5/bg3yY+/eTgUW9qj36vHG+wuJ7Dukng0NFCe9Kd
UC1YtKM3twc3FPSs8L5AzwrtwauWZpYV1rFuFcZzxSG9c+71rF+E8bzgkqg7
/x3W4aH/282zrT9z4fYU17TuYeAyX0GPXctTJF0j0t2CjlCWbvLd8HHyfrXv
7zHpvE/Wb1c8UpXudkcrtgfz/5R0fvcvsNj+ng==
   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFmwnYVsMbxt9z3jNnRJYKlVCR7GmxlRSyr5ElVChLEgmFkqRsIUsiRVmS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          "]], Polygon3DBox[CompressedData["
1:eJwtmwf8V9Mbx+/3jnOLKBXZMjNCorKK0rBTyEho2JStbDIiJKlE0kKLCv9Q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          "]], Polygon3DBox[CompressedData["
1:eJwt13m8TeUeB+DNPucgFSEy5BqSMQ3kpi4qURm7Lt2M3RCRKCEylDlkyJyx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          "]]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.224146685, 0.090484535]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0r1PU1EYB+BDpX4gBWcHESutxdiJOBB0MRgSHEhjDCkxJB1IaJo2MkCb
YHRQcCfBxM1BJ0f8CzRMuCiCH3yUSBiZGIwE63Pi8N7n957bc+85t6e3VCtU
20IIr9RTIeYZlyP+bQ/hAqf0LblHrsntyRDychdv8SLv8RoneJNlDrPBAl9w
ki9Z4Vs2+J6L/Mjc6RDSnr+qvugfc0j1nAphXX+ZX9nLDV7hJtP8xqv8zg5r
zZi3pvqM/TB2KGdVRv9Tn+VWXDO347u5w37u8jqbTHlWzrxPak//hLfVa2v+
rF/iBz7nCuf4hmUu8yEXOcY673CaAywyw1G+s/eBhP3KQ/ID77ghD8r35Utx
X3JSXlDd+vn4G9Uwr0tfZ4olY3NyZ/zm8qx8Xt63p/gHd8R18pe+JT+Tz8Vv
Ya935RP5rGq6f8xH5p/hgXt/OMKaMcsJv1VVto1QjGeDeZdxOb6u4l4inhVj
/W3/z9g/gyhCaA==
       "]]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwVzzlSQmEUROGLjLIHtbAMBUkcEnDWnCW4AM2UhARxISACgroRJ4wMXAqW
5fcH553uvjyqXuXiqnWZiYgW/nIehYgTzIsRg3xERm6giW1c49Xt3m1J3scB
drBuf8NMHrpnecETfsaDnOMVv9nEXB7ZqrymVzHWD/UPeZjewRm6+MKP/Y5v
0cN52m0T79XkPGr6o34k//KWPuWCvirX011+wcxe5A6+7Ru4kft4citxxfaJ
Y3kP7fQ9brv8bl/m0/R/tjL/Ay2nJ4E=
       "]], 
      Line3DBox[{1279, 359, 1593, 377, 1151, 466, 378, 555, 554, 1583, 1547, 
       1841, 1455, 1706, 1703, 1842, 1456, 1742, 1835, 1843, 1457, 1280, 2018,
        1714, 1458, 1715, 2019, 1548, 1608, 495, 1170, 497, 496, 1609, 1746, 
       1975, 1281, 1844, 1459, 1282, 1845, 1460, 1283, 1830, 1846, 1461, 1713,
        1827, 1847, 1462, 1662, 2008, 1533, 1658, 492, 493, 1168, 366, 1595, 
       470, 1594}], 
      Line3DBox[{1284, 1534, 1664, 1702, 1196, 1584, 1549, 1743, 1747, 1976, 
       1285, 1848, 1463, 1286, 1849, 1464, 1287, 1850, 1465, 1288, 2020, 1716,
        1466, 1717, 2021, 1550, 1610, 1670, 1689, 1671, 2012, 1585, 1672, 
       1551, 1611, 1748, 1977, 1289, 1749, 1908, 1290, 1851, 1467, 1291, 1852,
        1468, 1292, 1853, 1469, 1293, 2005, 1657, 1470, 1665, 2010, 1535, 
       1660, 1698, 1699, 1596}], 
      Line3DBox[{1294, 1663, 1750, 2009, 1712, 1711, 1751, 2017, 1295, 1752, 
       1909, 1296, 1854, 1471, 1297, 1855, 1472, 1298, 2022, 1718, 1473, 1719,
        2023, 1552, 1612, 1673, 1690, 1978, 1829, 1586, 1674, 1553, 1614, 
       1753, 1979, 1299, 1754, 1910, 1300, 1755, 1911, 1301, 1856, 1474, 1302,
        1857, 1475, 1303, 1858, 1476, 1304, 2006, 1659, 1477, 1708}], 
      Line3DBox[{1306, 1756, 1912, 1305, 1757, 1913, 1307, 1758, 1914, 1308, 
       1759, 1915, 1309, 1859, 1478, 1310, 2024, 1720, 1721, 1311, 2025, 1722,
        1554, 1613, 1555, 1691, 1617, 1991, 1618, 1616, 1556, 1615, 1557, 
       1980, 1312, 1760, 1916, 1313, 1761, 1917, 1314, 1762, 1918, 1315, 1860,
        1479, 1316, 1861, 1480, 1317, 1862, 1481, 1318}], 
      Line3DBox[{1320, 1763, 1919, 1319, 1764, 1920, 1321, 1765, 1921, 1322, 
       1766, 1922, 1323, 1767, 1923, 1324, 2026, 1723, 1724, 1325, 2027, 1725,
        1558, 1619, 1559, 1692, 1622, 1992, 1623, 1621, 1560, 1620, 1561, 
       1981, 1326, 1768, 1924, 1327, 1769, 1925, 1328, 1770, 1926, 1329, 1771,
        1927, 1330, 1863, 1482, 1331, 1864, 1483, 1332}], 
      Line3DBox[{106, 701, 107, 702, 108, 703, 109, 704, 110, 705, 111, 706, 
       112, 1120, 424, 707, 113, 425, 708, 114, 709, 115, 710, 116, 711, 117, 
       712, 118, 713, 119, 714, 120}], 
      Line3DBox[{1334, 1772, 1928, 1333, 1773, 1929, 1335, 1774, 1930, 1336, 
       1775, 1931, 1337, 1776, 1932, 1338, 1831, 1933, 1726, 1339, 1236, 1727,
        1624, 1629, 1628, 2002, 1340, 1626, 1627, 1625, 1934, 1824, 1341, 
       1777, 1935, 1342, 1778, 1936, 1343, 1779, 1937, 1344, 1780, 1938, 1345,
        1781, 1939, 1346, 1865, 1484, 1347}], 
      Line3DBox[{1349, 1866, 1485, 1348, 1867, 1486, 1350, 1868, 1487, 1351, 
       1869, 1488, 1352, 1870, 1489, 1353, 1832, 1871, 1490, 1728, 1019, 1630,
        1675, 1782, 2013, 1678, 1676, 1677, 1631, 2003, 1491, 1354, 1872, 
       1492, 1355, 1873, 1493, 1356, 1874, 1494, 1357, 1875, 1495, 1358, 1876,
        1496, 1359, 1877, 1497, 1360}], 
      Line3DBox[{1362, 1783, 1940, 1361, 1878, 1498, 1363, 1879, 1499, 1364, 
       1880, 1500, 1365, 1881, 1501, 1366, 1244, 1502, 1729, 2028, 1562, 1632,
        1679, 1784, 2014, 1682, 1680, 1681, 1633, 1785, 1982, 1367, 1882, 
       1503, 1368, 1883, 1504, 1369, 1884, 1505, 1370, 1885, 1506, 1371, 1886,
        1507, 1372, 1887, 1508, 1373}], 
      Line3DBox[{1375, 1786, 1941, 1374, 1787, 1942, 1376, 1888, 1509, 1377, 
       1889, 1510, 1378, 1890, 1511, 1379, 2029, 1730, 1512, 1731, 2030, 1563,
        1634, 1683, 1693, 1684, 2015, 1587, 1685, 1564, 1635, 1788, 1983, 
       1380, 1789, 1943, 1381, 1891, 1513, 1382, 1892, 1514, 1383, 1893, 1515,
        1384, 1894, 1516, 1385, 1895, 1517, 1386}], 
      Line3DBox[{1388, 1790, 1944, 1387, 1791, 1945, 1389, 1792, 1946, 1390, 
       1896, 1518, 1391, 1897, 1519, 1392, 2031, 1732, 1520, 1733, 2032, 1565,
        1636, 1686, 1694, 1687, 2016, 1588, 1688, 1566, 1638, 1793, 1984, 
       1393, 1794, 1947, 1394, 1795, 1948, 1395, 1898, 1521, 1396, 1899, 1522,
        1397, 1900, 1523, 1398, 1901, 1524, 1399}], 
      Line3DBox[{1401, 1796, 1949, 1400, 1797, 1950, 1402, 1798, 1951, 1403, 
       1799, 1952, 1404, 1902, 1525, 1405, 2033, 1734, 1735, 1406, 1833, 1985,
        1567, 1637, 1568, 1695, 1641, 1993, 1642, 1640, 1569, 1639, 1570, 
       1986, 1407, 1800, 1953, 1408, 1801, 1954, 1409, 1802, 1955, 1410, 1903,
        1526, 1411, 1904, 1527, 1412, 1905, 1528, 1413}], 
      Line3DBox[{1415, 1803, 1956, 1414, 1804, 1957, 1416, 1805, 1958, 1417, 
       1806, 1959, 1418, 1807, 1960, 1419, 2034, 1736, 1737, 1420, 2035, 1738,
        1571, 1643, 1572, 1696, 1646, 1994, 1647, 1645, 1573, 1644, 1574, 
       1987, 1421, 1808, 1961, 1422, 1809, 1962, 1423, 1810, 1963, 1424, 1811,
        1964, 1425, 1906, 1529, 1426, 1907, 1530, 1427}], 
      Line3DBox[{1441, 1580, 1579, 1990, 1440, 1974, 1820, 1439, 1973, 1819, 
       1438, 1972, 1818, 1437, 1971, 1817, 1436, 1970, 1816, 1435, 1989, 1578,
        1649, 1651, 1650, 1434, 2004, 1652, 1653, 1648, 1741, 1740, 2036, 
       1433, 1739, 1969, 1834, 1432, 1968, 1815, 1431, 1967, 1814, 1430, 1966,
        1813, 1429, 1965, 1812, 1428, 1988, 1576, 1575, 1577}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{620, 975, 989, 462, 1995, 621, 361, 1041, 554, 635, 1008, 
       1976, 824, 647, 1203, 2017, 835, 660, 1913, 847, 674, 1920, 860, 688, 
       1929, 873, 702, 886, 1867, 716, 899, 1878, 730, 1942, 912, 744, 1945, 
       925, 758, 1950, 938, 772, 1957, 951, 786, 1965, 964, 800}], 
      Line3DBox[{346, 228, 1704, 558, 557, 1842, 637, 826, 1849, 649, 837, 
       1854, 662, 1915, 849, 676, 1922, 862, 690, 1931, 875, 704, 888, 1869, 
       718, 901, 1880, 732, 914, 1889, 746, 927, 1896, 760, 1952, 940, 774, 
       1959, 953, 788, 1967, 966, 802}], 
      Line3DBox[{622, 1056, 977, 990, 978, 1836, 1276, 1277, 1273, 1275, 1274,
        1843, 638, 827, 1850, 650, 838, 1855, 663, 850, 1859, 677, 1923, 863, 
       691, 1932, 876, 705, 889, 1870, 719, 902, 1881, 733, 915, 1890, 747, 
       928, 1897, 761, 941, 1902, 775, 1960, 954, 789, 1968, 967, 803}], 
      Line3DBox[{623, 1062, 1063, 1039, 991, 1837, 624, 1208, 2018, 1209, 639,
        1213, 2020, 1214, 651, 1218, 2022, 1219, 664, 1223, 2024, 1224, 678, 
       1228, 2026, 1229, 692, 1933, 1233, 1234, 706, 1238, 1239, 1871, 720, 
       1243, 1244, 734, 1248, 2029, 1249, 748, 1253, 2031, 1254, 762, 1258, 
       2033, 1259, 776, 1263, 2034, 1264, 790, 1969, 1268, 1269, 804}], 
      Line3DBox[CompressedData["
1:eJwVz80qRGEcx/H/GCJ34QrcAwsbC2kWFhaShYUMZeGauAMUiqmZKaaGYmpG
eQk5R+bFWxKfZ/Hp98y305nnTCyX59cLEVFicyhiajhimkl2ORuN2LEz7HPA
Hnd6XoyYdT7imEMe9K4+53xKhRMe9b5ecq7x7HfdVnnXF+w5L3oj/S+f+qK9
4JIm39qSvabFFT/aiu1wQ5vMe3711XRX7rnlVf/T15yf0j3S3XjTC3aDPD2X
vknLbJEtevTTd9guI2ynezLQv+wHY4zzD9VuP2Q=
       "]], 
      Line3DBox[{630, 1073, 980, 998, 981, 1840, 1199, 1197, 1198, 1846, 644, 
       832, 1852, 656, 843, 1856, 669, 1918, 855, 683, 1926, 868, 697, 1937, 
       881, 711, 894, 1874, 725, 907, 1884, 739, 920, 1892, 753, 933, 1898, 
       767, 1955, 946, 781, 1963, 959, 795, 1972, 972, 809}], 
      Line3DBox[{631, 1074, 982, 999, 983, 1159, 2007, 1150, 1148, 1207, 1149,
        1847, 645, 833, 1853, 657, 844, 1857, 670, 856, 1860, 684, 1927, 869, 
       698, 1938, 882, 712, 895, 1875, 726, 908, 1885, 740, 921, 1893, 754, 
       934, 1899, 768, 947, 1903, 782, 1964, 960, 796, 1973, 973, 810}], 
      Line3DBox[{632, 984, 1000, 1076, 1075, 1999, 1068, 1161, 1162, 1160, 
       2008, 985, 1154, 1152, 2005, 1153, 658, 845, 1858, 671, 857, 1861, 685,
        870, 1863, 699, 1939, 883, 713, 896, 1876, 727, 909, 1886, 741, 922, 
       1894, 755, 935, 1900, 769, 948, 1904, 783, 961, 1906, 797, 1974, 974, 
       811}], Line3DBox[{633, 1001, 1067, 1997, 1002, 1077, 1078, 1099, 1079, 
       1007, 1081, 1168, 1080, 1069, 1164, 1165, 1163, 2010, 986, 1157, 1155, 
       2006, 1156, 672, 858, 1862, 686, 871, 1864, 700, 884, 1865, 714, 897, 
       1877, 728, 910, 1887, 742, 923, 1895, 756, 936, 1901, 770, 949, 1905, 
       784, 962, 1907, 798, 1035, 1990, 1036, 1037}], 
      Line3DBox[{799, 963, 1988, 1031, 785, 950, 1956, 771, 937, 1949, 757, 
       924, 1944, 743, 911, 1941, 729, 898, 1940, 715, 1866, 885, 701, 872, 
       1928, 687, 859, 1919, 673, 846, 1912, 659, 834, 2009, 1204, 1206, 1205,
        646, 823, 1196, 1043, 1083, 1082, 634, 817, 1151, 490, 1003, 1093, 
       1094, 1092, 619, 2000, 812, 988, 987, 1038}], 
      Line3DBox[{801, 965, 1966, 787, 952, 1958, 773, 939, 1951, 759, 926, 
       1946, 745, 1888, 913, 731, 1879, 900, 717, 1868, 887, 703, 874, 1930, 
       689, 861, 1921, 675, 848, 1914, 661, 836, 1909, 648, 1848, 825, 636, 
       1841, 818, 1200, 1004, 1201, 1202, 1996, 1085, 1084, 1158, 976, 1193, 
       1089, 1070}], Line3DBox[CompressedData["
1:eJwV0DlLnFEUBuAbDQRbMTHuKFgYSJXWws4FVDJDFBW3kRhUZgYNURxB7Gwk
kmhc4zIaEys7m1haZGKn2Ln/gPyCND5f8fCee897m1udSMdST0IIs9Tmh5Cj
4WkIr6giwwyXz0KYlsX2Jxyaf1HJJGf2U/ITBfZH/DQfUMEEf3U+ynH+54WQ
1flhvne/L8tJkSbJP51lnT3znU5WljHKGCPRvc68zq39rvMOpQzzgfec62R0
bnS2nbcoIcEQg5zqJHW+mzd5SR/9XHjXK491BnQ2zOvRX9BNzr5HdkV/ohPX
WTOv8oIO/uh0ynfRW51GnRXzN37bPZcx4rxlQadeZ9l8bb8ki2ijnVbmdN7o
fDV/oZBmWmiK/tz+tf2V94vOn3lwrpF1VEd/7/wIx9A/5w==
       "]], 
      Line3DBox[{806, 969, 1989, 1033, 792, 956, 1987, 1030, 778, 943, 1986, 
       1028, 764, 930, 1984, 1026, 750, 917, 1983, 1024, 736, 904, 1982, 1022,
        722, 2003, 891, 1020, 708, 878, 1018, 1934, 694, 865, 1981, 1016, 680,
        852, 1980, 1014, 666, 840, 1979, 1012, 653, 829, 1977, 1010, 641, 820,
        1975, 1006, 627, 2001, 814, 1040, 1060, 1059, 1064}], 
      Line3DBox[{807, 970, 1970, 793, 957, 1961, 779, 944, 1953, 765, 931, 
       1947, 751, 918, 1943, 737, 1882, 905, 723, 1872, 892, 709, 879, 1935, 
       695, 866, 1924, 681, 853, 1916, 667, 841, 1910, 654, 830, 1908, 642, 
       1844, 821, 628, 1838, 815, 1072, 994, 1087, 1086, 995}], 
      Line3DBox[{808, 971, 1971, 794, 958, 1962, 780, 945, 1954, 766, 932, 
       1948, 752, 1891, 919, 738, 1883, 906, 724, 1873, 893, 710, 880, 1936, 
       696, 867, 1925, 682, 854, 1917, 668, 842, 1911, 655, 1851, 831, 643, 
       1845, 822, 629, 1839, 816, 997, 979, 1061, 996}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsu3k0lt/7NmyOzEMyJTSokIhEdZ+apEiaCCljZaiMUciQ+UbmKZIxU+ZZ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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"Axiale z- Richtung [ m]\\t\"", TraditionalForm], 
    FormBox["\"\\tZeit [s]\"", TraditionalForm], 
    FormBox["\"Temperatur [\[Degree]C]\\t\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 1}, {0, 10000}, {0, 150.}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.419318070453125*^9, {3.419318252765625*^9, 3.419318258234375*^9}, 
   3.419319226125*^9, 3.41931977378125*^9, 3.41932044196875*^9, 
   3.41932183153125*^9, 3.4193218875*^9, 3.419331864375*^9, 
   3.419332894203125*^9, 3.41933433765625*^9, 3.4193561175*^9, 
   3.447385491453125*^9, 3.44738721334375*^9, 3.447388049875*^9, 
   3.4473884230625*^9, 3.447388979078125*^9, 3.44755661184375*^9, 
   3.481944621296875*^9, 3.6410988934797063`*^9, 3.6410999938733873`*^9, 
   3.6411016988316154`*^9, 3.641646786987076*^9, 3.641647680821983*^9, 
   3.6416943418983445`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzVfQeYHNWVbrvDzGjyjGZGmqCE2N233uC1x/Z6g73rtb1r7zobh8XYJsqI
DJYxSUQBBkTOAgmRhQISCkgoByQhIQQCZSQhJFAgJ5Ph7sn3VvXtVsDe9958
X830VFdVV53zn//859xb1d85bMjRRx1/2JDBRxzW/z9OOeykowcf8Zv+/37i
KbAq96lM5lNHZzKZMf0z+NrBS/lFP4Pxl/wTef0y/Sm4QYMGufAH/s9k8UUO
X54cbpwLN4b/Sh/gpP8bu72Y2g3fKux5t5fwTxbX7MXGsVPLm7Wq7NUg3vzj
Mkc86n95k/fLbJKLXNYRvNs7+If2yqWv7i1bwQfQ3TNkzeN4ozfwD63Iywkg
QnHL0E/H8sYXynm8/PLL7o03aNdMjazD/3E9/vff9slyUnBMAO343uCM8Prg
9TF85KF2GoXgM2bOnOm2b9+eqZV18Nrddddd9N9PbY/EZ4zrnQs+SKPNf9BZ
9KfoNPLBp65bt47+q5N1eBZq9R8lryyLn1Dwn1pIfKpaT0L6/0S8mEteRSo8
KNDpXLOR09YzyRsEqsWFJUmj+AjZUkfX1X6DXJlNPfhilsyXOX5qNRj7R/ax
Kdx6H8PL7u5ufEX/FWQduEAdINebtLYExl/u0UwRN+zd6dvq5AdXRNbV7PEs
9njo/T25vV39yX35ffwbi5eUByvEj7Q7rAsCN3M0HZq95pmuHFXmSvmBzq8i
cqpwhXm8RNj+7bfftu3Lob2Uuf40rohdja7bf/d8F/+mSBSOMLZ3vkyU4TFw
fakok4S2f1EWkxV7a6PK1BHALpmSXs2XceT/f3H2X/g3FWdZdKT6cGxv+a+E
c4lWs7hKD85vuBJOPpJ+Zz5d0lKVMcfbNukwjecl0gKfPLPlkq9YdaYNG6jq
fPJVzDEVHj1JgfAf9tGpiEo5okC/82xmWCfvkQdy5JHKhBvSpDiotP2bIu7q
VcZ+1ZHtY4qzJWKMmEb6Ov4md7Ct6LyFMKpKmYJWZflVMhUEV88nJPzyV5FT
TDOAK5F7e9kpxi60EFn3SQzyVfxdHJz3of8DQ+Caioh9siEw4u/qifl14/Dg
KSEqMTssOG1U06tWrTKFDa/ddddd5y8vV8pI9F9/vp402u+zk7yProqvtpA6
e+QauqwKgUHCFmN7K4IsTgL8y6XcJ/6KwTpf5r2uoksTfMJ59qIr6JULHcSX
gUvewNqjzFlnbatiLxyx51Oviti7d8TUZJ1ecga9cEFD90obugyImH0wbsam
0UicCSvUA6nLOPyTecBHoFQZEhO92ON0ZnQ2E9th9f0EgQm9SeELIXBBKdcx
PgmnovRGpJI3G6TiRQ0WEuzeXh9dQ1vMOQCQKe3OTetwbiosk+H1pHa8IPpL
ZzelAy96cgee3wMd/N54ctaE3mr8++ns74d3JtCSSVy4XF+er48vTbxHF1UR
995he766GAv25Kvz6TQFwulwDQv6wHsL++Anz+/j3FyItXld/HdWpwBweidC
bnIH7aUL/o9WkouY1J5T77eL99XVsOTEOuMUtkG6qIi4Uy54rF1AhTmvMek8
gmKmgcExXpw2nU8Vrsu5R/s5txKWx4H9VsLyGLxe3te5xfDezE7BIVwrI62S
LhvfcA/BMgOu8cEOQoVc5xS8xMl0iQoPcrZF6wRuLmQD+Z1wO/vYzBhc9aF8
0Q/HvFbNjIaYmiTonA7nNx/ctKCLL/ZJuLin+sM+6wYgGlYPcO4JWLUCrncO
eZTjDYGO174Elof70O7k7TmdfOkPdahNpnfgGT8oAYHBMbk9LyF7f2+6VL1A
9rJ2dMRUopVMCfyKr2+BXR/3WBJwJnOMEXzCXzrIJDkFvGI81aV9yaW0zaYD
nNs60LktA/n10wegAdjF88Uy8Jr+roR1K2BZppcPx1rYxVacB8ee3cnbgQnI
89M7DBRTzAKeDtj/eNET0RrGelpxBazg+S9EuRhkniG6QsKWNroXrn6MRNEY
AfcUscIsOOOH+zKg1w6gq6ftnjvQue1giW0D2SqbDxCng9BZA9uu78/bPQWg
WNXPW2Q5WOMRWBbDcRcJBczuzKjMAyRUWiAwGtgeYge0wQPtiDqySW80Bi2c
XQUPmhAINhonKZP8kk0y2zDCybU+bhKMvAfFHAiMR+BSVg1gEGwbKCe/40DU
2M8f6JlrPWyyDXEDyyZ4vXEAr1/b31vmcTjUY4KVpX3QKv5CPEPghc/owJCe
LsYhA2m+YK4g49jOEw0gKBwmUDob3zvN+JlfsCFmGja4AdWv2BDICxM7mK/m
9hHSgytZw7ggLOzgq3cv/Jn9dS8AVnbDsnMgY+ZZsMYzB1AU0TYYRWvEIo/3
Q2uIBaqENCRaZgd8yZFj3EEGEWNM7VA0PaDsSYE/sV2I836UnBMoiMYn1KOY
Yrphoi7ExD29yASmhTAxz0RaRDj3Yw7cgJcml7njQIuIl8AKLx7IlsBlFyw7
YJPnxGrPiCWeBktsGID48BSKFnm0L2Pj4YCF53SqRRAbD5FWYC4ho2TFBlMw
XU6mkHlADDHJqAXX3m+CNGWNQ9ga05JpMJX5q8tZaDKeIgY6Bn4/zhQbwULP
DmQC2SkW6mQLvXQgW0kttROW5xUzgZU0itb1Z9w8KZGEUSSW4qTM1iLGVWvN
6sxoN8OSN0dTFpGjKZcu8QGzU5a4h0SXD27NTEUi6udsuMkGo+a0kTSixrYz
yWE0LRGWXeNpBbkEsKKufOnPsmgcJIEwpBREWw8wvG3o762zuh9b6AmxkOQl
+vzFhimxSkGtBLjqCFO02CdDYGLzTBY2tjTs6ZhTVVZEaki7YptJBqpWWtHI
G93NtrHGB1LuPDjHZRJeyBSbD9DwCpmGzIOl6YtBqO1Ogog23+JBRCZaGzHT
SgHSsj45jcJFmsE7PZ68iJGIg8SFdgA8kYGmdnisPRCk8klI1JOQhCaqeQbx
wFrmYDbPBIMON2iavHnuDcwzo9Mrz1X9Od3A9SEi6P2dQjW7D1QXvXQgQ6hB
V/KGwshmmA0ljIO5aqWycytzkuqbtIXmBjonULmqyZmq203s0P9A2KTwqe5B
S6EmEzQVx9l/s7G8dk+NC7Htmnm3u8R2yk/ISxhyK8TnaLutKm6UwQeyDV84
UNTVCwdCdLFpBzKstkku2zIgYHDWP2y9fpjXxGK1HIHLJfqWig5KWE/LIrKe
hdYMgRTDbBpxkRhPBACzPNqNbObL3lQAitHGJFmdihu2Vy1vfgPE0h2w5p7A
Zli3LevLlQ0S7roBEnpbD0DmeJahR3bZOVBPffeBoDNpdyUsCscDyttunehH
RZ7oR2GjpX3QAIsTyMui8SyVzWQGI6ORTniQdUI7222qaoEp7aa8UXE/0G7A
C432Xcl84QC3ZsNwgPtTbNy7DZG+iaGF+S2t9B/buo0/5Xqw9e1tbGssQ6Z3
WjlBFeWTQQmySWIcDYcGR0N6g4ORVY3uHoi8tWug2PwAb/OtYu/NA/BwXmtp
xBfbHDU7m71ezN7Hk8f8QKKJYCWz++IGrU85RNtiolsFupxUVK+lgvzbgel1
3F/b7+G4v5j+zgiuEZto4pta6BM/vqI5cIHUQNf1dG60uADrn5lyQY9Ixnyi
n9ccyJCIVcAtuWGb2HbHQLZlAU2OHxoanSh2gCeCp7kcULAb1Qapmj4Q4w2N
j7tVF3NFoI3J6Jy1uVjgmloNzaiY2p7zbMF5KQB6aGztXFO/51No+0/xK7Lz
6CTEuXcAQQS2fWVYk9s2tNG9d2mze+3CJvrwIntfC/a+rY0pGVsbmE8XirJ9
VC59tZhlg9h8s9j8WTHp8wd4lYxUveOAYBHMP6fmH8ABiDYk0/cvNv3qfmFF
ZmJKC7MlXb5sTZmfTG/CqdPEt+kBQX0m7YEkN38RX1RExqeKBngDNR76yu9R
5LCT7Yglu/YDYrED9rqjjc7/vcua3eOn1LvZv6518wbXuZ3nNrr1pzWof9m9
lXxBV4PkHdXGJSPyKdrFRGYdIxzNvVbcgO7YJO7dykUzZ2Jys0pTcHg9r3tW
3n+GYcHpQ46zIXRrP6Uz9n4FC7vlfbkL4fVLlgpvCIgFgUfnSK+uQhSMEJqQ
mro4J+pYU0kRhX0hYvB8ZF3Z6QNpRyd3B2fLeKdMedv3znufWETXMive3koJ
Cg3z+kVNbvFxde76H/RwI39c7R47pcEtPKY+iQLRXFcBCka28RgEZl00IErD
JSKAMNiw6EcvrRPPbZJA36raYtsBeLXbDRB4EfC70q9DwAgQEASiETb0x3KA
dFg/A4J9rHRdLM0u65NEhOoyqiE7VbFmERP40daK6EjkOZE8ibDv1nZuLNhj
CCg5sWuQn0oSYMGCNh73+wuHTjsuY61OPUx84O5sY8lyKyBjRAvJGjeilbaZ
D9xw1Xd7uDP/rRL8MPYXNcEw2sF/V8jQoIjmAYQIHuM+gQjmr/mS09Q/T/Xz
ZIEQwUDXoH+GoIL+BoaH69km67dT6mX41PAqkT7EMSR9mC/oPZOd/XxKSVWE
mpoC8sCPXUIjGou7LM9acTOvk+FSIamhgxcPl7yKVe13ojqd1k45IjV2HwNL
CYjsA3J09R8NNDQYmeaQCssghBpckFNGtGZRlmGCuZaF2aJj69wV3+nhzv56
pbvkP6vcLQdVG3B+/ncFxo2Uwlc2AW5amFqmtPs6fCnE66NKL30ZOxj/6wNn
bya8bBmAmvcZSTiUdAQ72wZogmFYNRXj5ukkblgaykchbsLm7korW5b3xfwl
VGMCWKjGcBO2GBA4swk4WdZ13dImZ5YphLihACo1+crPXcmVfdVZCmhlJqMO
8hOmUrwUVuUy8yHzCSHWmj7uIJvYyUr/jrZMIxsSeQpFyM2tpDc/vryne+7s
Jvf4bzhbXQscdf43qtwpX65wVwLsiqAmWexygdp4T1F0eNSD6MvHBG5P9hWa
kjSzUahqEw6Vbe6PaWOLRxv3XewvXsxWGk57RqC2qb9CTSipJlCsAcyUojzU
kKYyVtZqVgtgJiIHHTsPx14CqPmxB+Gpbh2iYzkLIfNgu0ecR536goeH92KW
VwpGe7MO/2uPrOtRCrR7VcrsLxJp0Dstl6XKx9QIQCTqy7BEpjSHXZWrepKU
3nFOk1t+Yr0b/0vOT5d8q8qd+pUKNwSWAIoM+Az3I966sIHxiIJsQi/f/0HO
QLmC9Lc8hck1gscNAJKN/UJcIiwBbLgMUGrZOiBHhWqeUbhFNnq6v7VWOE+q
rMpSfyvnu/CPK/aq/YhfqK4WCwYXdSkOs5wrRWmn+s+CwQCCuRCC0R5Xep7M
J8UcuYDqMp5ItlcSPQ42X4ZV2Ksme+WzZg4xpGi6g9GUw99ZeqOBcii9eX1P
6mi8eXETVWQroUK7/1cMqSu/XeXO+3qVO+5LhZKQeukcSEnXggq7E9beL+Ph
M0WoL+xk3ngElhU+q9LfNX0ZBuv7CbSSsGKfbemvs4e29Fcw8eoqxtWm/p4s
N8hrPOI6BNYaApYnOk+ESnQIsEeLAWZEBzVdTqtHbUrP1aEg6qXO7FArM9h4
oFVHEKdFOlKMkD8dw+nczXAengIsnIcniBoeoaFKAkk+5CJcFFTUeRnZIhmC
zfP7b1a50/6lwh35+UIKJ73o/7eRem4GzrsrwMlD7SxP5gtWKCUmseJW95UC
rxgrkls0QYofNhNK9A1hhadF+2/go4jgYow0GEasvHuCk6GVEGmMLO1SIspY
j30BExKmxCyiBD92jgj3mR0+73sZhjjxk1cCBkrXcZ8cLPgf9xEyl9jBZcay
3ECo82kxHRZxRxYJIy/WfPfSZuKKtafWUy0//YgaN+bn1WqJE/8xDQFRQpcC
U90CGexuoZ6poPdnoCKCZW4HW+/hTrIuvb8yVEZ9JVus74f22hCIpI3o/6fR
/0YHm8j/TxsmnlYhxBvzMdbJMVgNWRtbExFiQCdXKCCXYxv7kT5oIjlJMnDQ
VaXNEjDIiz7qUCiYRNIUpYPvjIZkLoo58k8AiosjLACvRrdyJlEmQPvcLjho
BA5opa44dWMhh+BGL5zX6Dae1uCWnVDvZg2qdeMPqXa3/ojV8flfqwzzCGOj
zRfyiI175bMmAzamCT5mwTKvQyhCi3uIwsdT+Fjbzzt1PWJlA/7a2A9x7ilD
Czl0DKFhA81Fo1wh2luIBYRJZTEeVhoeqCbrY+5c0qVoyHA7sODR4Ec18b05
HTawq6zADEG6Oafd9+nlSKFkCfYl9ugwW+FVQUXEowX8rflqdBtWq6NauSEj
avOjy5vdH37PjfhNpze4lSfVu7lH17pJh9a4O37CNfYlQP9n/it3bw+xuG/h
87+mmSog+kRUnZNQeYJvH+ztY3+h2OERLsDJvyuTaaCbRtzWMQmQd/FS1lvm
x8sjX67HX2v7qf15DJUd+SSqS3AlmjdwJnykeWSZ53g23uIuPDLFd2fSo3O9
7JzTwSEeMn3CnwWjizAkv8fOOj8SfllxFh1qdCv9V7Df4sDR0g25vU3ETS9O
2LKethmlfTZYboRIvaan+3B4s3vjwib3wrlc664C1bfomDo37fAad/fPqt0t
P+SIHfYNc6k7698q5dYE6aGg6hvZk0LWjWtj1z7Qy7t1jhQXD0tmJ9dydgfX
+rkNT/VlNbiWljAWKelrTw193S8n3l3Xzyyv9clqczEiJkuVRI49vFLDtRuH
4c2ruYC5/RzCuVzSij+ppEWtJ2rIZ3MbEfCzpsJw5THfzGkWhn5ad3D/iiyF
kr7Omx+7bRAOnN2LXXybtChGiasxarFdcQO7+SNw81sg7JGU8f01Q+rd0uPr
3Iwja9xYIObRP2E3D/+WuPmzBTcU3EylKXzG1wZKMrqOo9/dja3WNhJw5Gpk
6Ie0hgQTLOr07qZaMhBzwNbuiT7s7tXkmjV9WYDlfR5mAq4QDNjqNYgB8LBu
yj7GQCY/G5TgsyzClkmuzlE406rFxMw4WiPbL5AJJ0zPwszo8xx5Wjxu43ES
0LjnjJizf0d/ytxBmmh20f63teoSwwBxgCnM0a36ZoZR0JsRgPuPlOVW2eam
Virt3NWcmt++pMm9fEGje24odxOe+g0H/NTDaty9B1e7kQf5BpagwA35p0Jz
Cgh06NtaPBAmtFnM03uzJVXPl3SNYFjcSbHPQtpLOwLDKgLCU31t+thqIYM1
/TSyCSmJcKdQ1+WpvuIcPpRk6W69GQPXYT5ZbhnbIKEK3j47lHDzCRmZrO/D
F0zDaTQiNEjG5eOo+M5eoiIq00rgI2/4kLMoAZvbsD0+En/dYu/eQFKNxzPk
iQzq66FfLbiTvlTINMr5KBbc8EapcMDRY1rN4XS8GUr0HZzD53MeR6dbLl/W
lXQ6sUBf3wZ4EiMY/Q+e5xDPGZ2b81GGia9peTI4wBN9xdG1VrKReFjRx3pH
fDJ9bGancAFRAXptUTAtdn4ndzXzXOjP6Qx4d5bV+pwF2PnUWUd0BM5XV357
zwjwYi5oSLugAxnAwDQB/c8YYPhW0RuVHgWKm1HGCwwd1Hegtd+HEu51EAAv
noucwNnhSRABi4ETpoMIGHtwDzf6x1UJjFzw75Xut18uuOP+voDjEFSC4H4J
crgRtR5wzugWwQ183lQRBVrrzRGSWNDhBcJirvsIL8u7vMa31A0Oz6PniS40
DJ4S5b9aVucMGza0gJ4MpTvOzIAj46Ys/BAivoqXAVzxTDiwbwCxdiOliiJc
kFawMq+IFPYWEtGar3h7bhpTuPMZ3daaShWVIUEwJHxIoybErsyNMsfuymb3
IUDjTYDGK+c3uV3nNLpnz2B4rDyx3i34dY2b8qtqd+/Pehg0QBe6s76KS8Gd
+A8FN/gLeZ73XpVABw25XQfouFlk4x0tbCGA0sRe3AyYznKCCj5Vjws8qRBI
oAAUkJiBjVdoyWsqeLKvFXMFRs4gufdQ1D/LEsJGLoUJCyzcNTWwb9jA7T13
+KEP6xR2ZAJJkQ8hYgApISj+a/9QkiuDEr2J8bYEGG5jidmKAyO3WVLh90VP
mKq8iYGC6pLeB13xDqjLV8/nQmIH8MgzZ7C+WAEqc+6gGjfpl9UGlN9+pQAn
MeTLBfj8If9c0LayPLGkxnIOLh9fjCMVkI2uaWJOGcHtBXdXC+YhPw8OuYVg
IwJkTihAQkWKIqTTC8UuoxeADpaEfUQ9KGSyklq6pQJNEMqqvt5KokHVvyv7
as1BaNIiNBjG6LZJqIUQU1qM8GfmwiyEyXVOh0HJyGpmR5iKCEfBbHBc/pO9
76sQL0NLPfcKsVIlwAhggouWSMAgvTxEbgkhIjBRiFzd7D64DGrNiyDVQBGy
8+xGt/2sRrfldIbJI8fVudlQjOBZ/xIgcvw/Aiz+AWFy/JcQJicgn3yRE5c8
ZgtPr83tOqPOvXZOvXsP28qXwnIlYOVaqVKYXUCkwnIfnNB4qY6madu5N1MM
idV2xgrTjMFqaZfXrFLEBHjxBQ39r8wCa0JmeYIKlDxNec/7jMbixMhCxCks
Ik4FMDplcEkoUvPWh/BjX/M7Q86ZY5yjCYpKGcwCvt1IS9hlFJicHaGUPcJE
QYGvEBkFQkW3lqOUYUi53NSKXI+l6fWeQN6FwuSVC5oMGUogKkYEGVl31BcK
cOijPl+gIQbcZPAX6X/rDig6Gtym39S4x4/lztSWITVu9xm17nVAy/sXNaCi
9UplBJzMbYKWe+BExyqzwLopnllItUhSwmCk/UN2Wcw1L61f5jtYonozio+V
hA//hpw4pZ+VoksEKVo1P4o0Qm3nZbSz3pzE0NCqyEZEdXLpAr0lmvTs3ECv
KKVJcyNvk0PkkwNYfKs0KirKoKKAWMjL51MdAqioSKQTOgPWHgiMnohgD4xM
DwkOpQVYwC+/gN88tn00eH7QFwAJUP0c+tm8O+QzeXY9uPHyZvfaefVu1qFV
btGRXNSuGFzt1pxY7Z4GKOw8k2eiERQuCxLMLShaGQp0dmOIOGxU4MEkEmgT
pGXWsVnpICkYTA4o064IPS9UQIDIy6sVfcImRsAKOUQUposu9eFiLVrI+AuJ
D7LocnUtdzSsazEHKSDp+FnS1bLBzZnFtcs3S3u/UjAQ8b4xQj6iNHIIAvy4
W33aYCi0SHXSkwcTruJs/z6Qw2tADs8DMWyGlLHut/VEDIrTgz9TcD/9m4L7
yd/k3EF/zZ91BODicMDFrwgzjMf3LpHBibPqAQg1buLBVTJwWeGeP73WvXZu
vfvg4kbiBnc1AOKGZpv/cqdQw33S5ZwoSWRab3/ngyYTLYTnJYphK+6ktoF6
mIif2so62WyF/6uAyOR8Jbuij5ejj9pgFC+P9skoSB7pyiVAouPYCztDkOgM
yW6dw5MLG18hOyi1EkXMTI9NCUKGRhDSoxxCRrVWpsExkjKE9CsYlXzHBdEC
lg04iICDRBDfH13Gif61C1hRoJrYcGoDNbUeO4lzxg//Kue+/+mc+95f8qd8
889z+liJjb8F0XFEjZtxaLUb/s3KSvH0zMN6uCVHV1uE7jirzr0OTPLeRQ1i
ewDH9cIU2AO7Q/pgyBTj2vyo9jSpZGYUJQ5GQgX7Y5F0SZZ2aqck66uaCm6V
P9rHu/tR0Q3o73yYIHj0gvMDZ6A+uhAkTGos7dIslWGEFERzdnqUKIvgR+ig
FS8eJHZAHdOcJQ3TGEj+IwBJcH94ydQxqjWrVcmoVi8yR3pUUN5ooYXexjYn
jkXgTQNXNtMEJ0TI+5cySl4+n9uem05DlNQTSvAE/+svch4VFe7e/+ZkMepH
VW7ED6rcjd+rdNd+u1Lv+oCX7jpYbv5upbvth5Xu3p9WukmH9AAgVbslg2vc
qhNq3Obf1iolvI9sgjOtmE1YaYxuUaVhsTxBpKkOh82QJ1XopOOQTeTWAhId
QbtEfLGM6GSZ5Q0vRpZ3FYnNZSQ2WVE8og2yLg+WCv53aZeBRqYo+54ZT9kY
ZBPbE8xiojQ52Dm7I2SXAgEnnnz+vTS1lMNPJYLG8BvWrzRd+KYWUaB0FnjP
lrIK4Obj4U3uQ8DMuzLUuRtK2m1nNriNv6vHxMM4qXPzBtW66YfVuAmHVLtx
B/dw9wlu7vhxDzcSsHPz9yvdTd/jztiI79P/3AkBTlx9cq3bcmqdUcz7WOUO
b2LoMkq80L9LqGVsGwoRRQUziwiQWN7xKLHO4CO+VbKsK8RITm7Mkw1QXhKK
9FYlmQrFxwtGTYQvFhBfcAki1KN0Mdc73Y+kmQbNe+2RvH+5jNtry7idUkfA
GN3WsoXVIvdvDcHA7EH55cYWX48EaMA8g4j44NKmBvHe3T/t4W4/qMrd+sMq
d8sPuLs1El6PgmU0eP6Og6ps6uLUX/ZwMw+vdouA7h47rtatO6XWbT2tzu0e
yurlg98TP1hgjpCccnuLH7YYJ9zwQC/f7pjezm1U7ZLN7gja7+J5SS5UHoBD
8/hKZcEjXSpEONw5LahSxFe0sXbH9Y1F1IpYGPF7wfxuylbnOOTCtpdPFXrM
eLr4Bvv0RPyTmthQsFd1lkzCJnkgaUZC/YEtbw5N61Ak/M7lBrAAFxWAk3ck
8l+BjPE8ZIzNp0PkD2HJufJEDtslx2Bjq9Y9eFi1mwgUMOHnrBjGHtyjIE66
DbCAOAE8uLt/UgUMwViZDnpj7pE1bimkiydOqHUbhtS5bafXWTcH0wUgMNFo
wom6SAQ4xj7WVyM69oopI4QEyQ0felqqLlD5h2IUcoc6ZYkJAnJ+Ju9HbnlR
Xy3pSu3C4NIxlJwlJrG/4SXgiiwXo902YReBUkjwg9YmOYMIddKL51B+nVFy
Av3Zt4lQLhhaCdc1lJclt8pQWsEjStF0YwuvxRaqMMdHw1l/IKLeusjnk+1n
cT5ZDRrkiZPr3YoTGFWLjq51c46qIVRhy/T+XzCqNMFgv/3OnwD9/LgKAMZ4
ef6MOvcyFC4eLwVmMEQ19vRHodwIWqWSTCxOUXNg1x1nQwuIurVDTeMac6wc
4NlX7FkrQ8l7i7t854OxkymHFz0gZ5fUaLxoUcFRjj6yKrx/TrWF8Q3LUmxv
WC8jTAB5D6Ekywh+TknhwOOlzJT9EhipkJFWnMXmmQh/fzokG5OqdPoiVd+D
Ovfti5vcG8Oa3KsXcMJ6DqCChQ0S0FNAQI+fVO8eFbgs+HWtmwVM8iAwymSA
y6RfMNGN+3kPGrkbA5C552eYsZh5xgAD4Xv3w/IAbDv1V7z9ol/XuGXH1ron
Tqx1a0+py0p58uq5De7tCxu9xRFVN/S0O9tGCyndg2PCbVwaj5fiZzKByk/h
T7OTJCxD1XxtYxI/LSJMPdxp8oO2e1ju/K2UslYR5NN8ME4nwlQyofZH8V/y
2jwRphrIMsjLi5/pUTSkJ+2SYPpmiKev7SsfxR8rXA5feUQWN0k6vHLBIX18
NkEaWFeweiEOuhg5qNG9PqyRaiF8H3kI66G1Aq4nTq7z4BIumn54dRYH++TW
zYlQ7IwXfCEl3XcwY2gi4GkyqJ2pgEXUxTMPr3HzjqrJ6DORN0KWexYS6e6z
6t1r5zW4d6CctsfiYHGPFDqyhVGFNxHc3cbpjlGVsYJE6WpaIuehhqCnU4Xz
MrhayuS0K6dtWtXE4bqHO7kYzumI3sO+OZJjvuO5nIqsYBZgYshP4RXOHzCI
zTXZM0ca8oUQXjaM42caFSe9fwtAFkwO3/vv9igHL025I1qy6JIMy9QkxloY
Y9eEBNbsPryMa6a3Kdc1tgibI1ZwE+abmpwomkW/pvzlHgfKWfOb2rzwxHtY
L0vBLnTDSQyRQc0WREarUdA4oRt8Wg1STggOnmrgCymdyDWHKiSqX9CdCwO5
vDBQLkRAKUlTIUBY2KkdsQWdKbfn/HTQfDhiZ/VOMAAs+CpEMpM4+cSI+/bV
3S1l3E2ezlNFXEFeplO7QbxNnkYgXN2MR5ZuLEO9m4bskUxQJr90Hg/XPAuF
8tMibFaBsFl5Up2Jm4cHs2SecURNFhWOQH/aoVgmcQLr1ulalSJWnoYq+dnT
6t1OYI2XIR29NazBvY8103DByLWCkRHEHoaLu1s9eejTYyfJZMUpYWqq9LpH
UpOVKfOI7ed3JFwdQEVpwTRK0bsLTSQt6NRJOTpnWNQLOWVuwCBzDaVcPRWS
tVJFgBWtlr8aYCU1MTxvOaWtPApuQjff2ILjLy16IdjkvL5ZOvIt5v+PJND/
AMnkDZAHqFTQ/7vPYQzg0B022FTcIgZw/dJj6wgD8yH0Zx5Zm3UPHVGT6W0p
WRecVzL1V6x7NZHMAZGzEETKkmNq3fLjmTmwbNoCpfT2M+upnMbRnj9c2AAl
dRMJKoaHqJVUbtFSakwAj4m9/Iy2ySGNxODhH4+pXbn5jJbO4OEfVm8pQhIg
4uo5o4/6WdApg1pBqzVoq9lsZAWHtmFn+TbsLJtvzt20bDAXICCJf2W3nxWh
inIgyVGFk7M84Gkgx515zglohauaMMdcyT744FIRtQAV7NS/fL6HyjbQH5tB
f6zHAR2EC4jbx070cFk0mBpt1gvB9Q8BHh46vBr+m36YipK5oFNwTtLDR0NZ
jRg5rtatPIFxsvl3VF67HUAhL54NlHV+Q0bTDZ03ivIRPYsBco8BxJ43oxQS
SzWJ0smacQyRnNW80hz13ldY5DwOCunaJsEQ5BvOKcwQmlB8nilurQguRFvg
70p72AG9l5oIIBj5Z8FI+MAy/T6H8IFln4lgiR7iUGro54YWm3qmiea6Fs/o
Ii24CQfhfIUP6XdZXrjXRMa+AFlhp8BpKzDPJm3TUtANwhtk2ddYKM08gvlk
1hHML4sAL4uPqXGPAF4eZcxUSOZ544IG9y58zkeXNNIMJDo3g0sRn1jmuU8o
BKfGT5SbXFSdMFx81NBNTR060XwuhS3yiSrGeXbf/DwkfoFQpTTcdK6H+VAb
bjGQqK6bba2UABK+nCk/PeRf2H+9It4eECBFn6+m390WPl/tM5aQOkrgQxQI
kgr9as5Uezl4lSxX8PiO9urxfeCYKnN6popqGVy/7Lg66tYthHoGm/aYfqBw
5tnPNW7VSbWQqepoNBA3fx5pAvD06nmiNkiREgZ8kkY5PKJFnCOOvytZs9Ap
T0iAwEuOoOVC281o10lcmWBkreB7unOtVMb84uedzi8e7Nepy15RdCaTRhE8
uqlDQgMxcjtLzt/jkNsfBOjN6/q9H+HXlfxtZN9SWOCbTnrmaL56objsuIrS
zZXN0jZVdaq14h8uaiKF+iopVOCKcxrdrnMauL/Rg4QqtlVWn8K93SdEqOCk
xUeOrXUPH1MLh4I6GK4XO3P4HqIIlwWEphpAE4/QLYHtcZ8VoE4ehwz21Cl1
QEN1QEd8zF2QeV4Cqnrt/Aa6B5oa/zjv5IrmjD1RDmkFHxGCI+G3axnsM5FA
yooLfKypL3yydJu5oGF6uy8jSRrICNFsjwGmjA6fW3QKwDxjB69EDJD0RBlf
1Mjh53SI84yL5thIT14mn800DpqJZFYEra+ww2MVjO/9c+2zV19f5vVvyQfg
hV8QMmhPT8vTEwvx7R++oO/uCemd5ZCOatVd0xN9i/frXG1ZMK/EMVw4D8e1
L2HAY18ZdJVopEa342yfDIsQfrJH+DLId6inEdmLBgPaB9eyf+BFFtdmbJ1b
Bqh+DPQURshqRDYQ5tMg8Z85jfsDL5xTD2VgQ144lSj6GhlM03wZAvsOA7af
zoJceb8sjGyM7cn0vPkp7fZcduFLUjHY9ZnVnkvMhfWMyfW3NfgCscOZ1kdB
yIQhO84WOtZj+KGJdJMmqbBye6Gwvlwa7qXR9wm/CK7wxzjI3sZGue/T1WMU
RQvFIT1CMNI+5ZuIKTAyNhf4St/pxC6URQiogg8uaeKgaJMeBWeAnRAgz58l
terpHCTYAMV69UkIkDANYJAsBVpfDIGyeDAHDNH9MbQuiy/gOpD5cfWqk+pk
kL8Okg4KiEb3LgiIjy6VsysVGKMoMLyYCBkfHxilwTGxdxAcEjhT9CnnvbVQ
5eBQ3p+lKrLb9xD8xOC5HZWJuRnBMBzTWvwuyGCeT1xK5iKNih4RRLmib8XL
RV6xQCgdLeUedrgPON7jl+HuT7zFwiL+FM89JY9ygUE+0D4d/sYhyCuatIAY
3qS6+D1QHm9fzAUN1eMQFi9CWOw+m0a7CXSZZoQyUf1aoPoNUJ5vhijB/v3z
ZzLlvwz6GGskHCCijtxlEYjf1NNa/Er7WlnrAx7GGboNoZOI86XGpo2414/X
Acxf5e811jolfHrCLH/r7hz/6MzEMKaf85ycxCZvZnTGAtk5NWOBgB9Ryunn
clbFIVGCx9PAjvVyS/V3WYyXySR/yq+M/aPkmL1NJvsXNX3xd9EsEYoPrhyu
bEKAQv0QtiE/Bon14SUss5DC376oUSaINLkdQxto6AzxsuW0BrfxVM4gayGD
rIGYeUpk1uMQQ4+dUOceBfmEEmr58fi6ThAHa+FYK0ha8faYfTDm1qO8guLh
GYi57adz95vCFVMKxBv2JT64RGLOCogefMtNMqX4oMPa9J42X2yMD/SWppV0
zD3YrjE5gx7z/VC7xZxJn0J6Pp8vY8NJP7N9ZyoxDT0cV1VqS95bbYmnIplc
KiJRV+LBav+7UZczwNEr/2WuqZa8385XHlxSJJBYJlSydsD9jJeuiGFcUfb1
uXlAZHseQLiiySasoQTjqdk2IQbHCt4cxknnFUw45zbSRBjUYhhNz6WiaZ1G
E0TCaokmzEhYWq+QKMK/j3E0YdMYTmIl/K52K0/wGo6iaQh2d+rdFoimbRBN
z0EG2zW0oUKLlSulzLrWklY8iO5s9YGGz4vFzBXTZhxEvvb282q454dt+XZf
CxdSswwkW83SyAqHhrWa1+0lWjI6UyFIhBk/SSFRojzECjHPg+bdRVMY/p+I
oD+PrKuVMyh6ZvWqVavKDYnGao0Y7MteTfzQB0a2zwZRoOKDi5UuGgrBqRjv
/Z5H0HBKxh8u9JFBUuxcHh6hKgUj40wfGVhy41DJOokMzDWUN05ixOPkxBWw
yBBKFsMl656AqMjR+09yJEmJUuveGEZ5jSThx5fJfS8aDtcVhYNNqL7T0onA
ayx9r+q4MBh8m2qyJBRueOYwGCihWMmuWSV4koKIrSqbIKwRQab2pYZGS5gX
sgLwAO4G9phSSz9D34OmHKD+OI9dkxjg96xOom1Kx0D6C8PhP59AYo2oPxLc
B6Y+RLoiUnEj5X90aROYB2rvDIP/PQH7O1JzUBpAwMvkNhzSfwHAvitIA9sM
8PX8jT+ZRrcJQP+MFCDPnVHvdpzF+2BHFbd980KcUMSiiIB8RaMUIs3cPxbN
M7KI0kEbSSFi0wX4KWhIhDqG84Ag2A/7IQim2RfaJ8b+ENg6IclyQMDLeYN4
AOyc/5qhBHXn9LEyIaCFVmL6x4uL/2UE/5PHoj5t1L399ttZt3z5ctgDXtoe
qk3Ch5D22VeExifO9UshNN5n/fjSJgZpDfyG6lWWbhpdbPRgvZDBiiyJDVa9
e2PzafXUM8KqGBfWKl5vAMuChYFv4SRXneyVPVQFWdwg00DkvU6eH44DlihN
too0QeLHmHhZptS8IwT9IRF0k0iqKp4WdUvQWB0djBrc1WaYH9vmZYpnZ5Ir
AahVKEyj77NUyTJdv7aQtYvHHuuHlKbIxhXHTJo4YcPOyuCm8IPYqDCirgrA
rbQYKy3dvrSP/oWBAmBMk+u+RUU8qnydWVniSHgxH15CNAWf9v4l2LTH3gmi
rptGrFiSvnI+ux5hgFoA1KrQIyjYM+qVHhGFcBzAYBZBmOEBdBQFAkMqRJ8S
kbBWmjkoq7FYRdgifPVgij+cJyHcqncy0L1JOA6PoxJ4X67eKBNCcJRB0BK7
p1Q07jgSCRMSZaeihYavphL2dM4NYzAxVh5q12I+1OQPWKsIkWfTdhgS8pAM
7SARML0eLwK1kDlPvU3Rkzxi82hz/CeFUKchtroMfwFwGCnNxFM4G+It4yke
YgwRhOjZOZR73ttDBJ0uPHZqPYFILEp0NoQaGUxXBdOZa4dwNbV+COHu1Hqe
pldPg+WvX8AfSVxFeZgnbRBwrokCx247v70oF6NX7qOHTI9t01ug/FRO+f5U
KbcIP7gpKkz+Wr6M4SZafekzcNi/M9sVD9aCfKhdbe8FpMIisXOS/zKZoB0t
6BhMf/ZUYvtegP/yE324VhoDamVIVPBx71zcmEVhleGBkLcu8lnrdUGEouEl
rS2ETwgREPLPCiKeAURAOmoQcGG5gcnuWRnlwzbUbmCGFyU7vSotYDqfi9nr
RBWXJ+jCMlExUyS9zm1h00y+xkaj3t9LrT2JJmBlsmHaIo/bVzc/SEEtZYYd
b4YP+QoL+ZxwScrXOisPt2Lo4K7yVCLePCaG+Pt1MqdH3moxtzaXCW1I9lks
ydijFeRNFrihR+FtcKmc1As8+Ynnl2bRf2BrvLloo5D7etEo6yBySXhIFNPm
G09FPYKe3iTexjFdBYTqbCxK0eOvn99IY1r4Hsd4Y8YGfa8rkRjS2uROHfSt
TkzCjPVU6FhaSua8AKf2CjpdkoB+h8j0dhsV01sDZpg0R+KY0R5EeJF6eUi/
L0lVTolSUoiEon2QfuV79HnaMST472loK4MEAEEO3Q87I7mL1eVxFdUWxkrs
mLm3ydDMVvAeZvTNv6tnPNQQz+NbqlnXCx4QG9hvIyGKADgVmR1gAB+kQNgu
YAiEaUaVARVbl8uELBn5ISDckAICzd9vNcK/MxHyiAG0Nd7ZCBAw7p6YmArw
gBB9JRG9ykfzPxM9bohda3wpfptuCqEQxLIAw+YKkQ+SgEm6OuXF2JfFhE4n
ZDSYq8vNcAL/VjAqX4cyA3m1kZqkGHEvytTGXSnaRn9vL/Z3hh2eN4fj342U
4MGzOfL1JvY3bAo76Wj1K/BZmCrelJYQ7vsxTnvDLD486mA/Bj8yHeUpQgf3
WlyOS0c3+XYS5W+dzDRZ5kiSJszLl5n5sYgHiex9gGtiZzqf0V7Km+LI+n0L
1xrzYd8SPiSCHgakDAydwZTYiI6kBd/CQVacI//qeTzYWsatYApwrAAX3foM
u5Xv9ezptkpIalhiL2SXPMoXp+CrFzFVvJXwZJNkZrmr/SqdQVHNN16FqTnu
SeNgFvTU82NRL20gGk/qrW1wmyUwubfGoVdnWXapHDCZta1DKO9K9PrhX8nV
061EJac2RjxXxqlV5tQD5P9YYGrGfR0zLrYA8iSu8XxeZWtniQ1z7kXvU3lq
VaWGpC24G/7dRGEKKRegpEmX/I1FGDs3i96FA+Fk1J1nx/2LA+/vXtyYsYcn
XtVsGhsnVTP9Rn2bsWeWK//6So3nu4NfLbp1XCM53ZCPP6W3UfrU5Pd5Sfq0
WA1SamIdOjYnv9EHqrGaSzv0NOPXKnvFBX2pWyZfJ7WEM3JePS9QS2Bh7Tyi
0nlO5LAmPIwykMSwP/Yiq8yBuqDzqHJmB2axsoJT2H4md+2RpjG2IVVL76iG
gxBns1/Z7BuU6rQbE07LmGVHS7fyjlYNRrSiECt6UW5hsXTIQ7uUQNG2fgp6
xtfbqIamtNvXmEN0UlT6byyi2kmam4HIiuXCpj34KjYQSav+0vwXDs0rVAp8
LhhhFVS7vCjt4t0SEuC8LHoOtkznxGfJFei9nJU26MWc/N4qPvZY8FXsm8Ma
qFMNlRXW2nz1Vtc0h51ldJz5KRJoWbr1XghQhkysxikktK94jmudbGIEZVLQ
qpsMEaftEhNKPvbwoNPafSW6r56K16l/G3mPUPAK+eZlKQ+0ZYl/X0JyBIfB
Ce0OXEYDvpTowGOc7dhBz55J7X2e7A/VknYp0KlIgxiguDMGLB5MP+v1Yeww
rJSwG/Ju3Gk2clscaHGn2WBXSJFjevFgVy6MMz9rT9qqypjd2qLwrFl8G/PU
YHSMvtNbvBcbwY957/Psi1+X8V5qIJ82+lzco1nyaIG9eS4vMsiCWe5ccBkE
ILxUf/r4qaDRGewiPiMLvibVDS8yvjx5XpqMyI0oXsKWAnuUa13xaEFB7iMP
PXR9z/CO1aQnLS6UMe8mxrwHv8tM/MjLfb3MzWFfkuOPJKl3o92pNyWpaHqz
ouHHoBa5J6ZLyrhsP0blvhj3ZAH9VimG2OmjjyMP3rZsJ24B92TYVYzurexB
2B5/V5H7dDB6h1Se5L6h5D69b4riD1uAMqJizaCrZFzZEye6z1RoWnmq6+5q
ixJneGOvNIlyfHOEdpXFe1pQZI06U82cmpS98b+GPXktPrNmT2NlxMiU7r4Q
d1qeMx6HWLc0d/C/LKmIPLHfThH88DfHLLrdWHQbd/PgP/6tMYfKhPQJC5FG
DjgI7FdFz74xjKeWIYViLw/vov1Ib8QPXcidXPvO6RGJwMvqI/uSHrT7niJy
UzyIthnfS9XHxF4aYkqfVPxjq7dEAbdHj+3X1JWYc/G/7hLxyNLoxXMa4j7c
xT4c6n24g32IrgrUi5QQPcl9mAh5XEZED0tKOqzSJtYFb4gnsS6gMUMKRJoF
T+PyVidYjRBkQnNjKz8ub1SrfzInzfhoCyOR1KfUgrT7WG3p5cKxRmnb5v3D
UnkwnZwYy2Uxx4oTj4p4Kz3zO86PlSX9F+/GgE1zkSSXxdjrId5RztwuXTes
FNBP2wIfFkjc1BBXqt/UZy+JYMLoe136qeC3jLSBZEYqts+13RJ3mB/mSHwR
CE5VkycH3qNLm20q1IlBR+4Km+tKii0Ro9WV9g6tiH61t3PlH1gRy5nlvAPI
l0Y3i/+hGmU0PnpmPXdQQkoUHzEZSpyJsOT/wFQ7hvo+ygv2CTjlt0AjLRJD
Oqkrwy4qxFzkY0bjaVRrSI3kPZt7Yl/XYdqE3mcX5bgZmonfb1kbWVdeDKae
DVFtTvt8CQcxYCAKcmgdOXntOsOStH+9GPO5ItOrO9D0z/FcZhGNTYlweEVC
Qpss2sJSTY/zsT/2btCklNEvJKUIuSlNafhki1H05ILbWvTLLaw9hR5IGV/v
+Qe7d+yb3c+NvPW5ErblVLELbbuzlG3VjqiW0arVAq3nZT44/oUFa2AU2LuG
1htlaX5/Rcbp0KSWIRImbUw0kCKcQ0a5qSW0aIJ3BNHMO1lv0pyZFK+1z16a
koM/c95+m7KKZbpHIaEuCHa1HiIWlizZv8ryKhWwqo6Uo8+XuRCVNMXsI2uM
Kw7JcmiBa+gZ9mY9fZ55JSukkbKMaim2nDB2xn8bYP+IDWJqVUx2/j6arCBo
CvSkako1HZoKAhZJFWFWyqYVZMvAploccJBXWZEeoo9UJhmzKUsTm3LFtjSZ
eXNLKqBHUkCParGsRzw5cN8sdsE+WgyhUp+naMuFAZiJ2SxPv/26bpt425TQ
At3STVbiQ1uhJtBJwYlovdTykJ8HFgtXb6+sxCviTrP7X0SuuzqyTsw0DP9Q
oiine8ku2ZQhnifwwO8eHJX8boA41FVDRS5X2WOkLO4uaDRbQDKo0OpvePCI
n6vC2CvETJGhR+B8OnKBsUE8ueiLIm991gwRtit3hM6NGSAfWceIqTJT7NJq
WpT9S+dQC61KAuA9T9fIPhww+bQRsnr3ONgg4JHY01lK6y7+DuhoVCQVRTfe
21/C5+mAKGUG3VdsGCiDGiRdasfieNqbqQEtJQ+yx2WNGWUQueNRUgL8+ty+
Xfvv9/La6UGfe3fZPQKa1exMkgqCXzptr2jni8MfrgauF97DJrRe8fu/53mD
9H2Nf7+XV8Wnzl/1HgRwpJFLojkZp/nwMlhn7CS5p1lyNxW12OOt9BWNXor0
0flC4CO+HDm9WGkmp3xZ5K3Pxk8+L/wfqssCny9pPFNIXkwx8eDvQiLvEyfT
9cBxvxY5hYrSZzx878+4IpVJfXREbO7PXOm7An//576d3eUlzy5dq5EySJ4f
fih90d9BkT1ijWr50CvwT7ZUuxl+Km0OzS8iR4l1XuTIV0Xe+rvo5Tipdg7b
tw+4utQH0DWkuxGlDsYWzlwTeStGyrHeYqyglsNei3/IerGDHV3KHPGDXR95
668/+WFviLz1V5F1PEsy3iMQbr4xslssqR9Dv4v6fXKUm8xosX2PTa0LPn5E
ZPOYkCpziFsim/95ZN1xkUMILm+NbP5nkXXH22XKjiMjG6XvX4vuOMpWxDan
qw1GlDKjIxsNiKwjHNEqmTR5e2SjWAV0pH3iP/COd0Q26hdZd6jtKM9eudOu
LLb5Iba5PF/z7shGXZF1P7Md5UsM7ols1BlZd5DtKN+4dm9ko1hL4gdmS/mq
6TF2ZbHNv2Of833efGxko1jL6Vu2IyeCzLjIRm2Rdd+wHX/GO46PbNQaWfdV
2/EQ3nGCXVls86+YIQ7lzSdGNorNLPlH+5wjeMdJkY1iLesv2o5M3pkHIhvF
BgE/ZzsyYWQm25XFNv9b25wfCZyZGtko1qH9tO34G95xWmSjWCPmL8yW/O2z
mQcjG8WqxgPtE8/gHadHNopVXv1tR/6yucwMM0ls8y7bnDsfmZmRjWKSqLft
yEVeZlZko5isaTWTXMo7zo5sFNMBTfaJrMMyc+zKYpvX2eYsQzLz5JRi2bHG
NuYUnpkvp5HKf5W23c283YLUJw/SATDaiPNFZiH+oQ9mfs5kPvU/8wzcxA==
\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"TLneu", "[", 
    RowBox[{
     RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "t0", ",", 
     RowBox[{"tn", "/", "10"}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\< t \\t\>\"", ",", "\"\< T \\t\>\""}], "}"}]}], ",", 
   RowBox[{
   "PlotLabel", "\[Rule]", " ", 
    "\"\<anf\[ADoubleDot]nglicher Temperaturverlauf in der MItte\>\""}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.41931874465625*^9, 3.419318772625*^9}, {
  3.419318855671875*^9, 3.419318869796875*^9}, {3.419319140578125*^9, 
  3.419319141234375*^9}, {3.447388217859375*^9, 3.44738822084375*^9}, {
  3.481944696875*^9, 3.481944707140625*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwl13k8VO0XAHBJ8paoXnlJ9jYlWaKU5WDs+8wYY1/H0kKyZgvJlmasSdZK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" T \\t\"", TraditionalForm]},
  AxesOrigin->{0, 74.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotLabel->FormBox[
   "\"anf\[ADoubleDot]nglicher Temperaturverlauf in der MItte\"", 
    TraditionalForm],
  PlotRange->{{0, 1000}, {74.57867296818827, 100.00000003638901`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.41578011896875*^9, 3.415944679234375*^9, 3.419318055953125*^9, {
   3.4193187659375*^9, 3.41931877325*^9}, 3.419318871125*^9, 
   3.41931922684375*^9, 3.419319774640625*^9, 3.41932044271875*^9, 
   3.41932183253125*^9, 3.419321888234375*^9, 3.419331865015625*^9, 
   3.419332894875*^9, 3.4193343383125*^9, 3.419356118234375*^9, 
   3.44738549225*^9, 3.44738721403125*^9, 3.44738805028125*^9, 
   3.44738822175*^9, 3.44738842346875*^9, 3.447388979140625*^9, 
   3.44755661190625*^9, 3.4819447080625*^9, 3.641098893573455*^9, 
   3.6410999939671345`*^9, 3.641101699050366*^9, 3.641646787053728*^9, 
   3.6416476809313593`*^9, 3.641694342210845*^9}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.419320352125*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"direkter", " ", "Vergleich", " ", "beider", " ", 
   RowBox[{"L\[ODoubleDot]sungen", ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.419320021109375*^9, 3.419320052703125*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"TLneu", "[", 
      RowBox[{
       RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}], ",", 
     RowBox[{"TL", "[", 
      RowBox[{
       RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "t0", ",", 
     RowBox[{"tn", "/", "10"}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\< t \\t\>\"", ",", "\"\< Abweichung \\t\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "Blue", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Dashed", ",", "Thick"}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.447389117109375*^9, 3.44738912471875*^9}, {
  3.481944724140625*^9, 3.481944731828125*^9}, {3.641693939633196*^9, 
  3.641693991758122*^9}, {3.6416940288830767`*^9, 3.641694031086195*^9}, {
  3.6416943981482825`*^9, 3.64169440105453*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
    LineBox[CompressedData["
1:eJwl13k8VO0XAHBJ8paoXnlJ9jYlWaKU5WDs+8wYY1/H0kKyZgvJlmasSdZK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     "]]}, 
   {RGBColor[1, 0, 0], Thickness[Large], Opacity[1.], Dashing[{Small, Small}],
     LineBox[CompressedData["
1:eJwl1nk4VO0bB3BL0SJSKkKSVpXsLS/jxtgHY4Yx9p0IUbZXErJvYyt5yRIh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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" Abweichung \\t\"", TraditionalForm]},
  AxesOrigin->{0, 74.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{558., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 1000}, {74.57867296818827, 100.00000003638901`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.447389125421875*^9, 3.447556612015625*^9, 
  3.48194473378125*^9, 3.6410988936984572`*^9, 3.6410999940921335`*^9, 
  3.6411016992847424`*^9, 3.641646787178726*^9, 3.641647681103235*^9, 
  3.641694342460844*^9, 3.6416944049607787`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TLneu", "[", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}], "-", 
    RowBox[{"TL", "[", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "t0", ",", 
     RowBox[{"tn", "/", "10"}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\< t \\t\>\"", ",", "\"\< Abweichung \\t\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.41931874465625*^9, 3.419318772625*^9}, {
  3.419318855671875*^9, 3.419318869796875*^9}, {3.419319140578125*^9, 
  3.419319141234375*^9}, {3.41931940775*^9, 3.419319418*^9}, {
  3.41931945146875*^9, 3.41931946553125*^9}, {3.447388339140625*^9, 
  3.4473883401875*^9}, {3.447389094578125*^9, 3.447389096703125*^9}, {
  3.481944739359375*^9, 3.481944746796875*^9}, {3.64169403464869*^9, 
  3.6416940367580624`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJw013k8lF8XAHAhFCI72UMqu7Fm5sEMDdkShZ+QLZUkKUJCsiUhIVuUpFJJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" Abweichung \\t\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 1000}, {-0.0010477656529417345`, 0.0004043169921317258}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.419319418890625*^9, 3.4193194661875*^9, 
  3.419319774921875*^9, 3.419320442859375*^9, 3.41932183265625*^9, 
  3.419321888359375*^9, 3.419331865140625*^9, 3.419332895*^9, 
  3.4193343384375*^9, 3.419356118375*^9, 3.44738549240625*^9, 
  3.44738721415625*^9, 3.447388050375*^9, 3.447388423640625*^9, 
  3.447388979296875*^9, 3.4473890976875*^9, 3.447556612109375*^9, 
  3.48194474803125*^9, 3.6410988940109572`*^9, 3.6410999944202614`*^9, 
  3.64110170017537*^9, 3.641646787491229*^9, 3.6416476814626107`*^9, 
  3.641694343210843*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TLneu", "[", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}], "-", 
    RowBox[{"TL", "[", 
     RowBox[{
      RowBox[{"zn", "/", "2"}], ",", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\< t \\t\>\"", ",", "\"\< Abweichung \\t\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6411010657671595`*^9, 3.6411010661890373`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJws13c8lt//B3DJSiXZJEmSvfd6c5N1D/ctlRBSKVIURURCyghJshKSFJWV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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" Abweichung \\t\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 10000}, {-0.0010476016707059443`, 0.0013247548651378338`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.641101700847246*^9, 3.6416467883874693`*^9, 
  3.641647681868862*^9, 3.6416943437733474`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"TLneu", "[", 
     RowBox[{"zn", ",", "t"}], "]"}], "-", 
    RowBox[{"TL", "[", 
     RowBox[{"zn", ",", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\< t \\t\>\"", ",", "\"\< Abweichung \\t\>\""}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.6411010841109686`*^9, 3.6411010894391065`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJxF0H0w03EcB/CV3DYdlYcsQlt5aOahzJGRrJaVELeQWp7idGFdux6FtlC/
5cpTujkayhKyPMw0j1nNqRzdSXlsl46V3JFUXFHd1ef7uXvf+17/ve9DjuYF
x67E4XD+f/K3pU6emjftVG/cv7vcJ3K6hRF2/Tdh7bAsAiOBXzrpzOzB7MA1
3qbZbpg7WOJL1jhjbPBtP5trDlgYOK/HbsQeiwe7BL33DMm5AB5X0VcwloTg
Q46V+UXGGJikTFYZyW6Cf8z3h3A/54KzrArFjN0FYLlzU4NQJAZr89MfRomL
wE+Jy3y/TxLwa61RVpygFO3t4Dwf1r0LLi9J4IVU3QN7Vh7RKaZLwbYt5CXt
2H3wiI9x7AnBA7Dp7KhSjq8CSytSz+Fl1WAl9o1i7VEDpvBZruwJGZgarxkM
fPYInFGFZUdhtWA9/p3FeW4dOLjX8uipLfXgtFj53KpJ5IE0xc6NygbwjKO1
YEOaHEyPXjor5jSCub3TZS42CvC+V2x1/UfkiNA1xY2tTWC30z4nJVceg7+q
MV4ZS4n+I/GytSM1gzP1uQN5I8jhy5PuwtoW8GzGWG7I+VZw4t4pCovRBja6
HhPXaNAOvnTct1S/Hxkf9aJrjtMBVtGWBqdbkTWdE5NDVk/AhuYZgUQRstRr
sI46jUxLcd92OKAT3JXqT+xWIKv2k0btzVTgjq2Yw7g5chthMaXQArlJPWxJ
JCNXMyWRE7bI+R42H0pckeOo9CmTIOQYYjmjJxg5UmuSlc5BDpd+p82FIgdQ
mpP6jiG7mTG/iBKQ6Qt1TGYS8va3m/MWeMi0Al16PB95k2H3GdZFZIvZHeqf
ychmfZXrG1KQjW9kKSgC5HWJv/BDQmSDA0lhOenIq+3fVbAzkQl6BxeWryL/
BpQ6Joo=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\" t \\t\"", TraditionalForm], 
    FormBox["\" Abweichung \\t\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 10000}, {-1., 1.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.641101700987873*^9, 3.641646788507163*^9, 
  3.641647681962613*^9, 3.6416943438983445`*^9}]
}, Open  ]],

Cell[TextData[{
 "\n  \n  \n  \n",
 StyleBox["F) Kontrolle : eine analytische Berechnung",
  FontSize->24,
  FontWeight->"Bold"]
}], "Text",
 CellChangeTimes->{{3.4819448658125*^9, 3.481944888421875*^9}, {
  3.481944929921875*^9, 3.48194493765625*^9}, {3.4819455681875*^9, 
  3.48194557584375*^9}, {3.6410986687447233`*^9, 3.6410986693072243`*^9}}],

Cell[TextData[{
 StyleBox["\n",
  FontSize->24],
 "(*",
 StyleBox[" ",
  FontSize->24],
 "Die exakte Behandlung (im Sinne einer einfachen L\[ODoubleDot]sungsformel) \
ist meistens nicht m\[ODoubleDot]glich. Oft ben\[ODoubleDot]tigt man \
(unendliche) Reihen, um die L\[ODoubleDot]sung darzustellen. Man findet das L\
\[ODoubleDot]sungsverfahren in B\[UDoubleDot]chern \[UDoubleDot]ber partielle \
Differentialgleichungen *)"
}], "Text",
 CellChangeTimes->{{3.4819448658125*^9, 3.481944888421875*^9}, {
  3.481944929921875*^9, 3.48194493765625*^9}, {3.4819455681875*^9, 
  3.481945586203125*^9}, {3.6416469581010833`*^9, 3.6416469910074267`*^9}}],

Cell[BoxData[
 RowBox[{"<<", "\"\<FourierSeries`\>\""}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p", "=", 
  RowBox[{"2", "zn"}]}]], "Input",
 CellChangeTimes->{{3.481945111046875*^9, 3.481945121140625*^9}}],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{{3.48194511446875*^9, 3.481945122421875*^9}, 
   3.481952301828125*^9, 3.4819537829375*^9, 3.641098895151586*^9, 
   3.6410999945140095`*^9, 3.641101702769128*^9, 3.6416467895068607`*^9, 
   3.641647682978238*^9, 3.6416943453202157`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Omega]", " ", "=", " ", 
  RowBox[{"2", 
   RowBox[{"Pi", "/", "p"}]}]}]], "Input",
 CellChangeTimes->{{3.48194512596875*^9, 3.481945129515625*^9}}],

Cell[BoxData["\[Pi]"], "Output",
 CellChangeTimes->{3.48194513609375*^9, 3.481952301921875*^9, 
  3.481953783015625*^9, 3.6410988951828346`*^9, 3.6410999945296354`*^9, 
  3.641101702831628*^9, 3.641646789538108*^9, 3.641647682993864*^9, 
  3.641694345335842*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nmax", "=", "10"}]], "Input",
 CellChangeTimes->{{3.481945166609375*^9, 3.481945167125*^9}, {
  3.481945309953125*^9, 3.481945310421875*^9}}],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.48194516796875*^9, 3.48194531125*^9, 3.481952302*^9, 
  3.48195270178125*^9, 3.481953783109375*^9, 3.6410988951984596`*^9, 
  3.6410992749651117`*^9, 3.6410999945452604`*^9, 3.641101702878503*^9, 
  3.6416467897412343`*^9, 3.641647683009489*^9, 3.64169434536709*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "fr", "]"}]], "Input",
 CellChangeTimes->{{3.481945262828125*^9, 3.48194526675*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Bem", "."}], ":", " ", 
     RowBox[{
     "wenn", " ", "man", " ", "zu", " ", "einer", " ", "Fkt", " ", "fS"}]}], 
    " ", "=", " ", 
    RowBox[{"f", " ", "-", " ", 
     RowBox[{"TRand", " ", "\[UDoubleDot]bergeht"}]}]}], ",", "  ", 
   "\[IndentingNewLine]", "   ", 
   RowBox[{
    RowBox[{
     RowBox[{"gilt", " ", 
      StyleBox[
       RowBox[{"fS", 
        RowBox[{"(", 
         RowBox[{"Rand", ",", 
          RowBox[{"t", "=", "0"}]}], ")"}]}],
       FontColor->GrayLevel[0]]}], 
     StyleBox[" ",
      FontColor->GrayLevel[0]], 
     StyleBox["=",
      FontColor->GrayLevel[0]], 
     StyleBox[" ",
      FontColor->GrayLevel[0]], 
     StyleBox[
      RowBox[{"0", " ", ":", " ", 
       RowBox[{
        RowBox[{"sog", ".", " ", "homogene"}], " ", "Randbedingungen"}]}],
      FontColor->GrayLevel[0]]}], ";", " ", "\[IndentingNewLine]", "   ", 
    RowBox[{
    "nur", " ", "daf\[UDoubleDot]r", " ", "gilt", " ", "die", " ", "folgende",
      " ", "L\[ODoubleDot]sungsformel"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6410983739314566`*^9, 3.641098420806573*^9}, {
   3.641098474275463*^9, 3.6410985024317856`*^9}, 3.6416462790054164`*^9, {
   3.6416465413498936`*^9, 3.641646604459447*^9}, {3.641694114351716*^9, 
   3.641694115820465*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fS", "[", "z_", "]"}], "=", " ", 
  RowBox[{
   RowBox[{"f", "[", "z", "]"}], "-", "TRand", "  ", 
   RowBox[{"(*", " ", 
    RowBox[{"homogene", " ", "Randbedingungen", " ", "herstellen"}], " ", 
    "*)"}]}]}]], "Input",
 CellChangeTimes->{{3.641099250636919*^9, 3.641099259230691*^9}, {
   3.641099323715243*^9, 3.64109933796528*^9}, 3.641646351833743*^9}],

Cell[BoxData[
 RowBox[{"100", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"UnitStep", "[", 
      RowBox[{
       RowBox[{"-", "0.6`"}], "+", "z"}], "]"}]}], "+", 
    RowBox[{"UnitStep", "[", 
     RowBox[{
      RowBox[{"-", "0.4`"}], "+", "z"}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.6410992605900736`*^9, 3.6410999945765104`*^9, 
  3.641101702941003*^9, 3.641646789834984*^9, 3.64164768304074*^9, 
  3.641694345413966*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "wir", " ", "brauchen", " ", "die", " ", "halbseitige", " ", "Fourier"}], 
   "-", "Sinus", "-", "Entwicklung"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.481945375*^9, 3.481945424203125*^9}, 
   3.6416941560079174`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fr", "[", "z_", "]"}], "=", 
  RowBox[{"FourierSinSeries", "[", 
   RowBox[{
    RowBox[{"fS", "[", "z", "]"}], ",", "z", ",", "nmax", ",", 
    RowBox[{"FourierParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Omega]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.481945206875*^9, 3.481945209171875*^9}, {
   3.481945269765625*^9, 3.481945277640625*^9}, 3.6410992302306147`*^9}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"39.34526572333864`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"34.33574765336559`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"3", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"25.464790894703253`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"5", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"14.715320422870967`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"7", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"4.371696191482071`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"9", " ", "\[Pi]", " ", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.481945214890625*^9, 3.481945278609375*^9, 3.48194531940625*^9, 
   3.48195230334375*^9, 3.481952462921875*^9, 3.48195270484375*^9, 
   3.481953785296875*^9, 3.641098899307846*^9, {3.64109927484011*^9, 
   3.641099278074494*^9}, 3.641099997560893*^9, 3.64110170837852*^9, 
   3.641646795522256*^9, 3.641647686212624*^9, 3.6416943501795845`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fS", "[", "z", "]"}], ",", 
     RowBox[{"fr", "[", "z", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4819452405625*^9, 3.481945248890625*^9}, {
   3.481945282453125*^9, 3.48194528346875*^9}, 3.641099295808918*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQ7ZX64uKBl6F2DFDwfF1Y0n1JE3sYX4z7at9mSRc4
X89SZOlcyRA43+qC8YZJkilw/oHZh017JUvg/ObG7oouyRY4P6XkvWSn5BQ4
n2OK58IPH5fA+dsvGLm7y62H8yOa79w63L0Fzs/fWKw748tOOP/ThGsnGBn3
w/knDh7bf97mEJyfWenJG/nmCJx/kNPo/5rc43D+ssVH/kmpnoLzHcT2Lgpe
dwbO1z1+Z8cxrfNw/hWH4Hcr312A83O4si9dNbgE55++Eb6Xr+8ynB/sFvHw
yZMrcL7Zgu7wBSrX4PwH/yZfyai/DufzvLnQXd6C4Fvc5HVu60TwJ2xu37h4
MoLvkFHdd285gr/wYpJHyAUEP2mJ4R57xRtwft/EvGI/NQR/V91qrVhtBF8o
UnVmlSmCf5hXsmyrJ4KvUs5goF2E4D/1PL9Y7DCSfLd6/8QTCH7KmfoqnnMI
/iM/g0Cmmwj+veCJ/96+Q/BvxAZHHpW6CeeLz1/t4qCA4Ic9YDbYrYrgX0na
wrbRAMG/mC66ZY4bgi+wMne+uA+CH/DqaNekQAT/XE5ZYkcMgn+q8DpfSRGC
z7lZ/9e7cgTf40v708xaBL/D9MGFJ00I/vEyiz3xHQg+244Jy2/1IvhuP19M
Cp2M4N88m6+YMAXBBwA8LeZX
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQHZ16WPDyvJv2DGAQ6XCg4ZeY+RYEf29r9BGlUwj+
tn5Z+V9fEfwNM+9XXlS8BedrTSxs/HsWwV/awdypWXUbzv+aHPUqbfcdOJ/b
pS1oo/g9OL9G4CnPw5j7cD7PPm2G674P4HzbMv+/h38h+HOW9CxWnvMQzo8L
NTnL6f0Izu8S9TV4sgDB33o1dfK+bwh+m4l/42Gux3B+2GSL/BNyCP4+J91n
pzQQ/CBfufJpBgg+ANSqXnc=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBmIQLSLp8f686WN7Bii45TlnxjlzBH9LaaSZvxWC37dQ
7Mp5GwQ/4+zlwgB7BN/p5wT+i44I/vcAbu9Lbgj+pZoTL4I8Efw1K1rbLnsj
+AkMDIeuBCD4J9Z/sbgeheDP4LundicPwbc8s4Hp2TQEX2ZR9a45MxF8hgq3
ouA5SOYp33l4YCGCH1bNfnD2GgS/SCuuPvAQkvs6uP/seYvgK7imfZ3s8gTO
NzUxnbjlGYJ//1PvycWtT+H8N8aBrZJGz+B8tde6rxgvI/hHVEovFTQ+h/P7
r1xNDlJ5Aee/Dz4wkekIgr8pVNTZsvAlnL/4bPPcR0KvEOF9PKZa6BCC/2Di
/q8Cea/h/G8XrSWb+N7A+QVTlA5U7kHwxc8qCTyJewvnB19d80fmH4L/KX5h
zp1V7+D8/QnrW/l83sP5u87neN/zQ/C32WkJrgtE8NfILJ3jG47gz7oxa3NP
EoJfGtD2kKsSwdd2iLVlX4bgq62XYr6+AsFXkrtxYtlqBF/iT1CI20YEn22H
R3brHgT/ob7JTObLCP6deR/jLl9F8G/wrldZfAPBP/dac4PTPQR/z3L5440v
EfwdYnd7At8g+JtbZwUpvkfwVyWL3jvwBcFfeunS4gnfEfwFjhMyE34h+HM2
+Oob/EXwp8tzf/3/H8EHALIZ/Wo=
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwcl3c81e/7x09GhMyjKJWsJKuipHK9W5IoiWwhSYWPWTQkSUSRJCRZSbKS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      "]]}, {}}, {{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {-5.25462780830809, 118.23276069615784`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.481945249859375*^9, 3.481945283984375*^9, 
  3.48194532175*^9, 3.481952304*^9, 3.481952503015625*^9, 
  3.481952706046875*^9, 3.481953785640625*^9, 3.641098899854726*^9, 
  3.6410992975120473`*^9, 3.641099997748395*^9, 3.641101709191024*^9, 
  3.641646796276166*^9, 3.6416476867907495`*^9, 3.6416943507264605`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nmax", "=", "20"}]], "Input",
 CellChangeTimes->{{3.481945166609375*^9, 3.481945167125*^9}, {
  3.481945309953125*^9, 3.481945310421875*^9}, {3.481945467953125*^9, 
  3.481945468265625*^9}}],

Cell[BoxData["20"], "Output",
 CellChangeTimes->{3.48194516796875*^9, 3.48194531125*^9, 
  3.481945469078125*^9, 3.481952304109375*^9, 3.48195303290625*^9, 
  3.48195378575*^9, 3.641098899885973*^9, 3.6410993076214514`*^9, 
  3.6410999977796454`*^9, 3.641101709222275*^9, 3.64164679629716*^9, 
  3.6416476868532495`*^9, 3.6416943507577095`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "fr", "]"}]], "Input",
 CellChangeTimes->{{3.481945262828125*^9, 3.48194526675*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fr", "[", "z_", "]"}], "=", 
  RowBox[{"FourierSinSeries", "[", 
   RowBox[{
    RowBox[{"fS", "[", "z", "]"}], ",", "z", ",", "nmax", ",", 
    RowBox[{"FourierParameters", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"1", ",", "\[Omega]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.481945206875*^9, 3.481945209171875*^9}, {
   3.481945269765625*^9, 3.481945277640625*^9}, 3.6410993173871007`*^9}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"39.34526572333864`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"34.33574765336559`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"3", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"25.464790894703253`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"5", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"14.715320422870967`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"7", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"4.371696191482071`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"9", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"3.576842338485331`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"11", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"7.923634073853597`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"13", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"8.48826363156775`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"15", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"6.059249585888046`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"17", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"2.0708034591230864`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"19", " ", "\[Pi]", " ", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.481945214890625*^9, 3.481945278609375*^9, 
  3.48194531940625*^9, 3.481945478*^9, 3.48195230428125*^9, 
  3.481952589421875*^9, 3.481952716078125*^9, 3.4819530378125*^9, 
  3.48195378959375*^9, 3.641098906901617*^9, 3.6410994016217113`*^9, 
  3.641100004732788*^9, 3.6411017176285486`*^9, 3.641646804116274*^9, 
  3.6416476951345234`*^9, 3.641694357867078*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fS", "[", "z", "]"}], ",", 
     RowBox[{"fr", "[", "z", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4819452405625*^9, 3.481945248890625*^9}, {
   3.481945282453125*^9, 3.48194528346875*^9}, 3.6410993696059933`*^9}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBGIQ7ZX64uKBl6F2DFDwfF1Y0n1JE3sYX4z7at9mSRc4
X89SZOlcyRA43+qC8YZJkilw/oHZh017JUvg/ObG7oouyRY4P6XkvWSn5BQ4
n2OK58IPH5fA+dsvGLm7y62H8yOa79w63L0Fzs/fWKw748tOOP/ThGsnGBn3
w/knDh7bf97mEJyfWenJG/nmCJx/kNPo/5rc43D+ssVH/kmpnoLzHcT2Lgpe
dwbO1z1+Z8cxrfNw/hWH4Hcr312A83O4si9dNbgE55++Eb6Xr+8ynB/sFvHw
yZMrcL7Zgu7wBSrX4PwH/yZfyai/DufzvLnQXd6C4Fvc5HVu60TwJ2xu37h4
MoLvkFHdd285gr/wYpJHyAUEP2mJ4R57xRtwft/EvGI/NQR/V91qrVhtBF8o
UnVmlSmCf5hXsmyrJ4KvUs5goF2E4D/1PL9Y7DCSfLd6/8QTCH7KmfoqnnMI
/iM/g0Cmmwj+veCJ/96+Q/BvxAZHHpW6CeeLz1/t4qCA4Ic9YDbYrYrgX0na
wrbRAMG/mC66ZY4bgi+wMne+uA+CH/DqaNekQAT/XE5ZYkcMgn+q8DpfSRGC
z7lZ/9e7cgTf40v708xaBL/D9MGFJ00I/vEyiz3xHQg+244Jy2/1IvhuP19M
Cp2M4N88m6+YMAXBBwA8LeZX
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQHZ16WPDyvJv2DGAQ6XCg4ZeY+RYEf29r9BGlUwj+
tn5Z+V9fEfwNM+9XXlS8BedrTSxs/HsWwV/awdypWXUbzv+aHPUqbfcdOJ/b
pS1oo/g9OL9G4CnPw5j7cD7PPm2G674P4HzbMv+/h38h+HOW9CxWnvMQzo8L
NTnL6f0Izu8S9TV4sgDB33o1dfK+bwh+m4l/42Gux3B+2GSL/BNyCP4+J91n
pzQQ/CBfufJpBgg+ANSqXnc=
      "]], LineBox[CompressedData["
1:eJxTTMoPSmViYGCwBmIQLSLp8f686WN7Bii45TlnxjlzBH9LaaSZvxWC37dQ
7Mp5GwQ/4+zlwgB7BN/p5wT+i44I/vcAbu9Lbgj+pZoTL4I8Efw1K1rbLnsj
+AkMDIeuBCD4J9Z/sbgeheDP4LundicPwbc8s4Hp2TQEX2ZR9a45MxF8hgq3
ouA5SOYp33l4YCGCH1bNfnD2GgS/SCuuPvAQkvs6uP/seYvgK7imfZ3s8gTO
NzUxnbjlGYJ//1PvycWtT+H8N8aBrZJGz+B8tde6rxgvI/hHVEovFTQ+h/P7
r1xNDlJ5Aee/Dz4wkekIgr8pVNTZsvAlnL/4bPPcR0KvEOF9PKZa6BCC/2Di
/q8Cea/h/G8XrSWb+N7A+QVTlA5U7kHwxc8qCTyJewvnB19d80fmH4L/KX5h
zp1V7+D8/QnrW/l83sP5u87neN/zQ/C32WkJrgtE8NfILJ3jG47gz7oxa3NP
EoJfGtD2kKsSwdd2iLVlX4bgq62XYr6+AsFXkrtxYtlqBF/iT1CI20YEn22H
R3brHgT/ob7JTObLCP6deR/jLl9F8G/wrldZfAPBP/dac4PTPQR/z3L5440v
EfwdYnd7At8g+JtbZwUpvkfwVyWL3jvwBcFfeunS4gnfEfwFjhMyE34h+HM2
+Oob/EXwp8tzf/3/H8EHALIZ/Wo=
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwcV3k8lN/bHmSJkoiQLCWViEqFcJ8iCUnSWAZRRClJkiRLVEKSJKQSQqJU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      "]]}, {}}, {{}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {-6.756036938316679, 112.42810533861142`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.481952718953125*^9, 3.4819537900625*^9, 3.6410989071516204`*^9, {
   3.6410993528871984`*^9, 3.641099370980999*^9}, 3.6410994049967213`*^9, 
   3.641100004982793*^9, 3.6411017178629246`*^9, 3.6416468043506503`*^9, 
   3.641647695384526*^9, 3.6416943582108297`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SinKoeff", " ", "=", " ", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"FourierSinCoefficient", "[", 
     RowBox[{
      RowBox[{"fS", "[", "z", "]"}], ",", "z", ",", "n", ",", 
      RowBox[{"FourierParameters", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "\[Omega]"}], "}"}]}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.481952968*^9, 3.4819529838125*^9}, {
   3.481953044234375*^9, 3.481953098125*^9}, 3.641099421731142*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"39.34526572333864`", ",", "0.`", ",", 
   RowBox[{"-", "34.33574765336559`"}], ",", "0.`", ",", 
   "25.464790894703253`", ",", "0.`", ",", 
   RowBox[{"-", "14.715320422870967`"}], ",", "0.`", ",", 
   "4.371696191482071`", ",", "0.`", ",", "3.576842338485331`", ",", "0.`", 
   ",", 
   RowBox[{"-", "7.923634073853597`"}], ",", "0.`", ",", "8.48826363156775`", 
   ",", "0.`", ",", 
   RowBox[{"-", "6.059249585888046`"}], ",", "0.`", ",", 
   "2.0708034591230864`", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{{3.4819529785625*^9, 3.481952986578125*^9}, 
   3.481953053515625*^9, 3.48195310025*^9, 3.48195379396875*^9, 
   3.641098914276639*^9, 3.6410994313249207`*^9, 3.641100011779681*^9, 
   3.6411017255191994`*^9, 3.6416468131163025`*^9, 3.6416477024626675`*^9, 
   3.6416943661014442`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SinKoeff", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.48195311190625*^9, 3.48195312246875*^9}}],

Cell[BoxData["39.34526572333864`"], "Output",
 CellChangeTimes->{3.48195312275*^9, 3.48195379415625*^9, 
  3.641098914370387*^9, 3.641099437762439*^9, 3.6411000118578067`*^9, 
  3.6411017256129494`*^9, 3.641646813210052*^9, 3.6416477025876684`*^9, 
  3.6416943662264442`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "die", " ", "Randtemperatur", " ", "wird", " ", "wieder", " ", "addiert"}], 
  " ", "*)"}]], "Input",
 CellChangeTimes->{{3.641646639834546*^9, 3.64164667370964*^9}, {
  3.6416941802266383`*^9, 3.641694196929744*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{"z_", ",", "t_"}], "]"}], "=", " ", 
  RowBox[{
   RowBox[{
    StyleBox["TRand",
     FontColor->RGBColor[1, 0, 0]], " ", "+", " ", 
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"SinKoeff", "[", 
        RowBox[{"[", "n", "]"}], "]"}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"n", " ", 
             RowBox[{"Pi", "/", "zn"}]}], ")"}], "^", "2"}]}], "  ", 
         FractionBox[
          RowBox[{"\[Lambda]", " ", "*", "t"}], 
          RowBox[{"cp", " ", "\[Rho]"}]]}], "]"}], " ", 
       RowBox[{"Sin", "[", 
        RowBox[{"n", " ", "Pi", " ", 
         RowBox[{"z", "/", "zn"}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "1", ",", "nmax"}], "}"}]}], "]"}]}], "/.", 
   "Materialdaten", " "}]}]], "Input",
 CellChangeTimes->{{3.481952765171875*^9, 3.481952817484375*^9}, {
   3.481952882359375*^9, 3.481952938125*^9}, {3.481953105390625*^9, 
   3.481953178453125*^9}, {3.481953872765625*^9, 3.481953878453125*^9}, {
   3.6410994434187036`*^9, 3.6410994722937813`*^9}, 3.641646355552503*^9}],

Cell[BoxData[
 RowBox[{"0.`", "\[VeryThinSpace]", "+", 
  RowBox[{"39.34526572333864`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"34.33574765336559`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"3", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"25.464790894703253`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "10400"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"5", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"14.715320422870967`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"49", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"7", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"4.371696191482071`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"81", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"9", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"3.576842338485331`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"121", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"11", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"7.923634073853597`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"13", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "20000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"13", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"8.48826363156775`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "10400"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"15", " ", "\[Pi]", " ", "z"}], "]"}]}], "-", 
  RowBox[{"6.059249585888046`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"289", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"17", " ", "\[Pi]", " ", "z"}], "]"}]}], "+", 
  RowBox[{"2.0708034591230864`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"361", " ", 
       SuperscriptBox["\[Pi]", "2"], " ", "t"}], "260000"]}]], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"19", " ", "\[Pi]", " ", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.481952944625*^9, {3.48195316584375*^9, 3.4819531795625*^9}, 
   3.481953794265625*^9, 3.481953879359375*^9, 3.641098914401639*^9, {
   3.6410994480905933`*^9, 3.641099473465661*^9}, 3.6411000119046817`*^9, 
   3.6411002722179213`*^9, 3.6411017256754503`*^9, 3.6416468132881765`*^9, 
   3.6416477026189194`*^9, 3.6416943663201942`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"u", "[", 
   RowBox[{".5", ",", "1"}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.4819533043125*^9, 3.48195332959375*^9}}],

Cell[BoxData["90.2694277060115`"], "Output",
 CellChangeTimes->{{3.48195331271875*^9, 3.481953330359375*^9}, 
   3.48195379440625*^9, 3.48195388484375*^9, 3.641098914432891*^9, 
   3.6410994767156706`*^9, 3.641100011935935*^9, 3.6411017257692003`*^9, 
   3.6416468133350573`*^9, 3.6416477026501684`*^9, 3.641694366382696*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Gesamtsicht", ":"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6416471686798306`*^9, 3.6416471757423477`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"z", ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"TRand", "+", "deltaT"}]}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Axiale z- Richtung [ m]\\t\>\"", ",", "\"\<\\tZeit [s]\>\"", ",", 
      "\"\<Temperatur [\[Degree]C]\\t\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.48195320528125*^9, 3.481953206671875*^9}, {
   3.641099483293812*^9, 3.641099484856318*^9}, {3.6411011049704065`*^9, 
   3.6411011189235706`*^9}, 3.6416463609587746`*^9}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyUnXk0V9/3/2nWgKRIKqSZlHl+XUN4FSWaNGjQXKR5UmmeNGmQ5gHRbC5S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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxFm3kcVcP/xu899545E9nKmq1I9j0pa2QnKbtkKRFR2dJGpJUs2eMre0lp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          "]], Polygon3DBox[CompressedData["
1:eJwtm3ccT9Ubx+/3e8f5SpSWFiG0tacGaUiiKNKQ2ULKiBLJbkuptKSUUVRS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          "]], Polygon3DBox[CompressedData["
1:eJwt13e8j+Ufx/EvjnOa/EQZTavSNhKJQioZlVUZh0I2ZdehRPZsGGXPUJER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          "]], Polygon3DBox[{{1986, 671, 709, 1284, 1283, 2073}}]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.224146685, 0.090484535]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, 
     {GrayLevel[1], EdgeForm[None], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtVDtPlFEQnb33+1ZCfAC+QIxGG1F846O2MSGLxljwcBGMhXb6M4wajYWd
mlib2Gllq1T2EowFJGZBkoVVlrVQ4zk5J9nJmTvf3LkzZ2b20O371++liJiB
ZMizSsQtyDDkLAwN2EaAbThVoXeAO3Fegr4LeAN+Y5CjkCnIBCRB+vHtGHAg
y4/+u227XNFbh7siniLefBnRQvAe2FrQ57ZErABX8X2f7wxm+TTh8xHf21W9
8wn6ryJiG+zX4FOD7QoEvzjn/M9nvXnV7/b43Avsc26s6Q1y+QP9JfAgzrPw
+QB9w7WTg7uucQfO35NyngO+Qw58dAP4ynEYrwVpQ/8JnPTdDDmZ5X8KeNz6
iazvU/ZhLfWKal5znHXguH2SfW6af3JB2+uqeCdv5G/Q+n7gJvJ7ixiLpWKM
+61GUt+Xk/II53gE0o3j56TcJl17x5w8ABaQR7D/C91nnBVgp1D838AhxJlm
nln51twj9v5bqVlgfPJbOK87zm095E8eNvHogVCNdc8e7RO+x/pH3Hf2/4x1
zvL2rLtPknjg3TZw3v1i37bah74XIKPwuQgcNifs1cMkTr4kzd6o+85aOM9r
peaLnC/AvscztjdrNmuuKWfxVmTtBn3oS/6eewf/It4LcpvUe84AZ6rJHCBL
kOQ4jPcjaYdX3ZPH7suYZ4lz0l/KtlCqr6yFNXGn3hfau0apP4Q+4FdId9a3
uvNnnGXYu7L6y51sup+XsvaC+3Ha/LMP5II1kpv/Fu2ErA==
          "]], Polygon3DBox[CompressedData["
1:eJwtkM8uQ1EQxufcc7VNE/Fnw4KIjUS7YIM3kEhEsLAQCZGw5D3YWPQBPAA7
FrYiPEKbhgULDW1KqSIR/CZfk/vl/mbOzJxvzvj2/upeYmYTKEWFaNbL34JZ
EQ7oED5ACfxE8RZ8hJ7heiIuogZc7TH7NfUMwo/kSkE9tUQ5P/O5NbiMdonX
0CcGZjxP/wLxLHyc4V44RR14ktxGkEf3Ws+ZndOXh6+zZnNRvTvokvvaqWKf
eQanUbuknN0n8uze8/ybiTxkqclEeSuTy9P7gyrwKHk+26RnDKhQ0yQucXYH
t9CrKdfC7zfzLjg7QR+p6l/QDfEVfhvwVNR7u7/lKO/u+Z34lvMhcg+UVIlH
4EKQB/fi7+nBX/ftfYbvOh01+4s4F7WT7/bmPjhf8fldT4vwepDXAermg+4b
jHo/6763+/Ee72U1a8N91CwF9fRHeXR/w1Hefb7vfoo68D/SKlM+
          "]], 
         Polygon3DBox[{{1989, 779, 1499, 1205, 1781}, {1498, 767, 766, 411, 
          1304}, {2283, 1513, 777, 258, 1781}, {1505, 660, 238, 332, 1270}, {
          1696, 30, 780, 779, 1989}, {1272, 342, 258, 777, 1512}, {1988, 711, 
          710, 16, 1777}}]}],
       Lighting->{{"Ambient", 
          GrayLevel[0.8]}}]}, 
     {GrayLevel[1], EdgeForm[None], 
      StyleBox[
       GraphicsGroup3DBox[{
         Polygon3DBox[{{1384, 734, 1520}, {762, 248, 764}, {836, 249, 837}, {
          764, 248, 665}, {761, 248, 762}, {835, 249, 836}, {834, 249, 835}, {
          1502, 760, 1494}}], 
         Polygon3DBox[{{1494, 248, 761, 1502}, {837, 249, 514, 839}, {1520, 
          839, 514, 1384}}]}],
       Lighting->{{"Ambient", 
          GrayLevel[0.8]}}]}, {}, {}}, {
     {GrayLevel[0], 
      Line3DBox[{349, 1, 333, 240, 1521, 16, 833, 741, 710, 711, 1519, 654, 
       2082, 1501, 660, 1505, 685, 684, 697, 1273, 346, 297, 349}], 
      Line3DBox[CompressedData["
1:eJwt01tMj3Ecx/FfJTFy56LZUCmHOdxZiJhxIRfWXDFsbkwzzV3c2UjDRiLE
nAtjjoWZ48qc5tSJfweFuGCZw1ZIeD3NxXvvz+/7PN/v//d7nuefurIgb21c
COELlgvxPC0hhOmYga7EELL5M99PCmGm3CnP4hzMxgNNhXq/qY/Sv1HukSfL
cQP1cDIv5BG8lMdzPmfxep7HxZzHe3kFV/IaruYNXMvD7SHN/GbUW5dwDrrt
o8G6hxv5BzfxT37Jv/gV93KMmwaEkKGvA7/VmtUGO0emdZ91i/UfbuW/3MZB
z+voTNzO8dzBMR6n702EdSnPwW57rrMu4hou5CrO5wpexmW8iLfwXC7kqbya
x/ISTuFcLnf2BfaYLU+U1/mNSfIEuUBOts9S17fjIT56B0c5fZB9ypVyO1/j
q9iGYfoX641Dlv4zaldQjRJUoBW12IV3+u/xYXTiCKpwGddxAlPMSnHfQR5q
fqK5T9Sf4hCe4a3rz/kuYtiKIdH71xNzbbSeVKQhHWOQgUx0uDcB5z333ui9
Yb76e33t6o9xAHfQhP1megRhVWLo/8B78QjlaMQH9WJOir4flLm/Ua1b7TaK
cAqXcBr70IDNyPW70diu6NngBepRh724hZvYFN//+YQ+s88K3+WRem+oX8BF
HEcbjqEFnwxu5hrsxB7swLno7DiJMnz9/9/9B8GOilc=
       "]], 
      Line3DBox[{351, 3, 334, 783, 784, 785, 786, 787, 788, 789, 790, 791, 
       1500, 792, 793, 794, 795, 796, 797, 799, 699, 351}], 
      Line3DBox[{647, 6, 337, 245, 751, 752, 753, 754, 755, 756, 757, 759, 
       647}], Line3DBox[{252, 10, 807, 716, 649, 727, 728, 669, 682, 668, 
       252}], Line3DBox[{848, 13, 348, 808, 809, 810, 811, 812, 813, 814, 815,
        1516, 816, 817, 818, 819, 820, 821, 822, 823, 706, 357, 848}], 
      Line3DBox[{359, 15, 344, 259, 358, 1495, 774, 775, 776, 1512, 777, 1513,
        1990, 778, 1499, 779, 780, 782, 653, 30, 1782, 260, 359}], 
      Line3DBox[{665, 248, 1494, 760, 1502, 761, 762, 764, 665}], 
      Line3DBox[{514, 249, 834, 835, 836, 837, 839, 1520, 734, 1384, 514}], 
      Line3DBox[{516, 254, 1304, 411, 765, 766, 767, 768, 1511, 769, 770, 771,
        772, 737, 516}], 
      Line3DBox[{522, 299, 404, 742, 743, 744, 745, 746, 747, 748, 750, 738, 
       522}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{1522, 377, 1833, 396, 1368, 489, 397, 579, 578, 1821, 1783, 
       2089, 1697, 1523, 1908, 2090, 1698, 1952, 2077, 2091, 1699, 1984, 2282,
        1983, 1700, 1524, 2223, 1784, 1845, 523, 1387, 525, 524, 1846, 1993, 
       2224, 1525, 2092, 1701, 1526, 1948, 2093, 1702, 1981, 2074, 2094, 1703,
        1945, 2075, 2095, 1704, 1902, 2255, 1774, 1897, 519, 520, 1385, 384, 
       1835, 493, 1834}], 
      Line3DBox[{1527, 1775, 1904, 1941, 1410, 1822, 1785, 1982, 1994, 2225, 
       1528, 2096, 1705, 1529, 2097, 1706, 1530, 2098, 1707, 1531, 2264, 1953,
        1708, 1954, 2265, 1786, 1847, 1910, 1929, 1911, 2258, 1823, 1912, 
       1787, 1848, 1995, 2226, 1532, 1996, 2156, 1533, 2099, 1709, 1534, 2100,
        1710, 1535, 2101, 1711, 1536, 2253, 1896, 1712, 1905, 2257, 1776, 
       1899, 1939, 1940, 1836}], 
      Line3DBox[{1537, 1903, 1997, 2256, 1951, 1950, 1998, 2263, 1538, 1999, 
       2157, 1539, 2102, 1713, 1540, 2103, 1714, 1541, 2266, 1955, 1715, 1956,
        2267, 1788, 1849, 1913, 1930, 2227, 2076, 1824, 1914, 1789, 1851, 
       2000, 2228, 1542, 2001, 2158, 1543, 2002, 2159, 1544, 2104, 1716, 1545,
        2105, 1717, 1546, 2106, 1718, 1547, 2254, 1898, 1719, 1946}], 
      Line3DBox[{1549, 2003, 2160, 1548, 2004, 2161, 1550, 2005, 2162, 1551, 
       2006, 2163, 1552, 2107, 1720, 1553, 2268, 1957, 1958, 1554, 2269, 1959,
        1790, 1850, 1791, 1931, 1854, 2240, 1855, 1853, 1792, 1852, 1793, 
       2229, 1555, 2007, 2164, 1556, 2008, 2165, 1557, 2009, 2166, 1558, 2108,
        1721, 1559, 2109, 1722, 1560, 2110, 1723, 1561}], 
      Line3DBox[{1563, 2010, 2167, 1562, 2011, 2168, 1564, 2012, 2169, 1565, 
       2013, 2170, 1566, 2014, 2171, 1567, 2270, 1960, 1961, 1568, 2271, 1962,
        1794, 1856, 1795, 1932, 1859, 2241, 1860, 1858, 1796, 1857, 1797, 
       2230, 1569, 2015, 2172, 1570, 2016, 2173, 1571, 2017, 2174, 1572, 2018,
        2175, 1573, 2111, 1724, 1574, 2112, 1725, 1575}], 
      Line3DBox[{106, 916, 107, 917, 108, 918, 109, 919, 110, 920, 111, 921, 
       112, 1333, 444, 922, 113, 445, 923, 114, 924, 115, 925, 116, 926, 117, 
       927, 118, 928, 119, 929, 120}], 
      Line3DBox[{1577, 2019, 2176, 1576, 2020, 2177, 1578, 2021, 2178, 1579, 
       2022, 2179, 1580, 2023, 2180, 1581, 2078, 2181, 1963, 1582, 1446, 1964,
        1861, 1866, 1865, 2249, 1583, 1863, 1864, 1862, 2182, 2072, 1584, 
       2024, 2183, 1585, 2025, 2184, 1586, 2026, 2185, 1587, 2027, 2186, 1588,
        2028, 2187, 1589, 2113, 1726, 1590}], 
      Line3DBox[{1592, 2114, 1727, 1591, 2115, 1728, 1593, 2116, 1729, 1594, 
       2117, 1730, 1595, 2118, 1731, 1596, 2079, 2119, 1732, 1965, 1223, 1867,
        1915, 2029, 2259, 1918, 1916, 1917, 1868, 2250, 1733, 1597, 2120, 
       1734, 1598, 2121, 1735, 1599, 2122, 1736, 1600, 2123, 1737, 1601, 2124,
        1738, 1602, 2125, 1739, 1603}], 
      Line3DBox[{1605, 2030, 2188, 1604, 2126, 1740, 1606, 2127, 1741, 1607, 
       2128, 1742, 1608, 2129, 1743, 1609, 1454, 1744, 1966, 2272, 1798, 1869,
        1919, 2031, 2260, 1922, 1920, 1921, 1870, 2032, 2231, 1610, 2130, 
       1745, 1611, 2131, 1746, 1612, 2132, 1747, 1613, 2133, 1748, 1614, 2134,
        1749, 1615, 2135, 1750, 1616}], 
      Line3DBox[{1618, 2033, 2189, 1617, 2034, 2190, 1619, 2136, 1751, 1620, 
       2137, 1752, 1621, 2138, 1753, 1622, 2273, 1967, 1754, 1968, 2274, 1799,
        1871, 1923, 1933, 1924, 2261, 1825, 1925, 1800, 1872, 2035, 2232, 
       1623, 2036, 2191, 1624, 2139, 1755, 1625, 2140, 1756, 1626, 2141, 1757,
        1627, 2142, 1758, 1628, 2143, 1759, 1629}], 
      Line3DBox[{1631, 2037, 2192, 1630, 2038, 2193, 1632, 2039, 2194, 1633, 
       2144, 1760, 1634, 2145, 1761, 1635, 2275, 1969, 1762, 1970, 2276, 1801,
        1873, 1926, 1934, 1927, 2262, 1826, 1928, 1802, 1875, 2040, 2233, 
       1636, 2041, 2195, 1637, 2042, 2196, 1638, 2146, 1763, 1639, 2147, 1764,
        1640, 2148, 1765, 1641, 2149, 1766, 1642}], 
      Line3DBox[{1644, 2043, 2197, 1643, 2044, 2198, 1645, 2045, 2199, 1646, 
       2046, 2200, 1647, 2150, 1767, 1648, 2277, 1971, 1972, 1649, 2080, 2234,
        1803, 1874, 1804, 1935, 1878, 2242, 1879, 1877, 1805, 1876, 1806, 
       2235, 1650, 2047, 2201, 1651, 2048, 2202, 1652, 2049, 2203, 1653, 2151,
        1768, 1654, 2152, 1769, 1655, 2153, 1770, 1656}], 
      Line3DBox[{1658, 2050, 2204, 1657, 2051, 2205, 1659, 2052, 2206, 1660, 
       2053, 2207, 1661, 2054, 2208, 1662, 2278, 1973, 1974, 1663, 2279, 1975,
        1807, 1880, 1808, 1936, 1883, 2243, 1884, 1882, 1809, 1881, 1810, 
       2236, 1664, 2055, 2209, 1665, 2056, 2210, 1666, 2057, 2211, 1667, 2058,
        2212, 1668, 2154, 1771, 1669, 2155, 1772, 1670}], 
      Line3DBox[{1684, 1816, 1815, 2239, 1683, 2222, 2067, 1682, 2221, 2066, 
       1681, 2220, 2065, 1680, 2219, 2064, 1679, 2218, 2063, 1678, 2238, 1814,
        1886, 1888, 1887, 1677, 2251, 1889, 1890, 1885, 1978, 1977, 2280, 
       1676, 1976, 2217, 2081, 1675, 2216, 2062, 1674, 2215, 2061, 1673, 2214,
        2060, 1672, 2213, 2059, 1671, 2237, 1812, 1811, 1813}], 
      Line3DBox[{1991, 1778, 1837, 1838, 1830, 1891, 2244, 1685, 1987, 1906, 
       1907, 1843, 2247, 1686, 1827, 1779, 1909, 1942, 1687, 1839, 2068, 2084,
        1947, 1979, 1688, 1817, 2069, 2085, 1985, 1689, 1844, 2248, 1943, 
       1944, 1831, 1892, 1992, 2252, 1828, 1900, 1901, 1840, 2245, 1690, 1818,
        1780, 2086, 1691, 1841, 1773, 1949, 2281, 1980, 1692, 1819, 2070, 
       2087, 1893, 1937, 1693, 1829, 2071, 2088, 1894, 1938, 1694, 1986, 2073,
        2246, 1842, 1832, 1895, 1695, 1820, 2083}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{843, 1300, 1375, 1189, 1281, 1190, 2084, 1416, 1414, 1422, 
       1415, 2091, 853, 1041, 2098, 865, 1052, 2103, 878, 1064, 2107, 892, 
       2171, 1077, 906, 2180, 1090, 920, 1103, 2118, 934, 1116, 2129, 948, 
       1129, 2138, 962, 1142, 2145, 976, 1155, 2150, 990, 2208, 1168, 1004, 
       2216, 1181, 1018}], 
      Line3DBox[{1014, 1177, 2237, 1235, 1000, 1164, 2204, 986, 1151, 2197, 
       972, 1138, 2192, 958, 1125, 2189, 944, 1112, 2188, 930, 2114, 1099, 
       916, 1086, 2176, 902, 1073, 2167, 888, 1060, 2160, 874, 1048, 2256, 
       1419, 1421, 1420, 861, 1037, 1410, 1250, 1291, 1290, 849, 1031, 1368, 
       517, 1206, 1307, 1308, 1306, 840, 1508}], 
      Line3DBox[{1015, 1178, 2213, 1001, 1165, 2205, 987, 1152, 2198, 973, 
       1139, 2193, 959, 1126, 2190, 945, 2126, 1113, 931, 2115, 1100, 917, 
       1087, 2177, 903, 1074, 2168, 889, 1061, 2161, 875, 1049, 2263, 1418, 
       862, 1038, 2225, 1212, 850, 578, 1248, 379, 841, 2244, 482, 1515}], 
      Line3DBox[{1016, 1179, 2214, 1002, 1166, 2206, 988, 1153, 2199, 974, 
       1140, 2194, 960, 2136, 1127, 946, 2127, 1114, 932, 2116, 1101, 918, 
       1088, 2178, 904, 1075, 2169, 890, 1062, 2162, 876, 1050, 2157, 863, 
       2096, 1039, 851, 2089, 1032, 1207, 842, 2247, 1027, 1263, 1195, 1292, 
       1196}], 
      Line3DBox[{1017, 1180, 2215, 1003, 1167, 2207, 989, 1154, 2200, 975, 
       2144, 1141, 961, 2137, 1128, 947, 2128, 1115, 933, 2117, 1102, 919, 
       1089, 2179, 905, 1076, 2170, 891, 1063, 2163, 877, 2102, 1051, 864, 
       2097, 1040, 852, 2090, 510, 511, 1909, 244, 722}], 
      Line3DBox[{1019, 1479, 1478, 2217, 1005, 1474, 2278, 1473, 991, 1469, 
       2277, 1468, 977, 1464, 2275, 1463, 963, 1459, 2273, 1458, 949, 1454, 
       1453, 935, 2119, 1449, 1448, 921, 1444, 1443, 2181, 907, 1439, 2270, 
       1438, 893, 1434, 2268, 1433, 879, 1429, 2266, 1428, 866, 1424, 2264, 
       1423, 854, 1488, 2282, 1489, 1492, 1491, 1490, 2085, 1197, 1243, 1275, 
       1274, 1493}], Line3DBox[CompressedData["
1:eJwV0Lkv5HEcxvGvGAkFBTXiiDvIkiF2Y2VHEMTVqDQUmzhm3HaxuzZRbrOt
Qq2XqF2NULlq4t5F/AEkXlO8834+z/f5FTMFw4mBeEoIYRmvqSGsR0LISQvh
jZ/RK/fhMD2EHn62+av/La/gSe7iPe/d3IkLm1X9L/knHuV23rXp4DYc2yzo
f8jn+mX+745xK75g32ZUtySf2SzyP/dnbkEztmyGdKfev7u/4cH9kT+hCRs2
fboTmwX3PO7dDdyIKNZsYro5eRZ3ch3X48B3H/iPTVQ/I0/jVq7hHe+1XJ38
vTbl+il5EjdyJW/bVHFFsrfJ1SfkODa9XbtL5TKUYMQmWzeR/K+8j/OVu4iL
UYhBmwzdmDyKSzmP85GLbu8R3ZHv+90vchZn4iveAWYHPbo=
       "]], 
      Line3DBox[{1021, 1183, 2238, 1237, 1007, 1170, 2236, 1234, 993, 1157, 
       2235, 1232, 979, 1144, 2233, 1230, 965, 1131, 2232, 1228, 951, 1118, 
       2231, 1226, 937, 2250, 1105, 1224, 923, 1092, 1222, 2182, 909, 1079, 
       2230, 1220, 895, 1066, 2229, 1218, 881, 1054, 2228, 1216, 868, 1043, 
       2226, 1214, 856, 1034, 2224, 1210, 845, 2245, 1029, 1244, 1296, 1295, 
       1509}], Line3DBox[{1022, 1184, 2218, 1008, 1171, 2209, 994, 1158, 2201,
        980, 1145, 2195, 966, 1132, 2191, 952, 2130, 1119, 938, 2120, 1106, 
       924, 1093, 2183, 910, 1080, 2172, 896, 1067, 2164, 882, 1055, 2158, 
       869, 1044, 2156, 857, 2092, 1035, 846, 2086, 1030, 1282, 1198, 1297, 
       1199}], Line3DBox[{1023, 1185, 2219, 1009, 1172, 2210, 995, 1159, 2202,
        981, 1146, 2196, 967, 2139, 1133, 953, 2131, 1120, 939, 2121, 1107, 
       925, 1094, 2184, 911, 1081, 2173, 897, 1068, 2165, 883, 1056, 2159, 
       870, 2099, 1045, 858, 2093, 1036, 1485, 1417, 1487, 847, 1484, 2281, 
       1483, 1245, 1191, 1376, 1266, 1497}], 
      Line3DBox[{1024, 1186, 2220, 1010, 1173, 2211, 996, 1160, 2203, 982, 
       2146, 1147, 968, 2140, 1134, 954, 2132, 1121, 940, 2122, 1108, 926, 
       1095, 2185, 912, 1082, 2174, 898, 1069, 2166, 884, 2104, 1057, 871, 
       2100, 1046, 859, 2094, 1363, 1486, 1362, 1364, 2087, 1201, 1246, 1200, 
       1506}], Line3DBox[{1025, 1187, 2221, 1011, 1174, 2212, 997, 2151, 1161,
        983, 2147, 1148, 969, 2141, 1135, 955, 2133, 1122, 941, 2123, 1109, 
       927, 1096, 2186, 913, 1083, 2175, 899, 2108, 1070, 885, 2105, 1058, 
       872, 2101, 1047, 860, 2095, 1366, 1413, 1365, 1367, 2088, 1203, 1265, 
       1202, 1276, 1305}], 
      Line3DBox[{1026, 1188, 2222, 1012, 2154, 1175, 998, 2152, 1162, 984, 
       2148, 1149, 970, 2142, 1136, 956, 2134, 1123, 942, 2124, 1110, 928, 
       1097, 2187, 914, 2111, 1084, 900, 2109, 1071, 886, 2106, 1059, 873, 
       1370, 2253, 1369, 1371, 1192, 2255, 1377, 1379, 1378, 1279, 2246, 1283,
        1284, 1507}], Line3DBox[CompressedData["
1:eJwVzkErgwEcx/G/orwBnHdwcHBwcHBw2MHBwWUvYS+AF8EbQI1ihUJtalPI
aEbb2kaSWkrSJNlexdrnOXz6/Z/vU09PKruRWR+LiAwf4xFd2hMRzwwmIzp2
jXe9bpv09YZd5U1/sHfao62xwqv+p1Xc98l70rzov/qV+4ZrlunoP3rJfUmZ
JVp6wV5QZDH5B+3UnnPGAnXtyJ7Q851jO8+TfmDzfOuHdi75T/3Lc869zx6z
VPVPfdu9yw4pKnpJv7VDNrW25y07xQzT/DMCi1w3mQ==
       "]], 
      Line3DBox[{1241, 1240, 2239, 1239, 1013, 2155, 1176, 999, 2153, 1163, 
       985, 2149, 1150, 971, 2143, 1137, 957, 2135, 1124, 943, 2125, 1111, 
       929, 2113, 1098, 915, 2112, 1085, 901, 2110, 1072, 887, 1373, 2254, 
       1372, 1374, 1193, 2257, 1380, 1382, 1381, 1280, 1288, 1385, 1289, 1211,
        1287, 1312, 1286, 1285, 1514}], Line3DBox[{1503, 1247, 1504}], 
      Line3DBox[{1517, 1194, 1518}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJzsvHk0lt3/NmwmM5UhZEiDyJxUuj6GBkOhJBkSSYNElBDJEMoUSkmGECrJ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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"Axiale z- Richtung [ m]\\t\"", TraditionalForm], 
    FormBox["\"\\tZeit [s]\"", TraditionalForm], 
    FormBox["\"Temperatur [\[Degree]C]\\t\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{{0, 1}, {0, 10000}, {0, 100}},
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02], Automatic},
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.48195320884375*^9, {3.4819532465625*^9, 3.481953273328125*^9}, 
   3.48195379540625*^9, 3.481953890109375*^9, 3.64109891496414*^9, 
   3.641099486700073*^9, 3.641100012529683*^9, 3.641101727019203*^9, 
   3.64164681422568*^9, 3.6416477032439213`*^9, 
   3.641694367132695*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"am", " ", "Ende", " ", "der", " ", 
   RowBox[{"Simulation", ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6416471811954904`*^9, 3.641647198242418*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"u", "[", 
    RowBox[{"z", ",", "tn"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"TRand", "+", "deltaT"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.481954032453125*^9, 3.48195404084375*^9}, 
   3.64110047289038*^9, 3.641101137079879*^9, 3.6416463652869062`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV13k4VN8bAHBLSdYou4gkkSWhzJ28J7SoJCRUqCzRIlt9v6goy7cQKpIS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{481., Automatic},
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0., 0.9999999795918367}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.481954042125*^9, 3.641098915698518*^9, 
  3.6410995485127487`*^9, 3.641100012654684*^9, 3.6411004807497797`*^9, 
  3.641101727300455*^9, 3.6416468144131823`*^9, 3.6416477033845468`*^9, 
  3.6416943674920692`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Vergleich", " ", "mit", " ", "der", " ", "besten", " ", "numerischen", " ", 
   RowBox[{"L\[ODoubleDot]sung", ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.641647068070156*^9, 3.6416470954296117`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"am", " ", "Ende", " ", "der", " ", 
   RowBox[{"Simulation", ":"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6416472096330767`*^9, 3.6416472197737293`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"TLneu", "[", 
     RowBox[{"z", ",", "tn"}], "]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"TRand", "+", "deltaT"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.6411003544369073`*^9, {3.6411004180933437`*^9, 3.6411004194058456`*^9}, 
   3.6411004780466485`*^9, 3.6411011418298893`*^9, 3.6416463683337955`*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1nk8VN/7AHBbiFZ9JGJE9i1ly9zhOaVNRZZUylZRlFAoS0lZviXZo0VS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0., 0.9999999795918367}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6411003557337894`*^9, 3.641100420624603*^9, 
  3.6411004827185383`*^9, 3.6411017274254556`*^9, 3.6416468144913063`*^9, 
  3.641647703493923*^9, 3.6416943676170673`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "[", 
      RowBox[{"z", ",", "tn"}], "]"}], "-", 
     RowBox[{"TLneu", "[", 
      RowBox[{"z", ",", "tn"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6411002851242085`*^9, 3.641100314030542*^9}, {
   3.6411003709057055`*^9, 3.6411003713900857`*^9}, {3.6411004355308943`*^9, 
   3.6411004366559*^9}, 3.6411004925310645`*^9, 3.641100574718809*^9}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwd2Hk8lU8XAPBLJdnJTmVtUSIhlcylqLTZQkJ3ea5QiRZaKIoikiyFKCWK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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 1}, {-0.0025765880203572067`, 0.0025768001174562016`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6411003210461893`*^9, 3.6411003727025895`*^9, 
  3.641100438609031*^9, 3.6411004945466995`*^9, 3.6411005759219418`*^9, 
  3.641101727769206*^9, 3.6416468146788077`*^9, 3.641647703759547*^9, 
  3.641694367835819*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Gesamtsicht", ":"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.6416471686798306`*^9, 3.6416471757423477`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"u", "[", 
     RowBox[{"z", ",", "t"}], "]"}], "-", 
    RowBox[{"TLneu", "[", 
     RowBox[{"z", ",", "t"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "z0", ",", "zn"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "t0", ",", "tn"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Axiale z- Richtung [ m]\\t\>\"", ",", "\"\<\\tZeit [s]\>\"", ",", 
      "\"\<Temperatur [\[Degree]C]\\t\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.48195320528125*^9, 3.481953206671875*^9}, {
   3.641099483293812*^9, 3.641099484856318*^9}, {3.6411011049704065`*^9, 
   3.6411011189235706`*^9}, 3.6416463609587746`*^9, {3.6416472453675566`*^9, 
   3.641647261148857*^9}, {3.641647332289692*^9, 3.641647333742821*^9}}],

Cell[BoxData[
 Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nXc4Vu8fxx9bSdpTaSjakvY351ESSqFBSfYms4yU3VREe2pJaWihwdHW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   "], {{
     {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
       GrayLevel[1], 3], 
      StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmgf8V9Mbx+/9nnOuFJVCRTuahGQnWkIKCdmpSFkVksqeoWRr2aHs7L2z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          "]], Polygon3DBox[CompressedData["
1:eJwtmnfgT9Ufxu+959yvlp2ZmbLKbFApya+trZ2G9qIptFFSUlGkiZSWNLS0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          "]], Polygon3DBox[CompressedData["
1:eJwt13fcTnUfB/DbdV8ohJCRvffIapDKXuGxKkRpPKWioqiksqVUGkjRUOmx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          "]], Polygon3DBox[{{1296, 635, 442, 441, 886, 1247}}]}],
       Lighting->{{"Ambient", 
          RGBColor[0.30100577, 0.224146685, 0.090484535]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{0, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 2, 2}]}, {"Directional", 
          RGBColor[0.2642166, 0.1833123, 0.04261530000000001], 
          ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
     {GrayLevel[0], Line3DBox[CompressedData["
1:eJwl0ktLlGEYBuBXG03HwwgF4iZpI240SWSQJluoGTpIjWFZq0TN0XKmw6J+
Qf2C/AUqpIRBLaVFLSWoPFRq2TaCIiI6IV4vLe657ucZvu97mW+OjhZyMyUh
hAXpVWJv8fGVDw+EUMclNnKZrXzGk3zJLHd4mV84xb+8y2QihPts4CybOc80
n/I0X3CDNZ55Vd6Yx3gozqUhrJknuc48NzjFTU7zLa/xHa9zRt7rBW6xyG3e
4A5v8gNv8SNvc5c5Z0555qR8Mo/zsFxxttfmIT5nD5+wg3Ns4gPW8x4reIe/
3S/Pz7zELQ5wlRmusIWPeISvXFfpeSOSMnezQi7KY6m1O8VyuSDLUmPXxYQU
3WeY1XYZlkrB7jyr7E6wzxxf8JAk1U722u3p5/RKTpjT+j/9bDxD/C3sOvQ/
+iCX5KDezl/McjGeTT/On/HduKZfL9Pb+INn4ll5jF2+/x7/A3o8Viu/xefH
s8f3Yjmq15X8/1/uA5jKSnw=
       "]]}, 
     {GrayLevel[0.2], Line3DBox[CompressedData["
1:eJwVzEdOAlAUBdBHsMSB7sFtSOwJC2DgArCjglETEXfENsAulqFRjAaMHQsx
tonHwcm97/2X358tZPKJiJignIzY6YgodkZk5TkVkuYe0l0Rk+Zdqnywbj9u
P6XvscUnX0yzzx2DblbcXuv3zHDAqt2Qtwe9wSOzPDFs35Q3XPFMn/sR+5Ze
55IL3knZz8lDtnlhzf2ofbecN3/zyhu3jHlryxw18u42+NFDLsgjCnqJXz0h
F+Uxy/omvSyZzxjw58n/X5zyB8AhN48=
       "]], 
      Line3DBox[{940, 1295, 1497, 939, 1282, 1404, 1135, 1292, 1268, 1405, 
       1136, 1284, 1270, 1406, 1137, 1285, 1393, 1407, 1138, 1277, 1604, 1250,
        1139, 1278, 1605, 1247, 1296, 1596, 1276, 1234, 1297, 1591, 1242, 
       1235, 1408, 1140, 1286, 1254, 1409, 1141, 1279, 1397, 1410, 1142, 1288,
        1398, 1411, 1143, 1291, 1607, 1290, 1144, 941, 1412, 1145, 942}], 
      Line3DBox[{944, 1298, 1498, 943, 1299, 1499, 945, 1413, 1146, 946, 1414,
        1147, 947, 1415, 1148, 948, 1416, 1149, 949, 1417, 1300, 1500, 950, 
       1301, 1501, 951, 1302, 1502, 952, 1418, 1150, 953, 1419, 1151, 954, 
       1420, 1152, 955, 1421, 1153, 956, 1422, 1154, 957}], 
      Line3DBox[{959, 1303, 1503, 958, 1304, 1504, 960, 1305, 1505, 961, 1423,
        1155, 962, 1424, 1156, 963, 1425, 1157, 964, 1426, 1306, 1506, 965, 
       1307, 1507, 966, 1308, 1508, 967, 1309, 1509, 968, 1427, 1158, 969, 
       1428, 1159, 970, 1429, 1160, 971, 1430, 1161, 972}], 
      Line3DBox[{974, 1310, 1510, 973, 1311, 1511, 975, 1312, 1512, 976, 1313,
        1513, 977, 1431, 1162, 978, 1432, 1163, 979, 1433, 1314, 1514, 980, 
       1315, 1515, 981, 1316, 1516, 982, 1317, 1517, 983, 1318, 1518, 984, 
       1434, 1164, 985, 1435, 1165, 986, 1436, 1166, 987}], 
      Line3DBox[{989, 1319, 1519, 988, 1320, 1520, 990, 1321, 1521, 991, 1322,
        1522, 992, 1323, 1523, 993, 1437, 1167, 994, 1438, 1324, 1524, 995, 
       1325, 1525, 996, 1326, 1526, 997, 1327, 1527, 998, 1328, 1528, 999, 
       1329, 1529, 1000, 1439, 1168, 1001, 1440, 1169, 1002}], 
      Line3DBox[{106, 510, 107, 511, 108, 512, 109, 513, 110, 514, 111, 515, 
       112, 516, 517, 113, 518, 114, 519, 115, 520, 116, 521, 117, 522, 118, 
       523, 119, 524, 120}], 
      Line3DBox[{1004, 1330, 1530, 1003, 1331, 1531, 1005, 1332, 1532, 1006, 
       1333, 1533, 1007, 1334, 1534, 1008, 1335, 1535, 1009, 706, 1536, 1010, 
       1336, 1537, 1011, 1337, 1538, 1012, 1338, 1539, 1013, 1339, 1540, 1014,
        1340, 1541, 1015, 1341, 1542, 1016, 1441, 1170, 1017}], 
      Line3DBox[{1019, 1442, 1171, 1018, 1443, 1172, 1020, 1444, 1173, 1021, 
       1445, 1174, 1022, 1446, 1175, 1023, 1447, 1176, 1024, 1448, 1342, 1543,
        1025, 1449, 1177, 1026, 1450, 1178, 1027, 1451, 1179, 1028, 1452, 
       1180, 1029, 1453, 1181, 1030, 1454, 1182, 1031, 1455, 1183, 1032}], 
      Line3DBox[{1034, 1343, 1544, 1033, 1456, 1184, 1035, 1457, 1185, 1036, 
       1458, 1186, 1037, 1459, 1187, 1038, 1460, 1188, 1039, 1461, 1344, 1545,
        1040, 1345, 1546, 1041, 1462, 1189, 1042, 1463, 1190, 1043, 1464, 
       1191, 1044, 1465, 1192, 1045, 1466, 1193, 1046, 1467, 1194, 1047}], 
      Line3DBox[{1049, 1346, 1547, 1048, 1347, 1548, 1050, 1468, 1195, 1051, 
       1469, 1196, 1052, 1470, 1197, 1053, 1471, 1198, 1054, 1472, 1348, 1549,
        1055, 1349, 1550, 1056, 1350, 1551, 1057, 1473, 1199, 1058, 1474, 
       1200, 1059, 1475, 1201, 1060, 1476, 1202, 1061, 1477, 1203, 1062}], 
      Line3DBox[{1064, 1351, 1552, 1063, 1352, 1553, 1065, 1353, 1554, 1066, 
       1478, 1204, 1067, 1479, 1205, 1068, 1480, 1206, 1069, 1481, 1354, 1555,
        1070, 1355, 1556, 1071, 1356, 1557, 1072, 1357, 1558, 1073, 1482, 
       1207, 1074, 1483, 1208, 1075, 1484, 1209, 1076, 1485, 1210, 1077}], 
      Line3DBox[{1079, 1358, 1559, 1078, 1359, 1560, 1080, 1360, 1561, 1081, 
       1361, 1562, 1082, 1486, 1211, 1083, 1487, 1212, 1084, 1488, 1362, 1563,
        1085, 1363, 1564, 1086, 1364, 1565, 1087, 1365, 1566, 1088, 1366, 
       1567, 1089, 1489, 1213, 1090, 1490, 1214, 1091, 1491, 1215, 1092}], 
      Line3DBox[{1094, 1367, 1568, 1093, 1368, 1569, 1095, 1369, 1570, 1096, 
       1370, 1571, 1097, 1371, 1572, 1098, 1492, 1216, 1099, 1493, 1372, 1573,
        1100, 1373, 1574, 1101, 1374, 1575, 1102, 1375, 1576, 1103, 1376, 
       1577, 1104, 1377, 1578, 1105, 1494, 1217, 1106, 1495, 1218, 1107}], 
      Line3DBox[{1121, 1240, 1239, 1593, 1120, 1590, 1389, 1119, 1589, 1388, 
       1118, 1588, 1387, 1117, 1587, 1386, 1116, 1586, 1385, 1115, 1585, 1384,
        1114, 1584, 1383, 1496, 1113, 1583, 1382, 1112, 1582, 1381, 1111, 
       1581, 1380, 1110, 1580, 1379, 1109, 1579, 1378, 1108, 1592, 1237, 1236,
        1238}]}, 
     {GrayLevel[0.2], 
      Line3DBox[{427, 855, 876, 856, 833, 899, 898, 1598, 893, 891, 918, 1604,
        892, 440, 645, 1416, 455, 660, 1425, 470, 675, 1432, 485, 690, 1437, 
       500, 1535, 705, 515, 720, 1447, 530, 735, 1460, 545, 750, 1471, 560, 
       765, 1480, 575, 780, 1487, 590, 795, 1492, 605, 1583, 810, 620}], 
      Line3DBox[{428, 857, 877, 858, 834, 895, 900, 1599, 894, 887, 885, 919, 
       1605, 886, 441, 646, 1417, 456, 661, 1426, 471, 676, 1433, 486, 691, 
       1438, 501, 706, 516, 721, 1448, 531, 736, 1461, 546, 751, 1472, 561, 
       766, 1481, 576, 781, 1488, 591, 796, 1493, 606, 811, 1496, 621}], 
      Line3DBox[{432, 867, 868, 843, 828, 1403, 935, 936, 937, 933, 1607, 932,
        448, 653, 1421, 463, 668, 1429, 478, 683, 1435, 493, 698, 1439, 508, 
       1542, 713, 523, 728, 1454, 538, 743, 1466, 553, 758, 1476, 568, 773, 
       1484, 583, 788, 1490, 598, 803, 1494, 613, 1590, 818, 628}], 
      Line3DBox[{433, 873, 874, 851, 1594, 844, 434, 639, 1412, 449, 654, 
       1422, 464, 669, 1430, 479, 684, 1436, 494, 699, 1440, 509, 714, 1441, 
       524, 729, 1455, 539, 744, 1467, 554, 759, 1477, 569, 774, 1485, 584, 
       789, 1491, 599, 804, 1495, 614, 848, 1593, 849, 850}], 
      Line3DBox[{615, 805, 1592, 847, 600, 790, 1568, 585, 775, 1559, 570, 
       760, 1552, 555, 745, 1547, 540, 730, 1544, 525, 1442, 715, 510, 700, 
       1530, 495, 685, 1519, 480, 670, 1510, 465, 655, 1503, 450, 640, 1498, 
       435, 632, 1497, 424, 1400, 629, 881, 883, 882, 884}], 
      Line3DBox[{616, 806, 1579, 601, 791, 1569, 586, 776, 1560, 571, 761, 
       1553, 556, 746, 1548, 541, 1456, 731, 526, 1443, 716, 511, 701, 1531, 
       496, 686, 1520, 481, 671, 1511, 466, 656, 1504, 451, 641, 1499, 436, 
       1404, 633, 934, 421, 425, 1606, 416, 829, 277, 302}], 
      Line3DBox[{617, 807, 1580, 602, 792, 1570, 587, 777, 1561, 572, 762, 
       1554, 557, 1468, 747, 542, 1457, 732, 527, 1444, 717, 512, 702, 1532, 
       497, 687, 1521, 482, 672, 1512, 467, 657, 1505, 452, 1413, 642, 437, 
       1405, 634, 925, 908, 926, 426, 1603, 924, 923, 831, 819, 853, 830}], 
      Line3DBox[{618, 808, 1581, 603, 793, 1571, 588, 778, 1562, 573, 1478, 
       763, 558, 1469, 748, 543, 1458, 733, 528, 1445, 718, 513, 703, 1533, 
       498, 688, 1522, 483, 673, 1513, 468, 1423, 658, 453, 1414, 643, 438, 
       1406, 386, 387, 1271, 228, 305, 244}], 
      Line3DBox[{619, 809, 1582, 604, 794, 1572, 589, 1486, 779, 574, 1479, 
       764, 559, 1470, 749, 544, 1459, 734, 529, 1446, 719, 514, 704, 1534, 
       499, 689, 1523, 484, 1431, 674, 469, 1424, 659, 454, 1415, 644, 439, 
       1407, 889, 927, 888, 890, 1597, 897, 821, 832, 820, 854, 875}], 
      Line3DBox[{622, 812, 1584, 607, 797, 1573, 592, 782, 1563, 577, 767, 
       1555, 562, 752, 1549, 547, 737, 1545, 532, 722, 1543, 517, 707, 1536, 
       502, 692, 1524, 487, 677, 1514, 472, 662, 1506, 457, 647, 1500, 442, 
       635, 1596, 915, 917, 916, 429, 630, 1600, 902, 901, 835, 860, 878, 859,
        869}], Line3DBox[{623, 813, 1585, 608, 798, 1574, 593, 783, 1564, 578,
        768, 1556, 563, 753, 1550, 548, 738, 1546, 533, 1449, 723, 518, 708, 
       1537, 503, 693, 1525, 488, 678, 1515, 473, 663, 1507, 458, 648, 1501, 
       443, 636, 1591, 852, 845, 430, 1595, 631, 905, 836, 862, 861, 870}], 
      Line3DBox[{624, 814, 1586, 609, 799, 1575, 594, 784, 1565, 579, 769, 
       1557, 564, 754, 1551, 549, 1462, 739, 534, 1450, 724, 519, 709, 1538, 
       504, 694, 1526, 489, 679, 1516, 474, 664, 1508, 459, 649, 1502, 444, 
       1408, 637, 928, 846, 929, 930, 1601, 904, 903, 838, 822, 871, 863, 
       837}], Line3DBox[{625, 815, 1587, 610, 800, 1576, 595, 785, 1566, 580, 
       770, 1558, 565, 1473, 755, 550, 1463, 740, 535, 1451, 725, 520, 710, 
       1539, 505, 695, 1527, 490, 680, 1517, 475, 665, 1509, 460, 1418, 650, 
       445, 1409, 638, 920, 896, 922, 431, 907, 1602, 906, 840, 823, 864, 
       839}], Line3DBox[{626, 816, 1588, 611, 801, 1577, 596, 786, 1567, 581, 
       1482, 771, 566, 1474, 756, 551, 1464, 741, 536, 1452, 726, 521, 711, 
       1540, 506, 696, 1528, 491, 681, 1518, 476, 1427, 666, 461, 1419, 651, 
       446, 1410, 910, 921, 909, 911, 1401, 825, 841, 824, 872, 865, 879}], 
      Line3DBox[{627, 817, 1589, 612, 802, 1578, 597, 1489, 787, 582, 1483, 
       772, 567, 1475, 757, 552, 1465, 742, 537, 1453, 727, 522, 712, 1541, 
       507, 697, 1529, 492, 1434, 682, 477, 1428, 667, 462, 1420, 652, 447, 
       1411, 913, 931, 912, 914, 1402, 827, 842, 826, 866, 880}]}, {}, {}}},
   VertexNormals->CompressedData["
1:eJxc/Hc4l2/4P46HSEIJlZZIKFqyMu6LRETJKElJVlZl771n9t57RPbIuG+b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    "]],
  Axes->True,
  AxesLabel->{
    FormBox["\"Axiale z- Richtung [ m]\\t\"", TraditionalForm], 
    FormBox["\"\\tZeit [s]\"", TraditionalForm], 
    FormBox["\"Temperatur [\[Degree]C]\\t\"", TraditionalForm]},
  BoxRatios->{1, 1, 0.4},
  DisplayFunction->Identity,
  FaceGridsStyle->Automatic,
  ImageSize->{654., 280.},
  Method->{"DefaultBoundaryStyle" -> Directive[
      GrayLevel[0.3]], "RotationControl" -> "Globe"},
  PlotRange->{All, All, All},
  PlotRangePadding->{Automatic, Automatic, Automatic},
  Ticks->{Automatic, Automatic, Automatic},
  ViewPoint->{1.1969430118479443`, -2.453024138973844, 2.},
  ViewVertical->{0., 0., 1.}]], "Output",
 CellChangeTimes->{3.6416472943052063`*^9, 3.6416473355553265`*^9, 
  3.641647704243924*^9, 
  3.6416943682889423`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
},
ScreenStyleEnvironment->"Presentation",
WindowSize->{1280, 940},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.0 for Microsoft Windows (32-bit) (September 9, 2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 1449, 34, 261, "Text"],
Cell[1997, 56, 2011, 38, 751, "Text"],
Cell[4011, 96, 146, 4, 157, "Text"],
Cell[4160, 102, 2422, 55, 334, "Input"],
Cell[6585, 159, 158, 2, 50, "Input"],
Cell[CellGroupData[{
Cell[6768, 165, 310, 8, 85, "Input"],
Cell[7081, 175, 740, 14, 50, "Output"]
}, Open  ]],
Cell[7836, 192, 881, 20, 187, "Input"],
Cell[8720, 214, 68, 2, 50, "Input"],
Cell[8791, 218, 68, 2, 50, "Input"],
Cell[8862, 222, 87, 1, 85, "Input"],
Cell[8952, 225, 572, 16, 85, "Input"],
Cell[9527, 243, 776, 24, 119, "Input"],
Cell[CellGroupData[{
Cell[10328, 271, 216, 7, 50, "Input"],
Cell[10547, 280, 944, 19, 52, "Output"]
}, Open  ]],
Cell[11506, 302, 1010, 32, 85, "Input"],
Cell[CellGroupData[{
Cell[12541, 338, 331, 10, 50, "Input"],
Cell[12875, 350, 1017, 21, 52, "Output"]
}, Open  ]],
Cell[13907, 374, 296, 8, 50, "Input"],
Cell[CellGroupData[{
Cell[14228, 386, 365, 10, 84, "Input"],
Cell[14596, 398, 1307, 32, 82, "Output"]
}, Open  ]],
Cell[15918, 433, 481, 15, 50, "Input"],
Cell[CellGroupData[{
Cell[16424, 452, 154, 3, 50, "Input"],
Cell[16581, 457, 1219, 29, 77, "Output"]
}, Open  ]],
Cell[17815, 489, 767, 19, 221, "Input"],
Cell[18585, 510, 143, 2, 50, "Input"],
Cell[18731, 514, 2072, 54, 221, "Input"],
Cell[20806, 570, 68, 1, 50, "Input"],
Cell[20877, 573, 295, 7, 50, "Input"],
Cell[21175, 582, 144, 3, 50, "Input"],
Cell[CellGroupData[{
Cell[21344, 589, 810, 22, 50, "Input"],
Cell[22157, 613, 717, 16, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22911, 634, 570, 15, 50, "Input"],
Cell[23484, 651, 727, 19, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24248, 675, 483, 11, 50, "Input"],
Cell[24734, 688, 2984, 61, 243, "Output"]
}, Open  ]],
Cell[27733, 752, 1389, 51, 85, "Input"],
Cell[29125, 805, 317, 9, 50, "Input"],
Cell[29445, 816, 1287, 48, 85, "Input"],
Cell[30735, 866, 274, 8, 50, "Input"],
Cell[31012, 876, 237, 5, 85, "Input"],
Cell[CellGroupData[{
Cell[31274, 885, 199, 5, 50, "Input"],
Cell[31476, 892, 1826, 50, 129, "Output"]
}, Open  ]],
Cell[33317, 945, 220, 5, 221, "Text"],
Cell[33540, 952, 908, 25, 119, "Input"],
Cell[CellGroupData[{
Cell[34473, 981, 288, 9, 50, "Input"],
Cell[34764, 992, 2057, 55, 182, "Output"]
}, Open  ]],
Cell[36836, 1050, 1198, 28, 187, "Input"],
Cell[38037, 1080, 304, 9, 85, "Input"],
Cell[38344, 1091, 68, 2, 50, "Input"],
Cell[38415, 1095, 71, 2, 50, "Input"],
Cell[CellGroupData[{
Cell[38511, 1101, 379, 11, 50, "Input"],
Cell[38893, 1114, 1190, 20, 76, "Message"],
Cell[40086, 1136, 10485, 207, 93, "Output"]
}, Open  ]],
Cell[50586, 1346, 256, 5, 85, "Input"],
Cell[50845, 1353, 121, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[50991, 1361, 212, 7, 50, "Input"],
Cell[51206, 1370, 10028, 200, 93, "Output"]
}, Open  ]],
Cell[61249, 1573, 153, 4, 85, "Input"],
Cell[CellGroupData[{
Cell[61427, 1581, 615, 16, 85, "Input"],
Cell[62045, 1599, 183329, 2999, 191, 163206, 2669, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[245389, 4601, 295, 6, 221, "Text"],
Cell[245687, 4609, 58, 1, 50, "Input"],
Cell[CellGroupData[{
Cell[245770, 4614, 164, 4, 50, "Input"],
Cell[245937, 4620, 306, 4, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[246280, 4629, 331, 9, 50, "Input"],
Cell[246614, 4640, 775, 14, 76, "Message"],
Cell[247392, 4656, 10462, 207, 93, "Output"]
}, Open  ]],
Cell[257869, 4866, 153, 3, 50, "Input"],
Cell[258025, 4871, 121, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[258171, 4879, 212, 7, 50, "Input"],
Cell[258386, 4888, 10009, 200, 93, "Output"]
}, Open  ]],
Cell[268410, 5091, 323, 6, 221, "Text"],
Cell[268736, 5099, 347, 11, 85, "Input"],
Cell[CellGroupData[{
Cell[269108, 5114, 1020, 24, 85, "Input"],
Cell[270131, 5140, 145939, 2387, 191, 124363, 2032, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[416085, 7530, 602, 13, 187, "Input"],
Cell[CellGroupData[{
Cell[416712, 7547, 1060, 24, 187, "Input"],
Cell[417775, 7573, 7083, 127, 362, "Output"]
}, Open  ]],
Cell[424873, 7703, 1057, 27, 187, "Input"],
Cell[CellGroupData[{
Cell[425955, 7734, 711, 18, 119, "Input"],
Cell[426669, 7754, 4620, 87, 348, "Output"]
}, Open  ]],
Cell[431304, 7844, 189, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[431518, 7852, 894, 24, 119, "Input"],
Cell[432415, 7878, 7013, 127, 335, "Output"]
}, Open  ]],
Cell[439443, 8008, 360, 7, 221, "Text"],
Cell[439806, 8017, 2893, 90, 187, "Input"],
Cell[CellGroupData[{
Cell[442724, 8111, 1489, 40, 119, "Input"],
Cell[444216, 8153, 712, 13, 76, "Message"]
}, Open  ]],
Cell[444943, 8169, 121, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[445089, 8177, 277, 8, 50, "Input"],
Cell[445369, 8187, 9951, 199, 93, "Output"]
}, Open  ]],
Cell[455335, 8389, 347, 11, 85, "Input"],
Cell[CellGroupData[{
Cell[455707, 8404, 971, 24, 85, "Input"],
Cell[456681, 8430, 145997, 2388, 191, 124490, 2034, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[602715, 10823, 756, 19, 85, "Input"],
Cell[603474, 10844, 6824, 124, 245, "Output"]
}, Open  ]],
Cell[610313, 10971, 84, 1, 85, "Input"],
Cell[610400, 10974, 228, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[610653, 10982, 999, 27, 119, "Input"],
Cell[611655, 11011, 11586, 203, 336, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[623278, 11219, 937, 23, 85, "Input"],
Cell[624218, 11244, 38608, 643, 204, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[662863, 11892, 545, 16, 85, "Input"],
Cell[663411, 11910, 40126, 668, 204, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[703574, 12583, 491, 14, 50, "Input"],
Cell[704068, 12599, 1972, 44, 204, "Output"]
}, Open  ]],
Cell[706055, 12646, 348, 8, 177, "Text"],
Cell[706406, 12656, 645, 14, 143, "Text"],
Cell[707054, 12672, 66, 1, 50, "Input"],
Cell[CellGroupData[{
Cell[707145, 12677, 134, 3, 50, "Input"],
Cell[707282, 12682, 285, 4, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[707604, 12691, 174, 4, 50, "Input"],
Cell[707781, 12697, 262, 4, 50, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[708080, 12706, 165, 3, 50, "Input"],
Cell[708248, 12711, 317, 4, 50, "Output"]
}, Open  ]],
Cell[708580, 12718, 121, 2, 50, "Input"],
Cell[708704, 12722, 1360, 38, 119, "Input"],
Cell[CellGroupData[{
Cell[710089, 12764, 394, 9, 50, "Input"],
Cell[710486, 12775, 459, 13, 50, "Output"]
}, Open  ]],
Cell[710960, 12791, 285, 7, 50, "Input"],
Cell[CellGroupData[{
Cell[711270, 12802, 444, 10, 50, "Input"],
Cell[711717, 12814, 1022, 22, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712776, 12841, 389, 10, 50, "Input"],
Cell[713168, 12853, 25885, 437, 238, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[739090, 13295, 214, 4, 50, "Input"],
Cell[739307, 13301, 344, 5, 50, "Output"]
}, Open  ]],
Cell[739666, 13309, 121, 2, 50, "Input"],
Cell[CellGroupData[{
Cell[739812, 13315, 444, 10, 50, "Input"],
Cell[740259, 13327, 1641, 37, 119, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[741937, 13369, 391, 10, 50, "Input"],
Cell[742331, 13381, 36237, 607, 238, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[778605, 13993, 555, 13, 85, "Input"],
Cell[779163, 14008, 846, 16, 85, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[780046, 14029, 148, 3, 50, "Input"],
Cell[780197, 14034, 275, 4, 50, "Output"]
}, Open  ]],
Cell[780487, 14041, 265, 6, 50, "Input"],
Cell[CellGroupData[{
Cell[780777, 14051, 1195, 32, 157, "Input"],
Cell[781975, 14085, 3284, 87, 211, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[785296, 14177, 166, 4, 50, "Input"],
Cell[785465, 14183, 325, 4, 50, "Output"]
}, Open  ]],
Cell[785805, 14190, 159, 3, 50, "Input"],
Cell[CellGroupData[{
Cell[785989, 14197, 807, 20, 85, "Input"],
Cell[786799, 14219, 151331, 2477, 191, 128981, 2109, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[938145, 16699, 206, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[938376, 16707, 467, 12, 50, "Input"],
Cell[938846, 16721, 6283, 113, 336, "Output"]
}, Open  ]],
Cell[945144, 16837, 258, 5, 50, "Input"],
Cell[945405, 16844, 208, 4, 50, "Input"],
Cell[CellGroupData[{
Cell[945638, 16852, 534, 14, 50, "Input"],
Cell[946175, 16868, 6211, 111, 259, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[952423, 16984, 530, 13, 50, "Input"],
Cell[952956, 16999, 9161, 160, 227, "Output"]
}, Open  ]],
Cell[962132, 17162, 159, 3, 50, "Input"],
Cell[CellGroupData[{
Cell[962316, 17169, 906, 21, 85, "Input"],
Cell[963225, 17192, 122584, 1999, 303, 100931, 1642, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
